@@ -48,10 +48,8 @@ import org.apache.commons.compress.utils.IOUtils;
 import org.apache.commons.compress.utils.Sets;
 
 /**
- * Factory to create Archive[In|Out]putStreams from names or the first bytes of
- * the InputStream. In order to add other implementations, you should extend
- * ArchiveStreamFactory and override the appropriate methods (and call their
- * implementation from super of course).
+ * Factory to create Archive[In|Out]putStreams from names or the first bytes of the InputStream. In order to add other implementations, you should extend
+ * ArchiveStreamFactory and override the appropriate methods (and call their implementation from super of course).
  *
  * Compressing a ZIP-File:
  *
@@ -74,12 +72,13 @@ import org.apache.commons.compress.utils.Sets;
  * <pre>
  * final InputStream is = Files.newInputStream(input.toPath());
  * ArchiveInputStream in = new ArchiveStreamFactory().createArchiveInputStream(ArchiveStreamFactory.ZIP, is);
- * ZipArchiveEntry entry = (ZipArchiveEntry)in.getNextEntry();
+ * ZipArchiveEntry entry = (ZipArchiveEntry) in.getNextEntry();
  * OutputStream out = Files.newOutputStream(dir.toPath().resolve(entry.getName()));
  * IOUtils.copy(in, out);
  * out.close();
  * in.close();
  * </pre>
+ * 
  * @Immutable provided that the deprecated method setEntryEncoding is not used.
  * @ThreadSafe even if the deprecated method setEntryEncoding is used
  */
@@ -93,6 +92,7 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
 
     /**
      * The singleton instance using the platform default encoding.
+     * 
      * @since 1.21
      */
     public static final ArchiveStreamFactory DEFAULT = new ArchiveStreamFactory();
@@ -139,367 +139,67 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
 
     /**
      * Constant (value {@value}) used to identify the AR archive format.
+     * 
      * @since 1.1
      */
     public static final String AR = "ar";
 
     /**
-     * Constant (value {@value}) used to identify the ARJ archive format.
-     * Not supported as an output stream type.
+     * Constant (value {@value}) used to identify the ARJ archive format. Not supported as an output stream type.
+     * 
      * @since 1.6
      */
     public static final String ARJ = "arj";
 
     /**
      * Constant (value {@value}) used to identify the CPIO archive format.
+     * 
      * @since 1.1
      */
     public static final String CPIO = "cpio";
 
     /**
-     * Constant (value {@value}) used to identify the Unix DUMP archive format.
-     * Not supported as an output stream type.
+     * Constant (value {@value}) used to identify the Unix DUMP archive format. Not supported as an output stream type.
+     * 
      * @since 1.3
      */
     public static final String DUMP = "dump";
 
     /**
      * Constant (value {@value}) used to identify the JAR archive format.
+     * 
      * @since 1.1
      */
     public static final String JAR = "jar";
 
     /**
      * Constant used to identify the TAR archive format.
+     * 
      * @since 1.1
      */
     public static final String TAR = "tar";
 
     /**
      * Constant (value {@value}) used to identify the ZIP archive format.
+     * 
      * @since 1.1
      */
     public static final String ZIP = "zip";
 
     /**
      * Constant (value {@value}) used to identify the 7z archive format.
+     * 
      * @since 1.8
      */
     public static final String SEVEN_Z = "7z";
 
-    /**
-     * Entry encoding, null for the platform default.
-     */
-    private final String encoding;
-
-    /**
-     * Entry encoding, null for the default.
-     */
-    private volatile String entryEncoding;
-
-    private SortedMap<String, ArchiveStreamProvider> archiveInputStreamProviders;
-
-    private SortedMap<String, ArchiveStreamProvider> archiveOutputStreamProviders;
-
-    static void putAll(final Set<String> names, final ArchiveStreamProvider provider, final TreeMap<String, ArchiveStreamProvider> map) {
-        names.forEach(name -> map.put(toKey(name), provider));
-    }
-
     private static Iterable<ArchiveStreamProvider> archiveStreamProviderIterable() {
         return ServiceLoader.load(ArchiveStreamProvider.class, ClassLoader.getSystemClassLoader());
     }
-    
-    private static String toKey(final String name) {
-        return name.toUpperCase(Locale.ROOT);
-    }
-
-    /**
-     * Constructs a new sorted map from input stream provider names to provider
-     * objects.
-     *
-     * <p>
-     * The map returned by this method will have one entry for each provider for
-     * which support is available in the current Java virtual machine. If two or
-     * more supported provider have the same name then the resulting map will
-     * contain just one of them; which one it will contain is not specified.
-     * </p>
-     *
-     * <p>
-     * The invocation of this method, and the subsequent use of the resulting
-     * map, may cause time-consuming disk or network I/O operations to occur.
-     * This method is provided for applications that need to enumerate all of
-     * the available providers, for example to allow user provider selection.
-     * </p>
-     *
-     * <p>
-     * This method may return different results at different times if new
-     * providers are dynamically made available to the current Java virtual
-     * machine.
-     * </p>
-     *
-     * @return An immutable, map from names to provider objects
-     * @since 1.13
-     */
-    public static SortedMap<String, ArchiveStreamProvider> findAvailableArchiveInputStreamProviders() {
-        return AccessController.doPrivileged((PrivilegedAction<SortedMap<String, ArchiveStreamProvider>>) () -> {
-            final TreeMap<String, ArchiveStreamProvider> map = new TreeMap<>();
-            putAll(DEFAULT.getInputStreamArchiveNames(), DEFAULT, map);
-            archiveStreamProviderIterable().forEach(provider -> putAll(provider.getInputStreamArchiveNames(), provider, map));
-            return map;
-        });
-    }
-
-    /**
-     * Constructs a new sorted map from output stream provider names to provider
-     * objects.
-     *
-     * <p>
-     * The map returned by this method will have one entry for each provider for
-     * which support is available in the current Java virtual machine. If two or
-     * more supported provider have the same name then the resulting map will
-     * contain just one of them; which one it will contain is not specified.
-     * </p>
-     *
-     * <p>
-     * The invocation of this method, and the subsequent use of the resulting
-     * map, may cause time-consuming disk or network I/O operations to occur.
-     * This method is provided for applications that need to enumerate all of
-     * the available providers, for example to allow user provider selection.
-     * </p>
-     *
-     * <p>
-     * This method may return different results at different times if new
-     * providers are dynamically made available to the current Java virtual
-     * machine.
-     * </p>
-     *
-     * @return An immutable, map from names to provider objects
-     * @since 1.13
-     */
-    public static SortedMap<String, ArchiveStreamProvider> findAvailableArchiveOutputStreamProviders() {
-        return AccessController.doPrivileged((PrivilegedAction<SortedMap<String, ArchiveStreamProvider>>) () -> {
-            final TreeMap<String, ArchiveStreamProvider> map = new TreeMap<>();
-            putAll(DEFAULT.getOutputStreamArchiveNames(), DEFAULT, map);
-            archiveStreamProviderIterable().forEach(provider -> putAll(provider.getOutputStreamArchiveNames(), provider, map));
-            return map;
-        });
-    }
-
-    /**
-     * Create an instance using the platform default encoding.
-     */
-    public ArchiveStreamFactory() {
-        this(null);
-    }
-
-    /**
-     * Create an instance using the specified encoding.
-     *
-     * @param encoding the encoding to be used.
-     *
-     * @since 1.10
-     */
-    public ArchiveStreamFactory(final String encoding) {
-        this.encoding = encoding;
-        // Also set the original field so can continue to use it.
-        this.entryEncoding = encoding;
-    }
-
-    /**
-     * Returns the encoding to use for arj, jar, zip, dump, cpio and tar
-     * files, or null for the archiver default.
-     *
-     * @return entry encoding, or null for the archiver default
-     * @since 1.5
-     */
-    public String getEntryEncoding() {
-        return entryEncoding;
-    }
-
-    /**
-     * Sets the encoding to use for arj, jar, zip, dump, cpio and tar files. Use null for the archiver default.
-     *
-     * @param entryEncoding the entry encoding, null uses the archiver default.
-     * @since 1.5
-     * @deprecated 1.10 use {@link #ArchiveStreamFactory(String)} to specify the encoding
-     * @throws IllegalStateException if the constructor {@link #ArchiveStreamFactory(String)}
-     * was used to specify the factory encoding.
-     */
-    @Deprecated
-    public void setEntryEncoding(final String entryEncoding) {
-        // Note: this does not detect new ArchiveStreamFactory(null) but that does not set the encoding anyway
-        if (encoding != null) {
-            throw new IllegalStateException("Cannot overide encoding set by the constructor");
-        }
-        this.entryEncoding = entryEncoding;
-    }
-
-    /**
-     * Creates an archive input stream from an archiver name and an input stream.
-     *
-     * @param archiverName the archive name,
-     * i.e. {@value #AR}, {@value #ARJ}, {@value #ZIP}, {@value #TAR}, {@value #JAR}, {@value #CPIO}, {@value #DUMP} or {@value #SEVEN_Z}
-     * @param in the input stream
-     * @return the archive input stream
-     * @throws ArchiveException if the archiver name is not known
-     * @throws StreamingNotSupportedException if the format cannot be
-     * read from a stream
-     * @throws IllegalArgumentException if the archiver name or stream is null
-     */
-    public ArchiveInputStream createArchiveInputStream(final String archiverName, final InputStream in) throws ArchiveException {
-        return createArchiveInputStream(archiverName, in, entryEncoding);
-    }
-
-    @Override
-    public ArchiveInputStream createArchiveInputStream(final String archiverName, final InputStream in,
-            final String actualEncoding) throws ArchiveException {
-
-        if (archiverName == null) {
-            throw new IllegalArgumentException("Archivername must not be null.");
-        }
-
-        if (in == null) {
-            throw new IllegalArgumentException("InputStream must not be null.");
-        }
-
-        if (AR.equalsIgnoreCase(archiverName)) {
-            return new ArArchiveInputStream(in);
-        }
-        if (ARJ.equalsIgnoreCase(archiverName)) {
-            if (actualEncoding != null) {
-                return new ArjArchiveInputStream(in, actualEncoding);
-            }
-            return new ArjArchiveInputStream(in);
-        }
-        if (ZIP.equalsIgnoreCase(archiverName)) {
-            if (actualEncoding != null) {
-                return new ZipArchiveInputStream(in, actualEncoding);
-            }
-            return new ZipArchiveInputStream(in);
-        }
-        if (TAR.equalsIgnoreCase(archiverName)) {
-            if (actualEncoding != null) {
-                return new TarArchiveInputStream(in, actualEncoding);
-            }
-            return new TarArchiveInputStream(in);
-        }
-        if (JAR.equalsIgnoreCase(archiverName) || APK.equalsIgnoreCase(archiverName)) {
-            if (actualEncoding != null) {
-                return new JarArchiveInputStream(in, actualEncoding);
-            }
-            return new JarArchiveInputStream(in);
-        }
-        if (CPIO.equalsIgnoreCase(archiverName)) {
-            if (actualEncoding != null) {
-                return new CpioArchiveInputStream(in, actualEncoding);
-            }
-            return new CpioArchiveInputStream(in);
-        }
-        if (DUMP.equalsIgnoreCase(archiverName)) {
-            if (actualEncoding != null) {
-                return new DumpArchiveInputStream(in, actualEncoding);
-            }
-            return new DumpArchiveInputStream(in);
-        }
-        if (SEVEN_Z.equalsIgnoreCase(archiverName)) {
-            throw new StreamingNotSupportedException(SEVEN_Z);
-        }
-
-        final ArchiveStreamProvider archiveStreamProvider = getArchiveInputStreamProviders().get(toKey(archiverName));
-        if (archiveStreamProvider != null) {
-            return archiveStreamProvider.createArchiveInputStream(archiverName, in, actualEncoding);
-        }
-
-        throw new ArchiveException("Archiver: " + archiverName + " not found.");
-    }
-
-    /**
-     * Creates an archive output stream from an archiver name and an output stream.
-     *
-     * @param archiverName the archive name,
-     * i.e. {@value #AR}, {@value #ZIP}, {@value #TAR}, {@value #JAR} or {@value #CPIO}
-     * @param out the output stream
-     * @return the archive output stream
-     * @throws ArchiveException if the archiver name is not known
-     * @throws StreamingNotSupportedException if the format cannot be
-     * written to a stream
-     * @throws IllegalArgumentException if the archiver name or stream is null
-     */
-    public ArchiveOutputStream createArchiveOutputStream(final String archiverName, final OutputStream out)
-            throws ArchiveException {
-        return createArchiveOutputStream(archiverName, out, entryEncoding);
-    }
-
-    @Override
-    public ArchiveOutputStream createArchiveOutputStream(
-            final String archiverName, final OutputStream out, final String actualEncoding)
-            throws ArchiveException {
-        if (archiverName == null) {
-            throw new IllegalArgumentException("Archivername must not be null.");
-        }
-        if (out == null) {
-            throw new IllegalArgumentException("OutputStream must not be null.");
-        }
-
-        if (AR.equalsIgnoreCase(archiverName)) {
-            return new ArArchiveOutputStream(out);
-        }
-        if (ZIP.equalsIgnoreCase(archiverName)) {
-            final ZipArchiveOutputStream zip = new ZipArchiveOutputStream(out);
-            if (actualEncoding != null) {
-                zip.setEncoding(actualEncoding);
-            }
-            return zip;
-        }
-        if (TAR.equalsIgnoreCase(archiverName)) {
-            if (actualEncoding != null) {
-                return new TarArchiveOutputStream(out, actualEncoding);
-            }
-            return new TarArchiveOutputStream(out);
-        }
-        if (JAR.equalsIgnoreCase(archiverName)) {
-            if (actualEncoding != null) {
-                return new JarArchiveOutputStream(out, actualEncoding);
-            }
-            return new JarArchiveOutputStream(out);
-        }
-        if (CPIO.equalsIgnoreCase(archiverName)) {
-            if (actualEncoding != null) {
-                return new CpioArchiveOutputStream(out, actualEncoding);
-            }
-            return new CpioArchiveOutputStream(out);
-        }
-        if (SEVEN_Z.equalsIgnoreCase(archiverName)) {
-            throw new StreamingNotSupportedException(SEVEN_Z);
-        }
-
-        final ArchiveStreamProvider archiveStreamProvider = getArchiveOutputStreamProviders().get(toKey(archiverName));
-        if (archiveStreamProvider != null) {
-            return archiveStreamProvider.createArchiveOutputStream(archiverName, out, actualEncoding);
-        }
-
-        throw new ArchiveException("Archiver: " + archiverName + " not found.");
-    }
-
-    /**
-     * Create an archive input stream from an input stream, autodetecting
-     * the archive type from the first few bytes of the stream. The InputStream
-     * must support marks, like BufferedInputStream.
-     *
-     * @param in the input stream
-     * @return the archive input stream
-     * @throws ArchiveException if the archiver name is not known
-     * @throws StreamingNotSupportedException if the format cannot be
-     * read from a stream
-     * @throws IllegalArgumentException if the stream is null or does not support mark
-     */
-    public ArchiveInputStream createArchiveInputStream(final InputStream in)
-            throws ArchiveException {
-        return createArchiveInputStream(detect(in), in);
-    }
 
     /**
      * Try to determine the type of Archiver
+     * 
      * @param in input stream
      * @return type of archiver if found
      * @throws ArchiveException if an archiver cannot be detected in the stream
@@ -571,11 +271,9 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
 
         // COMPRESS-117 - improve auto-recognition
         if (signatureLength >= TAR_HEADER_SIZE) {
-            TarArchiveInputStream tais = null;
-            try {
-                tais = new TarArchiveInputStream(new ByteArrayInputStream(tarHeader));
+            try (TarArchiveInputStream tais = new TarArchiveInputStream(new ByteArrayInputStream(tarHeader))) {
                 // COMPRESS-191 - verify the header checksum
-                if (tais.getNextTarEntry().isCheckSumOK()) {
+                if (tais.getNextEntry().isCheckSumOK()) {
                     return TAR;
                 }
             } catch (final Exception e) { // NOPMD NOSONAR
@@ -583,29 +281,298 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
                 // as IOException
                 // autodetection, simply not a TAR
                 // ignored
-            } finally {
-                IOUtils.closeQuietly(tais);
             }
         }
         throw new ArchiveException("No Archiver found for the stream signature");
     }
 
+    /**
+     * Constructs a new sorted map from input stream provider names to provider objects.
+     *
+     * <p>
+     * The map returned by this method will have one entry for each provider for which support is available in the current Java virtual machine. If two or more
+     * supported provider have the same name then the resulting map will contain just one of them; which one it will contain is not specified.
+     * </p>
+     *
+     * <p>
+     * The invocation of this method, and the subsequent use of the resulting map, may cause time-consuming disk or network I/O operations to occur. This method
+     * is provided for applications that need to enumerate all of the available providers, for example to allow user provider selection.
+     * </p>
+     *
+     * <p>
+     * This method may return different results at different times if new providers are dynamically made available to the current Java virtual machine.
+     * </p>
+     *
+     * @return An immutable, map from names to provider objects
+     * @since 1.13
+     */
+    public static SortedMap<String, ArchiveStreamProvider> findAvailableArchiveInputStreamProviders() {
+        return AccessController.doPrivileged((PrivilegedAction<SortedMap<String, ArchiveStreamProvider>>) () -> {
+            final TreeMap<String, ArchiveStreamProvider> map = new TreeMap<>();
+            putAll(DEFAULT.getInputStreamArchiveNames(), DEFAULT, map);
+            archiveStreamProviderIterable().forEach(provider -> putAll(provider.getInputStreamArchiveNames(), provider, map));
+            return map;
+        });
+    }
+
+    /**
+     * Constructs a new sorted map from output stream provider names to provider objects.
+     *
+     * <p>
+     * The map returned by this method will have one entry for each provider for which support is available in the current Java virtual machine. If two or more
+     * supported provider have the same name then the resulting map will contain just one of them; which one it will contain is not specified.
+     * </p>
+     *
+     * <p>
+     * The invocation of this method, and the subsequent use of the resulting map, may cause time-consuming disk or network I/O operations to occur. This method
+     * is provided for applications that need to enumerate all of the available providers, for example to allow user provider selection.
+     * </p>
+     *
+     * <p>
+     * This method may return different results at different times if new providers are dynamically made available to the current Java virtual machine.
+     * </p>
+     *
+     * @return An immutable, map from names to provider objects
+     * @since 1.13
+     */
+    public static SortedMap<String, ArchiveStreamProvider> findAvailableArchiveOutputStreamProviders() {
+        return AccessController.doPrivileged((PrivilegedAction<SortedMap<String, ArchiveStreamProvider>>) () -> {
+            final TreeMap<String, ArchiveStreamProvider> map = new TreeMap<>();
+            putAll(DEFAULT.getOutputStreamArchiveNames(), DEFAULT, map);
+            archiveStreamProviderIterable().forEach(provider -> putAll(provider.getOutputStreamArchiveNames(), provider, map));
+            return map;
+        });
+    }
+
+    static void putAll(final Set<String> names, final ArchiveStreamProvider provider, final TreeMap<String, ArchiveStreamProvider> map) {
+        names.forEach(name -> map.put(toKey(name), provider));
+    }
+
+    private static String toKey(final String name) {
+        return name.toUpperCase(Locale.ROOT);
+    }
+
+    /**
+     * Entry encoding, null for the platform default.
+     */
+    private final String encoding;
+
+    /**
+     * Entry encoding, null for the default.
+     */
+    private volatile String entryEncoding;
+
+    private SortedMap<String, ArchiveStreamProvider> archiveInputStreamProviders;
+
+    private SortedMap<String, ArchiveStreamProvider> archiveOutputStreamProviders;
+
+    /**
+     * Create an instance using the platform default encoding.
+     */
+    public ArchiveStreamFactory() {
+        this(null);
+    }
+
+    /**
+     * Create an instance using the specified encoding.
+     *
+     * @param encoding the encoding to be used.
+     *
+     * @since 1.10
+     */
+    public ArchiveStreamFactory(final String encoding) {
+        this.encoding = encoding;
+        // Also set the original field so can continue to use it.
+        this.entryEncoding = encoding;
+    }
+
+    /**
+     * Create an archive input stream from an input stream, autodetecting the archive type from the first few bytes of the stream. The InputStream must support
+     * marks, like BufferedInputStream.
+     *
+     * @param <I> The {@link ArchiveInputStream} type.
+     * @param in  the input stream
+     * @return the archive input stream
+     * @throws ArchiveException               if the archiver name is not known
+     * @throws StreamingNotSupportedException if the format cannot be read from a stream
+     * @throws IllegalArgumentException       if the stream is null or does not support mark
+     */
+    public <I extends ArchiveInputStream<? extends ArchiveEntry>> I createArchiveInputStream(final InputStream in) throws ArchiveException {
+        return createArchiveInputStream(detect(in), in);
+    }
+
+    /**
+     * Creates an archive input stream from an archiver name and an input stream.
+     *
+     * @param <I>          The {@link ArchiveInputStream} type.
+     * @param archiverName the archive name, i.e. {@value #AR}, {@value #ARJ}, {@value #ZIP}, {@value #TAR}, {@value #JAR}, {@value #CPIO}, {@value #DUMP} or
+     *                     {@value #SEVEN_Z}
+     * @param in           the input stream
+     * @return the archive input stream
+     * @throws ArchiveException               if the archiver name is not known
+     * @throws StreamingNotSupportedException if the format cannot be read from a stream
+     * @throws IllegalArgumentException       if the archiver name or stream is null
+     */
+    public <I extends ArchiveInputStream<? extends ArchiveEntry>> I createArchiveInputStream(final String archiverName, final InputStream in)
+            throws ArchiveException {
+        return createArchiveInputStream(archiverName, in, entryEncoding);
+    }
+
+    @SuppressWarnings("unchecked")
+    @Override
+    public <I extends ArchiveInputStream<? extends ArchiveEntry>> I createArchiveInputStream(final String archiverName, final InputStream in,
+            final String actualEncoding) throws ArchiveException {
+
+        if (archiverName == null) {
+            throw new IllegalArgumentException("Archiver name must not be null.");
+        }
+
+        if (in == null) {
+            throw new IllegalArgumentException("InputStream must not be null.");
+        }
+
+        if (AR.equalsIgnoreCase(archiverName)) {
+            return (I) new ArArchiveInputStream(in);
+        }
+        if (ARJ.equalsIgnoreCase(archiverName)) {
+            if (actualEncoding != null) {
+                return (I) new ArjArchiveInputStream(in, actualEncoding);
+            }
+            return (I) new ArjArchiveInputStream(in);
+        }
+        if (ZIP.equalsIgnoreCase(archiverName)) {
+            if (actualEncoding != null) {
+                return (I) new ZipArchiveInputStream(in, actualEncoding);
+            }
+            return (I) new ZipArchiveInputStream(in);
+        }
+        if (TAR.equalsIgnoreCase(archiverName)) {
+            if (actualEncoding != null) {
+                return (I) new TarArchiveInputStream(in, actualEncoding);
+            }
+            return (I) new TarArchiveInputStream(in);
+        }
+        if (JAR.equalsIgnoreCase(archiverName) || APK.equalsIgnoreCase(archiverName)) {
+            if (actualEncoding != null) {
+                return (I) new JarArchiveInputStream(in, actualEncoding);
+            }
+            return (I) new JarArchiveInputStream(in);
+        }
+        if (CPIO.equalsIgnoreCase(archiverName)) {
+            if (actualEncoding != null) {
+                return (I) new CpioArchiveInputStream(in, actualEncoding);
+            }
+            return (I) new CpioArchiveInputStream(in);
+        }
+        if (DUMP.equalsIgnoreCase(archiverName)) {
+            if (actualEncoding != null) {
+                return (I) new DumpArchiveInputStream(in, actualEncoding);
+            }
+            return (I) new DumpArchiveInputStream(in);
+        }
+        if (SEVEN_Z.equalsIgnoreCase(archiverName)) {
+            throw new StreamingNotSupportedException(SEVEN_Z);
+        }
+
+        final ArchiveStreamProvider archiveStreamProvider = getArchiveInputStreamProviders().get(toKey(archiverName));
+        if (archiveStreamProvider != null) {
+            return archiveStreamProvider.createArchiveInputStream(archiverName, in, actualEncoding);
+        }
+
+        throw new ArchiveException("Archiver: " + archiverName + " not found.");
+    }
+
+    /**
+     * Creates an archive output stream from an archiver name and an output stream.
+     *
+     * @param <O>          The {@link ArchiveOutputStream} type.
+     * @param archiverName the archive name, i.e. {@value #AR}, {@value #ZIP}, {@value #TAR}, {@value #JAR} or {@value #CPIO}
+     * @param out          the output stream
+     * @return the archive output stream
+     * @throws ArchiveException               if the archiver name is not known
+     * @throws StreamingNotSupportedException if the format cannot be written to a stream
+     * @throws IllegalArgumentException       if the archiver name or stream is null
+     */
+    public <O extends ArchiveOutputStream<? extends ArchiveEntry>> O createArchiveOutputStream(final String archiverName, final OutputStream out)
+            throws ArchiveException {
+        return createArchiveOutputStream(archiverName, out, entryEncoding);
+    }
+
+    @SuppressWarnings("unchecked")
+    @Override
+    public <O extends ArchiveOutputStream<? extends ArchiveEntry>> O createArchiveOutputStream(final String archiverName, final OutputStream out,
+            final String actualEncoding) throws ArchiveException {
+        if (archiverName == null) {
+            throw new IllegalArgumentException("Archiver name must not be null.");
+        }
+        if (out == null) {
+            throw new IllegalArgumentException("OutputStream must not be null.");
+        }
+
+        if (AR.equalsIgnoreCase(archiverName)) {
+            return (O) new ArArchiveOutputStream(out);
+        }
+        if (ZIP.equalsIgnoreCase(archiverName)) {
+            final ZipArchiveOutputStream zip = new ZipArchiveOutputStream(out);
+            if (actualEncoding != null) {
+                zip.setEncoding(actualEncoding);
+            }
+            return (O) zip;
+        }
+        if (TAR.equalsIgnoreCase(archiverName)) {
+            if (actualEncoding != null) {
+                return (O) new TarArchiveOutputStream(out, actualEncoding);
+            }
+            return (O) new TarArchiveOutputStream(out);
+        }
+        if (JAR.equalsIgnoreCase(archiverName)) {
+            if (actualEncoding != null) {
+                return (O) new JarArchiveOutputStream(out, actualEncoding);
+            }
+            return (O) new JarArchiveOutputStream(out);
+        }
+        if (CPIO.equalsIgnoreCase(archiverName)) {
+            if (actualEncoding != null) {
+                return (O) new CpioArchiveOutputStream(out, actualEncoding);
+            }
+            return (O) new CpioArchiveOutputStream(out);
+        }
+        if (SEVEN_Z.equalsIgnoreCase(archiverName)) {
+            throw new StreamingNotSupportedException(SEVEN_Z);
+        }
+
+        final ArchiveStreamProvider archiveStreamProvider = getArchiveOutputStreamProviders().get(toKey(archiverName));
+        if (archiveStreamProvider != null) {
+            return archiveStreamProvider.createArchiveOutputStream(archiverName, out, actualEncoding);
+        }
+
+        throw new ArchiveException("Archiver: " + archiverName + " not found.");
+    }
+
     public SortedMap<String, ArchiveStreamProvider> getArchiveInputStreamProviders() {
         if (archiveInputStreamProviders == null) {
-            archiveInputStreamProviders = Collections
-                    .unmodifiableSortedMap(findAvailableArchiveInputStreamProviders());
+            archiveInputStreamProviders = Collections.unmodifiableSortedMap(findAvailableArchiveInputStreamProviders());
         }
         return archiveInputStreamProviders;
     }
 
     public SortedMap<String, ArchiveStreamProvider> getArchiveOutputStreamProviders() {
         if (archiveOutputStreamProviders == null) {
-            archiveOutputStreamProviders = Collections
-                    .unmodifiableSortedMap(findAvailableArchiveOutputStreamProviders());
+            archiveOutputStreamProviders = Collections.unmodifiableSortedMap(findAvailableArchiveOutputStreamProviders());
         }
         return archiveOutputStreamProviders;
     }
 
+    /**
+     * Gets the encoding to use for arj, jar, ZIP, dump, cpio and tar files, or null for the archiver default.
+     *
+     * @return entry encoding, or null for the archiver default
+     * @since 1.5
+     */
+    public String getEntryEncoding() {
+        return entryEncoding;
+    }
+
     @Override
     public Set<String> getInputStreamArchiveNames() {
         return Sets.newHashSet(AR, ARJ, ZIP, TAR, JAR, CPIO, DUMP, SEVEN_Z);
@@ -616,4 +583,21 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
         return Sets.newHashSet(AR, ZIP, TAR, JAR, CPIO, SEVEN_Z);
     }
 
+    /**
+     * Sets the encoding to use for arj, jar, ZIP, dump, cpio and tar files. Use null for the archiver default.
+     *
+     * @param entryEncoding the entry encoding, null uses the archiver default.
+     * @since 1.5
+     * @deprecated 1.10 use {@link #ArchiveStreamFactory(String)} to specify the encoding
+     * @throws IllegalStateException if the constructor {@link #ArchiveStreamFactory(String)} was used to specify the factory encoding.
+     */
+    @Deprecated
+    public void setEntryEncoding(final String entryEncoding) {
+        // Note: this does not detect new ArchiveStreamFactory(null) but that does not set the encoding anyway
+        if (encoding != null) {
+            throw new IllegalStateException("Cannot overide encoding set by the constructor");
+        }
+        this.entryEncoding = entryEncoding;
+    }
+
 }
