@@ -13,7 +13,6 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 package org.apache.commons.compress.archivers.sevenz;
 
@@ -25,7 +24,7 @@ import org.tukaani.xz.DeltaOptions;
 import org.tukaani.xz.FinishableWrapperOutputStream;
 import org.tukaani.xz.UnsupportedOptionsException;
 
-class DeltaDecoder extends CoderBase {
+final class DeltaDecoder extends AbstractCoder {
     DeltaDecoder() {
         super(Number.class);
     }
@@ -39,7 +38,7 @@ class DeltaDecoder extends CoderBase {
     @SuppressWarnings("resource")
     @Override
     OutputStream encode(final OutputStream out, final Object options) throws IOException {
-        final int distance = numberOptionOrDefault(options, 1);
+        final int distance = toInt(options, 1);
         try {
             return new DeltaOptions(distance).getOutputStream(new FinishableWrapperOutputStream(out));
         } catch (final UnsupportedOptionsException ex) { // NOSONAR
@@ -50,19 +49,19 @@ class DeltaDecoder extends CoderBase {
     @Override
     byte[] getOptionsAsProperties(final Object options) {
         return new byte[] {
-            (byte) (numberOptionOrDefault(options, 1) - 1)
+            (byte) (toInt(options, 1) - 1)
         };
     }
 
-    @Override
-    Object getOptionsFromCoder(final Coder coder, final InputStream in) {
-        return getOptionsFromCoder(coder);
-    }
-
     private int getOptionsFromCoder(final Coder coder) {
         if (coder.properties == null || coder.properties.length == 0) {
             return 1;
         }
         return (0xff & coder.properties[0]) + 1;
     }
+
+    @Override
+    Object getOptionsFromCoder(final Coder coder, final InputStream in) {
+        return getOptionsFromCoder(coder);
+    }
 }
