@@ -13,20 +13,19 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 package org.apache.commons.compress.archivers.sevenz;
 
+import java.nio.file.attribute.FileTime;
 import java.util.Arrays;
-import java.util.Calendar;
 import java.util.Collections;
 import java.util.Date;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.Objects;
-import java.util.TimeZone;
 
 import org.apache.commons.compress.archivers.ArchiveEntry;
+import org.apache.commons.compress.utils.TimeUtils;
 
 /**
  * An entry in a 7z archive.
@@ -35,6 +34,34 @@ import org.apache.commons.compress.archivers.ArchiveEntry;
  * @since 1.6
  */
 public class SevenZArchiveEntry implements ArchiveEntry {
+
+    static final SevenZArchiveEntry[] EMPTY_SEVEN_Z_ARCHIVE_ENTRY_ARRAY = {};
+
+    /**
+     * Converts Java time to NTFS time.
+     * @param date the Java time
+     * @return the NTFS time
+     * @deprecated Use {@link TimeUtils#toNtfsTime(Date)} instead.
+     * @see TimeUtils#toNtfsTime(Date)
+     */
+    @Deprecated
+    public static long javaTimeToNtfsTime(final Date date) {
+        return TimeUtils.toNtfsTime(date);
+    }
+
+    /**
+     * Converts NTFS time (100 nanosecond units since 1 January 1601)
+     * to Java time.
+     * @param ntfsTime the NTFS time in 100 nanosecond units
+     * @return the Java time
+     * @deprecated Use {@link TimeUtils#ntfsTimeToDate(long)} instead.
+     * @see TimeUtils#ntfsTimeToDate(long)
+     */
+    @Deprecated
+    public static Date ntfsTimeToJavaTime(final long ntfsTime) {
+        return TimeUtils.ntfsTimeToDate(ntfsTime);
+    }
+
     private String name;
     private boolean hasStream;
     private boolean isDirectory;
@@ -42,294 +69,147 @@ public class SevenZArchiveEntry implements ArchiveEntry {
     private boolean hasCreationDate;
     private boolean hasLastModifiedDate;
     private boolean hasAccessDate;
-    private long creationDate;
-    private long lastModifiedDate;
-    private long accessDate;
+    private FileTime creationDate;
+    private FileTime lastModifiedDate;
+    private FileTime accessDate;
     private boolean hasWindowsAttributes;
     private int windowsAttributes;
     private boolean hasCrc;
     private long crc, compressedCrc;
-    private long size, compressedSize;
-    private Iterable<? extends SevenZMethodConfiguration> contentMethods;
-    static final SevenZArchiveEntry[] EMPTY_SEVEN_Z_ARCHIVE_ENTRY_ARRAY = new SevenZArchiveEntry[0];
 
+    private long size, compressedSize;
+
+    private Iterable<? extends SevenZMethodConfiguration> contentMethods;
+
+    /**
+     * Constructs a new instance.
+     */
     public SevenZArchiveEntry() {
     }
 
-    /**
-     * Get this entry's name.
-     *
-     * <p>This method returns the raw name as it is stored inside of the archive.</p>
-     *
-     * @return This entry's name.
-     */
     @Override
-    public String getName() {
-        return name;
-    }
-
-    /**
-     * Set this entry's name.
-     *
-     * @param name This entry's new name.
-     */
-    public void setName(final String name) {
-        this.name = name;
-    }
-
-    /**
-     * Whether there is any content associated with this entry.
-     * @return whether there is any content associated with this entry.
-     */
-    public boolean hasStream() {
-        return hasStream;
-    }
-
-    /**
-     * Sets whether there is any content associated with this entry.
-     * @param hasStream whether there is any content associated with this entry.
-     */
-    public void setHasStream(final boolean hasStream) {
-        this.hasStream = hasStream;
-    }
-
-    /**
-     * Return whether or not this entry represents a directory.
-     *
-     * @return True if this entry is a directory.
-     */
-    @Override
-    public boolean isDirectory() {
-        return isDirectory;
-    }
-
-    /**
-     * Sets whether or not this entry represents a directory.
-     *
-     * @param isDirectory True if this entry is a directory.
-     */
-    public void setDirectory(final boolean isDirectory) {
-        this.isDirectory = isDirectory;
-    }
-
-    /**
-     * Indicates whether this is an "anti-item" used in differential backups,
-     * meaning it should delete the same file from a previous backup.
-     * @return true if it is an anti-item, false otherwise
-     */
-    public boolean isAntiItem() {
-        return isAntiItem;
-    }
-
-    /**
-     * Sets whether this is an "anti-item" used in differential backups,
-     * meaning it should delete the same file from a previous backup.
-     * @param isAntiItem true if it is an anti-item, false otherwise
-     */
-    public void setAntiItem(final boolean isAntiItem) {
-        this.isAntiItem = isAntiItem;
-    }
-
-    /**
-     * Returns whether this entry has got a creation date at all.
-     * @return whether the entry has got a creation date
-     */
-    public boolean getHasCreationDate() {
-        return hasCreationDate;
-    }
-
-    /**
-     * Sets whether this entry has got a creation date at all.
-     * @param hasCreationDate whether the entry has got a creation date
-     */
-    public void setHasCreationDate(final boolean hasCreationDate) {
-        this.hasCreationDate = hasCreationDate;
-    }
-
-    /**
-     * Gets the creation date.
-     * @throws UnsupportedOperationException if the entry hasn't got a
-     * creation date.
-     * @return the creation date
-     */
-    public Date getCreationDate() {
-        if (hasCreationDate) {
-            return ntfsTimeToJavaTime(creationDate);
+    public boolean equals(final Object obj) {
+        if (this == obj) {
+            return true;
         }
-        throw new UnsupportedOperationException(
-                "The entry doesn't have this timestamp");
-    }
-
-    /**
-     * Sets the creation date using NTFS time (100 nanosecond units
-     * since 1 January 1601)
-     * @param ntfsCreationDate the creation date
-     */
-    public void setCreationDate(final long ntfsCreationDate) {
-        this.creationDate = ntfsCreationDate;
-    }
-
-    /**
-     * Sets the creation date,
-     * @param creationDate the creation date
-     */
-    public void setCreationDate(final Date creationDate) {
-        hasCreationDate = creationDate != null;
-        if (hasCreationDate) {
-            this.creationDate = javaTimeToNtfsTime(creationDate);
+        if (obj == null || getClass() != obj.getClass()) {
+            return false;
         }
+        final SevenZArchiveEntry other = (SevenZArchiveEntry) obj;
+        return
+            Objects.equals(name, other.name) &&
+            hasStream == other.hasStream &&
+            isDirectory == other.isDirectory &&
+            isAntiItem == other.isAntiItem &&
+            hasCreationDate == other.hasCreationDate &&
+            hasLastModifiedDate == other.hasLastModifiedDate &&
+            hasAccessDate == other.hasAccessDate &&
+            Objects.equals(creationDate, other.creationDate) &&
+            Objects.equals(lastModifiedDate, other.lastModifiedDate) &&
+            Objects.equals(accessDate, other.accessDate) &&
+            hasWindowsAttributes == other.hasWindowsAttributes &&
+            windowsAttributes == other.windowsAttributes &&
+            hasCrc == other.hasCrc &&
+            crc == other.crc &&
+            compressedCrc == other.compressedCrc &&
+            size == other.size &&
+            compressedSize == other.compressedSize &&
+            equalSevenZMethods(contentMethods, other.contentMethods);
     }
 
-    /**
-     * Returns whether this entry has got a last modified date at all.
-     * @return whether this entry has got a last modified date at all
-     */
-    public boolean getHasLastModifiedDate() {
-        return hasLastModifiedDate;
-    }
-
-    /**
-     * Sets whether this entry has got a last modified date at all.
-     * @param hasLastModifiedDate whether this entry has got a last
-     * modified date at all
-     */
-    public void setHasLastModifiedDate(final boolean hasLastModifiedDate) {
-        this.hasLastModifiedDate = hasLastModifiedDate;
-    }
-
-    /**
-     * Gets the last modified date.
-     * @throws UnsupportedOperationException if the entry hasn't got a
-     * last modified date.
-     * @return the last modified date
-     */
-    @Override
-    public Date getLastModifiedDate() {
-        if (hasLastModifiedDate) {
-            return ntfsTimeToJavaTime(lastModifiedDate);
+    private boolean equalSevenZMethods(final Iterable<? extends SevenZMethodConfiguration> c1,
+        final Iterable<? extends SevenZMethodConfiguration> c2) {
+        if (c1 == null) {
+            return c2 == null;
         }
-        throw new UnsupportedOperationException(
-                "The entry doesn't have this timestamp");
-    }
-
-    /**
-     * Sets the last modified date using NTFS time (100 nanosecond
-     * units since 1 January 1601)
-     * @param ntfsLastModifiedDate the last modified date
-     */
-    public void setLastModifiedDate(final long ntfsLastModifiedDate) {
-        this.lastModifiedDate = ntfsLastModifiedDate;
-    }
-
-    /**
-     * Sets the last modified date,
-     * @param lastModifiedDate the last modified date
-     */
-    public void setLastModifiedDate(final Date lastModifiedDate) {
-        hasLastModifiedDate = lastModifiedDate != null;
-        if (hasLastModifiedDate) {
-            this.lastModifiedDate = javaTimeToNtfsTime(lastModifiedDate);
+        if (c2 == null) {
+            return false;
         }
-    }
-
-    /**
-     * Returns whether this entry has got an access date at all.
-     * @return whether this entry has got an access date at all.
-     */
-    public boolean getHasAccessDate() {
-        return hasAccessDate;
-    }
-
-    /**
-     * Sets whether this entry has got an access date at all.
-     * @param hasAcessDate whether this entry has got an access date at all.
-     */
-    public void setHasAccessDate(final boolean hasAcessDate) {
-        this.hasAccessDate = hasAcessDate;
+        final Iterator<? extends SevenZMethodConfiguration> i2 = c2.iterator();
+        for (final SevenZMethodConfiguration element : c1) {
+            if (!i2.hasNext()) {
+                return false;
+            }
+            if (!element.equals(i2.next())) {
+                return false;
+            }
+        }
+        return !i2.hasNext();
     }
 
     /**
      * Gets the access date.
-     * @throws UnsupportedOperationException if the entry hasn't got a
-     * access date.
+     * This is equivalent to {@link SevenZArchiveEntry#getAccessTime()}, but precision is truncated to milliseconds.
+     *
+     * @throws UnsupportedOperationException if the entry hasn't got an access date.
      * @return the access date
+     * @see SevenZArchiveEntry#getAccessTime()
      */
     public Date getAccessDate() {
+        return TimeUtils.toDate(getAccessTime());
+    }
+
+    /**
+     * Gets the access time.
+     *
+     * @throws UnsupportedOperationException if the entry hasn't got an access time.
+     * @return the access time
+     * @since 1.23
+     */
+    public FileTime getAccessTime() {
         if (hasAccessDate) {
-            return ntfsTimeToJavaTime(accessDate);
+            return accessDate;
         }
         throw new UnsupportedOperationException(
                 "The entry doesn't have this timestamp");
     }
 
     /**
-     * Sets the access date using NTFS time (100 nanosecond units
-     * since 1 January 1601)
-     * @param ntfsAccessDate the access date
-     */
-    public void setAccessDate(final long ntfsAccessDate) {
-        this.accessDate = ntfsAccessDate;
-    }
-
-    /**
-     * Sets the access date,
-     * @param accessDate the access date
-     */
-    public void setAccessDate(final Date accessDate) {
-        hasAccessDate = accessDate != null;
-        if (hasAccessDate) {
-            this.accessDate = javaTimeToNtfsTime(accessDate);
-        }
-    }
-
-    /**
-     * Returns whether this entry has windows attributes.
-     * @return whether this entry has windows attributes.
-     */
-    public boolean getHasWindowsAttributes() {
-        return hasWindowsAttributes;
-    }
-
-    /**
-     * Sets whether this entry has windows attributes.
-     * @param hasWindowsAttributes whether this entry has windows attributes.
-     */
-    public void setHasWindowsAttributes(final boolean hasWindowsAttributes) {
-        this.hasWindowsAttributes = hasWindowsAttributes;
-    }
-
-    /**
-     * Gets the windows attributes.
-     * @return the windows attributes
-     */
-    public int getWindowsAttributes() {
-        return windowsAttributes;
-    }
-
-    /**
-     * Sets the windows attributes.
-     * @param windowsAttributes the windows attributes
-     */
-    public void setWindowsAttributes(final int windowsAttributes) {
-        this.windowsAttributes = windowsAttributes;
-    }
-
-    /**
-     * Returns whether this entry has got a crc.
+     * Gets the compressed CRC.
      *
-     * <p>In general entries without streams don't have a CRC either.</p>
-     * @return whether this entry has got a crc.
+     * @return the compressed CRC
+     * @deprecated Use {@link #getCompressedCrcValue()} instead.
      */
-    public boolean getHasCrc() {
-        return hasCrc;
+    @Deprecated
+    int getCompressedCrc() {
+        return (int) compressedCrc;
     }
 
     /**
-     * Sets whether this entry has got a crc.
-     * @param hasCrc whether this entry has got a crc.
+     * Gets the compressed CRC.
+     *
+     * @since 1.7
+     * @return the CRC
      */
-    public void setHasCrc(final boolean hasCrc) {
-        this.hasCrc = hasCrc;
+    long getCompressedCrcValue() {
+        return compressedCrc;
+    }
+
+    /**
+     * Gets this entry's compressed file size.
+     *
+     * @return This entry's compressed file size.
+     */
+    long getCompressedSize() {
+        return compressedSize;
+    }
+
+    /**
+     * Gets the (compression) methods to use for entry's content - the
+     * default is LZMA2.
+     *
+     * <p>Currently only {@link SevenZMethod#COPY}, {@link
+     * SevenZMethod#LZMA2}, {@link SevenZMethod#BZIP2} and {@link
+     * SevenZMethod#DEFLATE} are supported when writing archives.</p>
+     *
+     * <p>The methods will be consulted in iteration order to create
+     * the final output.</p>
+     *
+     * @since 1.8
+     * @return the methods to use for the content
+     */
+    public Iterable<? extends SevenZMethodConfiguration> getContentMethods() {
+        return contentMethods;
     }
 
     /**
@@ -342,18 +222,9 @@ public class SevenZArchiveEntry implements ArchiveEntry {
         return (int) crc;
     }
 
-    /**
-     * Sets the CRC.
-     * @deprecated use setCrcValue instead.
-     * @param crc the CRC
-     */
-    @Deprecated
-    public void setCrc(final int crc) {
-        this.crc = crc;
-    }
-
     /**
      * Gets the CRC.
+     *
      * @since 1.7
      * @return the CRC
      */
@@ -362,22 +233,206 @@ public class SevenZArchiveEntry implements ArchiveEntry {
     }
 
     /**
-     * Sets the CRC.
-     * @since 1.7
-     * @param crc the CRC
+     * Gets the creation date.
+     * This is equivalent to {@link SevenZArchiveEntry#getCreationTime()}, but precision is truncated to milliseconds.
+     *
+     * @throws UnsupportedOperationException if the entry hasn't got a creation date.
+     * @return the new creation date
+     * @see SevenZArchiveEntry#getCreationTime()
      */
-    public void setCrcValue(final long crc) {
-        this.crc = crc;
+    public Date getCreationDate() {
+        return TimeUtils.toDate(getCreationTime());
     }
 
     /**
-     * Gets the compressed CRC.
-     * @deprecated use getCompressedCrcValue instead.
-     * @return the compressed CRC
+     * Gets the creation time.
+     *
+     * @throws UnsupportedOperationException if the entry hasn't got a creation time.
+     * @return the creation time
+     * @since 1.23
      */
-    @Deprecated
-    int getCompressedCrc() {
-        return (int) compressedCrc;
+    public FileTime getCreationTime() {
+        if (hasCreationDate) {
+            return creationDate;
+        }
+        throw new UnsupportedOperationException(
+                "The entry doesn't have this timestamp");
+    }
+
+    /**
+     * Gets whether this entry has got an access date at all.
+     * @return whether this entry has got an access date at all.
+     */
+    public boolean getHasAccessDate() {
+        return hasAccessDate;
+    }
+
+    /**
+     * Gets whether this entry has got a crc.
+     *
+     * <p>In general entries without streams don't have a CRC either.</p>
+     * @return whether this entry has got a crc.
+     */
+    public boolean getHasCrc() {
+        return hasCrc;
+    }
+
+    /**
+     * Gets whether this entry has got a creation date at all.
+     * @return whether the entry has got a creation date
+     */
+    public boolean getHasCreationDate() {
+        return hasCreationDate;
+    }
+
+    /**
+     * Gets whether this entry has got a last modified date at all.
+     * @return whether this entry has got a last modified date at all
+     */
+    public boolean getHasLastModifiedDate() {
+        return hasLastModifiedDate;
+    }
+
+    /**
+     * Gets whether this entry has windows attributes.
+     * @return whether this entry has windows attributes.
+     */
+    public boolean getHasWindowsAttributes() {
+        return hasWindowsAttributes;
+    }
+
+    /**
+     * Gets the last modified date.
+     * This is equivalent to {@link SevenZArchiveEntry#getLastModifiedTime()}, but precision is truncated to milliseconds.
+     *
+     * @throws UnsupportedOperationException if the entry hasn't got a last modified date.
+     * @return the last modified date
+     * @see SevenZArchiveEntry#getLastModifiedTime()
+     */
+    @Override
+    public Date getLastModifiedDate() {
+        return TimeUtils.toDate(getLastModifiedTime());
+    }
+
+    /**
+     * Gets the last modified time.
+     *
+     * @throws UnsupportedOperationException if the entry hasn't got a last modified time.
+     * @return the last modified time
+     * @since 1.23
+     */
+    public FileTime getLastModifiedTime() {
+        if (hasLastModifiedDate) {
+            return lastModifiedDate;
+        }
+        throw new UnsupportedOperationException(
+                "The entry doesn't have this timestamp");
+    }
+
+    /**
+     * Gets this entry's name.
+     *
+     * <p>This method returns the raw name as it is stored inside of the archive.</p>
+     *
+     * @return This entry's name.
+     */
+    @Override
+    public String getName() {
+        return name;
+    }
+
+    /**
+     * Gets this entry's file size.
+     *
+     * @return This entry's file size.
+     */
+    @Override
+    public long getSize() {
+        return size;
+    }
+
+    /**
+     * Gets the windows attributes.
+     * @return the windows attributes
+     */
+    public int getWindowsAttributes() {
+        return windowsAttributes;
+    }
+
+    @Override
+    public int hashCode() {
+        final String n = getName();
+        return n == null ? 0 : n.hashCode();
+    }
+
+    /**
+     * Tests whether there is any content associated with this entry.
+     *
+     * @return whether there is any content associated with this entry.
+     */
+    public boolean hasStream() {
+        return hasStream;
+    }
+
+    /**
+     * Tests whether this is an "anti-item" used in differential backups,
+     * meaning it should delete the same file from a previous backup.
+     *
+     * @return true if it is an anti-item, false otherwise
+     */
+    public boolean isAntiItem() {
+        return isAntiItem;
+    }
+
+    /**
+     * Tests whether or not this entry represents a directory.
+     *
+     * @return True if this entry is a directory.
+     */
+    @Override
+    public boolean isDirectory() {
+        return isDirectory;
+    }
+
+    /**
+     * Sets the access date.
+     *
+     * @param accessDate the new access date
+     * @see SevenZArchiveEntry#setAccessTime(FileTime)
+     */
+    public void setAccessDate(final Date accessDate) {
+        setAccessTime(TimeUtils.toFileTime(accessDate));
+    }
+
+    /**
+     * Sets the access date using NTFS time (100 nanosecond units
+     * since 1 January 1601)
+     * @param ntfsAccessDate the access date
+     */
+    public void setAccessDate(final long ntfsAccessDate) {
+        this.accessDate = TimeUtils.ntfsTimeToFileTime(ntfsAccessDate);
+    }
+
+    /**
+     * Sets the access time.
+     *
+     * @param time the new access time
+     * @since 1.23
+     */
+    public void setAccessTime(final FileTime time) {
+        hasAccessDate = time != null;
+        if (hasAccessDate) {
+            this.accessDate = time;
+        }
+    }
+
+    /**
+     * Sets whether this is an "anti-item" used in differential backups,
+     * meaning it should delete the same file from a previous backup.
+     * @param isAntiItem true if it is an anti-item, false otherwise
+     */
+    public void setAntiItem(final boolean isAntiItem) {
+        this.isAntiItem = isAntiItem;
     }
 
     /**
@@ -390,15 +445,6 @@ public class SevenZArchiveEntry implements ArchiveEntry {
         this.compressedCrc = crc;
     }
 
-    /**
-     * Gets the compressed CRC.
-     * @since 1.7
-     * @return the CRC
-     */
-    long getCompressedCrcValue() {
-        return compressedCrc;
-    }
-
     /**
      * Sets the compressed CRC.
      * @since 1.7
@@ -409,35 +455,7 @@ public class SevenZArchiveEntry implements ArchiveEntry {
     }
 
     /**
-     * Get this entry's file size.
-     *
-     * @return This entry's file size.
-     */
-    @Override
-    public long getSize() {
-        return size;
-    }
-
-    /**
-     * Set this entry's file size.
-     *
-     * @param size This entry's new file size.
-     */
-    public void setSize(final long size) {
-        this.size = size;
-    }
-
-    /**
-     * Get this entry's compressed file size.
-     *
-     * @return This entry's compressed file size.
-     */
-    long getCompressedSize() {
-        return compressedSize;
-    }
-
-    /**
-     * Set this entry's compressed file size.
+     * Sets this entry's compressed file size.
      *
      * @param size This entry's new compressed file size.
      */
@@ -483,109 +501,174 @@ public class SevenZArchiveEntry implements ArchiveEntry {
      * @param methods the methods to use for the content
      * @since 1.22
      */
-    public void setContentMethods(SevenZMethodConfiguration... methods) {
+    public void setContentMethods(final SevenZMethodConfiguration... methods) {
         setContentMethods(Arrays.asList(methods));
     }
 
     /**
-     * Gets the (compression) methods to use for entry's content - the
-     * default is LZMA2.
-     *
-     * <p>Currently only {@link SevenZMethod#COPY}, {@link
-     * SevenZMethod#LZMA2}, {@link SevenZMethod#BZIP2} and {@link
-     * SevenZMethod#DEFLATE} are supported when writing archives.</p>
-     *
-     * <p>The methods will be consulted in iteration order to create
-     * the final output.</p>
-     *
-     * @since 1.8
-     * @return the methods to use for the content
+     * Sets the CRC.
+     * @deprecated use setCrcValue instead.
+     * @param crc the CRC
      */
-    public Iterable<? extends SevenZMethodConfiguration> getContentMethods() {
-        return contentMethods;
-    }
-
-    @Override
-    public int hashCode() {
-        final String n = getName();
-        return n == null ? 0 : n.hashCode();
-    }
-
-    @Override
-    public boolean equals(final Object obj) {
-        if (this == obj) {
-            return true;
-        }
-        if (obj == null || getClass() != obj.getClass()) {
-            return false;
-        }
-        final SevenZArchiveEntry other = (SevenZArchiveEntry) obj;
-        return
-            Objects.equals(name, other.name) &&
-            hasStream == other.hasStream &&
-            isDirectory == other.isDirectory &&
-            isAntiItem == other.isAntiItem &&
-            hasCreationDate == other.hasCreationDate &&
-            hasLastModifiedDate == other.hasLastModifiedDate &&
-            hasAccessDate == other.hasAccessDate &&
-            creationDate == other.creationDate &&
-            lastModifiedDate == other.lastModifiedDate &&
-            accessDate == other.accessDate &&
-            hasWindowsAttributes == other.hasWindowsAttributes &&
-            windowsAttributes == other.windowsAttributes &&
-            hasCrc == other.hasCrc &&
-            crc == other.crc &&
-            compressedCrc == other.compressedCrc &&
-            size == other.size &&
-            compressedSize == other.compressedSize &&
-            equalSevenZMethods(contentMethods, other.contentMethods);
+    @Deprecated
+    public void setCrc(final int crc) {
+        this.crc = crc;
     }
 
     /**
-     * Converts NTFS time (100 nanosecond units since 1 January 1601)
-     * to Java time.
-     * @param ntfsTime the NTFS time in 100 nanosecond units
-     * @return the Java time
+     * Sets the CRC.
+     * @since 1.7
+     * @param crc the CRC
      */
-    public static Date ntfsTimeToJavaTime(final long ntfsTime) {
-        final Calendar ntfsEpoch = Calendar.getInstance();
-        ntfsEpoch.setTimeZone(TimeZone.getTimeZone("GMT+0"));
-        ntfsEpoch.set(1601, 0, 1, 0, 0, 0);
-        ntfsEpoch.set(Calendar.MILLISECOND, 0);
-        final long realTime = ntfsEpoch.getTimeInMillis() + (ntfsTime / (10*1000));
-        return new Date(realTime);
+    public void setCrcValue(final long crc) {
+        this.crc = crc;
     }
 
     /**
-     * Converts Java time to NTFS time.
-     * @param date the Java time
-     * @return the NTFS time
+     * Sets the creation date.
+     *
+     * @param creationDate the new creation date
+     * @see SevenZArchiveEntry#setCreationTime(FileTime)
      */
-    public static long javaTimeToNtfsTime(final Date date) {
-        final Calendar ntfsEpoch = Calendar.getInstance();
-        ntfsEpoch.setTimeZone(TimeZone.getTimeZone("GMT+0"));
-        ntfsEpoch.set(1601, 0, 1, 0, 0, 0);
-        ntfsEpoch.set(Calendar.MILLISECOND, 0);
-        return ((date.getTime() - ntfsEpoch.getTimeInMillis())* 1000 * 10);
+    public void setCreationDate(final Date creationDate) {
+        setCreationTime(TimeUtils.toFileTime(creationDate));
     }
 
-    private boolean equalSevenZMethods(final Iterable<? extends SevenZMethodConfiguration> c1,
-        final Iterable<? extends SevenZMethodConfiguration> c2) {
-        if (c1 == null) {
-            return c2 == null;
+    /**
+     * Sets the creation date using NTFS time (100 nanosecond units
+     * since 1 January 1601)
+     * @param ntfsCreationDate the creation date
+     */
+    public void setCreationDate(final long ntfsCreationDate) {
+        this.creationDate = TimeUtils.ntfsTimeToFileTime(ntfsCreationDate);
+    }
+
+    /**
+     * Sets the creation time.
+     *
+     * @param time the new creation time
+     * @since 1.23
+     */
+    public void setCreationTime(final FileTime time) {
+        hasCreationDate = time != null;
+        if (hasCreationDate) {
+            this.creationDate = time;
         }
-        if (c2 == null) {
-            return false;
+    }
+
+    /**
+     * Sets whether or not this entry represents a directory.
+     *
+     * @param isDirectory True if this entry is a directory.
+     */
+    public void setDirectory(final boolean isDirectory) {
+        this.isDirectory = isDirectory;
+    }
+
+    /**
+     * Sets whether this entry has got an access date at all.
+     * @param hasAcessDate whether this entry has got an access date at all.
+     */
+    public void setHasAccessDate(final boolean hasAcessDate) {
+        this.hasAccessDate = hasAcessDate;
+    }
+
+    /**
+     * Sets whether this entry has got a crc.
+     * @param hasCrc whether this entry has got a crc.
+     */
+    public void setHasCrc(final boolean hasCrc) {
+        this.hasCrc = hasCrc;
+    }
+
+    /**
+     * Sets whether this entry has got a creation date at all.
+     * @param hasCreationDate whether the entry has got a creation date
+     */
+    public void setHasCreationDate(final boolean hasCreationDate) {
+        this.hasCreationDate = hasCreationDate;
+    }
+
+    /**
+     * Sets whether this entry has got a last modified date at all.
+     * @param hasLastModifiedDate whether this entry has got a last
+     * modified date at all
+     */
+    public void setHasLastModifiedDate(final boolean hasLastModifiedDate) {
+        this.hasLastModifiedDate = hasLastModifiedDate;
+    }
+
+    /**
+     * Sets whether there is any content associated with this entry.
+     * @param hasStream whether there is any content associated with this entry.
+     */
+    public void setHasStream(final boolean hasStream) {
+        this.hasStream = hasStream;
+    }
+
+    /**
+     * Sets whether this entry has windows attributes.
+     * @param hasWindowsAttributes whether this entry has windows attributes.
+     */
+    public void setHasWindowsAttributes(final boolean hasWindowsAttributes) {
+        this.hasWindowsAttributes = hasWindowsAttributes;
+    }
+
+    /**
+     * Sets the last modified date.
+     *
+     * @param lastModifiedDate the new last modified date
+     * @see SevenZArchiveEntry#setLastModifiedTime(FileTime)
+     */
+    public void setLastModifiedDate(final Date lastModifiedDate) {
+        setLastModifiedTime(TimeUtils.toFileTime(lastModifiedDate));
+    }
+
+    /**
+     * Sets the last modified date using NTFS time (100 nanosecond
+     * units since 1 January 1601)
+     * @param ntfsLastModifiedDate the last modified date
+     */
+    public void setLastModifiedDate(final long ntfsLastModifiedDate) {
+        this.lastModifiedDate = TimeUtils.ntfsTimeToFileTime(ntfsLastModifiedDate);
+    }
+
+    /**
+     * Sets the last modified time.
+     *
+     * @param time the new last modified time
+     * @since 1.23
+     */
+    public void setLastModifiedTime(final FileTime time) {
+        hasLastModifiedDate = time != null;
+        if (hasLastModifiedDate) {
+            this.lastModifiedDate = time;
         }
-        final Iterator<? extends SevenZMethodConfiguration> i2 = c2.iterator();
-        for (SevenZMethodConfiguration element : c1) {
-            if (!i2.hasNext()) {
-                return false;
-            }
-            if (!element.equals(i2.next())) {
-                return false;
-            }
-        }
-        return !i2.hasNext();
+    }
+
+    /**
+     * Sets this entry's name.
+     *
+     * @param name This entry's new name.
+     */
+    public void setName(final String name) {
+        this.name = name;
+    }
+
+    /**
+     * Sets this entry's file size.
+     *
+     * @param size This entry's new file size.
+     */
+    public void setSize(final long size) {
+        this.size = size;
+    }
+
+    /**
+     * Sets the windows attributes.
+     * @param windowsAttributes the windows attributes
+     */
+    public void setWindowsAttributes(final int windowsAttributes) {
+        this.windowsAttributes = windowsAttributes;
     }
 }
