@@ -36,210 +36,249 @@ public interface TarConstants {
     /**
      * GNU format as per before tar 1.12.
      */
-    int    FORMAT_OLDGNU = 2;
+    int FORMAT_OLDGNU = 2;
 
     /**
      * Pure Posix format.
      */
-    int    FORMAT_POSIX = 3;
+    int FORMAT_POSIX = 3;
+
+    /**
+     * xstar format used by Jörg Schilling's star.
+     */
+    int FORMAT_XSTAR = 4;
 
     /**
      * The length of the name field in a header buffer.
      */
-    int    NAMELEN = 100;
+    int NAMELEN = 100;
 
     /**
      * The length of the mode field in a header buffer.
      */
-    int    MODELEN = 8;
+    int MODELEN = 8;
 
     /**
      * The length of the user id field in a header buffer.
      */
-    int    UIDLEN = 8;
+    int UIDLEN = 8;
 
     /**
      * The length of the group id field in a header buffer.
      */
-    int    GIDLEN = 8;
+    int GIDLEN = 8;
 
     /**
-     * The maximum value of gid/uid in a tar archive which can
-     * be expressed in octal char notation (that's 7 sevens, octal).
+     * The maximum value of gid/uid in a tar archive which can be expressed in octal char notation (that's 7 sevens, octal).
      */
-    long    MAXID = 07777777L;
- 
+    long MAXID = 07777777L;
+
     /**
      * The length of the checksum field in a header buffer.
      */
-    int    CHKSUMLEN = 8;
+    int CHKSUMLEN = 8;
 
     /**
      * Offset of the checksum field within header record.
+     *
      * @since 1.5
      */
-    int    CHKSUM_OFFSET = 148;
+    int CHKSUM_OFFSET = 148;
 
     /**
-     * The length of the size field in a header buffer.
-     * Includes the trailing space or NUL.
+     * The length of the size field in a header buffer. Includes the trailing space or NUL.
      */
-    int    SIZELEN = 12;
+    int SIZELEN = 12;
 
     /**
-     * The maximum size of a file in a tar archive 
-     * which can be expressed in octal char notation (that's 11 sevens, octal).
+     * The maximum size of a file in a tar archive which can be expressed in octal char notation (that's 11 sevens, octal).
      */
-    long   MAXSIZE = 077777777777L;
+    long MAXSIZE = 077777777777L;
 
     /** Offset of start of magic field within header record */
-    int    MAGIC_OFFSET = 257;
+    int MAGIC_OFFSET = 257;
     /**
      * The length of the magic field in a header buffer.
      */
-    int    MAGICLEN = 6;
+    int MAGICLEN = 6;
 
     /** Offset of start of magic field within header record */
-    int    VERSION_OFFSET = 263;
+    int VERSION_OFFSET = 263;
     /**
      * Previously this was regarded as part of "magic" field, but it is separate.
      */
-    int    VERSIONLEN = 2;
+    int VERSIONLEN = 2;
 
     /**
      * The length of the modification time field in a header buffer.
      */
-    int    MODTIMELEN = 12;
+    int MODTIMELEN = 12;
 
     /**
      * The length of the user name field in a header buffer.
      */
-    int    UNAMELEN = 32;
+    int UNAMELEN = 32;
 
     /**
      * The length of the group name field in a header buffer.
      */
-    int    GNAMELEN = 32;
+    int GNAMELEN = 32;
 
     /**
      * The length of each of the device fields (major and minor) in a header buffer.
      */
-    int    DEVLEN = 8;
+    int DEVLEN = 8;
 
     /**
      * Length of the prefix field.
-     * 
+     *
      */
-    int    PREFIXLEN = 155;
+    int PREFIXLEN = 155;
 
     /**
      * The length of the access time field in an old GNU header buffer.
-     * 
+     *
      */
-    int    ATIMELEN_GNU = 12;
+    int ATIMELEN_GNU = 12;
 
     /**
      * The length of the created time field in an old GNU header buffer.
-     * 
+     *
      */
-    int    CTIMELEN_GNU = 12;
+    int CTIMELEN_GNU = 12;
 
     /**
-     * The length of the multivolume start offset field in an old GNU header buffer. 
-     * 
+     * The length of the multivolume start offset field in an old GNU header buffer.
+     *
      */
-    int    OFFSETLEN_GNU = 12;
+    int OFFSETLEN_GNU = 12;
 
     /**
-     * The length of the long names field in an old GNU header buffer. 
-     * 
+     * The length of the long names field in an old GNU header buffer.
+     *
      */
-    int    LONGNAMESLEN_GNU = 4;
+    int LONGNAMESLEN_GNU = 4;
 
     /**
-     * The length of the padding field in an old GNU header buffer. 
-     * 
+     * The length of the padding field in an old GNU header buffer.
+     *
      */
-    int    PAD2LEN_GNU = 1;
+    int PAD2LEN_GNU = 1;
 
     /**
-     * The sum of the length of all sparse headers in an old GNU header buffer. 
-     * 
+     * The sum of the length of all sparse headers in an old GNU header buffer.
+     *
      */
-    int    SPARSELEN_GNU = 96;
+    int SPARSELEN_GNU = 96;
 
     /**
-     * The length of the is extension field in an old GNU header buffer. 
-     * 
+     * The length of the is extension field in an old GNU header buffer.
+     *
      */
-    int    ISEXTENDEDLEN_GNU = 1;
+    int ISEXTENDEDLEN_GNU = 1;
 
     /**
-     * The length of the real size field in an old GNU header buffer. 
-     * 
+     * The length of the real size field in an old GNU header buffer.
+     *
      */
-    int    REALSIZELEN_GNU = 12;
+    int REALSIZELEN_GNU = 12;
 
     /**
-     * The sum of the length of all sparse headers in a sparse header buffer. 
-     * 
+     * The length of offset in struct sparse
+     *
+     * @since 1.20
      */
-    int    SPARSELEN_GNU_SPARSE = 504;
+    int SPARSE_OFFSET_LEN = 12;
 
     /**
-     * The length of the is extension field in a sparse header buffer. 
-     * 
+     * The length of numbytes in struct sparse
+     *
+     * @since 1.20
      */
-    int    ISEXTENDEDLEN_GNU_SPARSE = 1;
+    int SPARSE_NUMBYTES_LEN = 12;
 
     /**
-     * LF_ constants represent the "link flag" of an entry, or more commonly,
-     * the "entry type". This is the "old way" of indicating a normal file.
+     * The number of sparse headers in an old GNU header
+     *
+     * @since 1.20
      */
-    byte   LF_OLDNORM = 0;
+    int SPARSE_HEADERS_IN_OLDGNU_HEADER = 4;
+
+    /**
+     * The number of sparse headers in an extension header
+     *
+     * @since 1.20
+     */
+    int SPARSE_HEADERS_IN_EXTENSION_HEADER = 21;
+
+    /**
+     * The sum of the length of all sparse headers in a sparse header buffer.
+     *
+     */
+    int SPARSELEN_GNU_SPARSE = 504;
+
+    /**
+     * The length of the is extension field in a sparse header buffer.
+     *
+     */
+    int ISEXTENDEDLEN_GNU_SPARSE = 1;
+
+    /**
+     * LF_ constants represent the "link flag" of an entry, or more commonly, the "entry type". This is the "old way" of
+     * indicating a normal file.
+     */
+    byte LF_OLDNORM = 0;
+
+    /**
+     * Offset inside the header for the "link flag" field.
+     *
+     * @since 1.22
+     * @see TarArchiveEntry
+     */
+    int LF_OFFSET = 156;
 
     /**
      * Normal file type.
      */
-    byte   LF_NORMAL = (byte) '0';
+    byte LF_NORMAL = (byte) '0';
 
     /**
      * Link file type.
      */
-    byte   LF_LINK = (byte) '1';
+    byte LF_LINK = (byte) '1';
 
     /**
      * Symbolic link file type.
      */
-    byte   LF_SYMLINK = (byte) '2';
+    byte LF_SYMLINK = (byte) '2';
 
     /**
      * Character device file type.
      */
-    byte   LF_CHR = (byte) '3';
+    byte LF_CHR = (byte) '3';
 
     /**
      * Block device file type.
      */
-    byte   LF_BLK = (byte) '4';
+    byte LF_BLK = (byte) '4';
 
     /**
      * Directory file type.
      */
-    byte   LF_DIR = (byte) '5';
+    byte LF_DIR = (byte) '5';
 
     /**
      * FIFO (pipe) file type.
      */
-    byte   LF_FIFO = (byte) '6';
+    byte LF_FIFO = (byte) '6';
 
     /**
      * Contiguous file type.
      */
-    byte   LF_CONTIG = (byte) '7';
+    byte LF_CONTIG = (byte) '7';
 
     /**
-     * Identifies the *next* file on the tape as having a long linkname.
+     * Identifies the *next* file on the tape as having a long link name.
      */
     byte LF_GNUTYPE_LONGLINK = (byte) 'K';
 
@@ -276,6 +315,13 @@ public interface TarConstants {
      */
     byte LF_PAX_GLOBAL_EXTENDED_HEADER = (byte) 'g';
 
+    /**
+     * Identifies the entry as a multi-volume past volume #0
+     *
+     * @since 1.22
+     */
+    byte LF_MULTIVOLUME = (byte) 'M';
+
     /**
      * The magic tag representing a POSIX tar archive.
      */
@@ -286,8 +332,15 @@ public interface TarConstants {
      * The magic tag representing a GNU tar archive.
      */
     String MAGIC_GNU = "ustar ";
-    // Appear to be two possible GNU versions
+
+    /**
+     * One of two possible GNU versions
+     */
     String VERSION_GNU_SPACE = " \0";
+
+    /**
+     * One of two possible GNU versions
+     */
     String VERSION_GNU_ZERO  = "0\0";
 
     /**
@@ -311,4 +364,75 @@ public interface TarConstants {
      */
     String GNU_LONGLINK = "././@LongLink"; // TODO rename as LONGLINK_GNU ?
 
+    /**
+     * The magix string used in the last four bytes of the header to
+     * identify the xstar format.
+     * @since 1.11
+     */
+    String MAGIC_XSTAR = "tar\0";
+
+    /**
+     * Offset inside the header for the xtar multivolume data
+     *
+     * @since 1.22
+     * @see TarArchiveEntry
+     */
+    int XSTAR_MULTIVOLUME_OFFSET = 464;
+
+    /**
+     * Offset inside the header for the xstar magic bytes.
+     * @since 1.11
+     */
+    int XSTAR_MAGIC_OFFSET = 508;
+
+    /**
+     * Length of the XSTAR magic.
+     * @since 1.11
+     */
+    int XSTAR_MAGIC_LEN = 4;
+
+    /**
+     * Length of the prefix field in xstar archives.
+     *
+     * @since 1.11
+     */
+    int PREFIXLEN_XSTAR = 131;
+
+    /**
+     * Offset inside the header for the prefix field in xstar archives.
+     *
+     * @since 1.22
+     * @see TarArchiveEntry
+     */
+    int XSTAR_PREFIX_OFFSET = 345;
+
+    /**
+     * Offset inside the header for the atime field in xstar archives.
+     *
+     * @since 1.22
+     * @see TarArchiveEntry
+     */
+    int XSTAR_ATIME_OFFSET = 476;
+
+    /**
+     * The length of the access time field in a xstar header buffer.
+     *
+     * @since 1.11
+     */
+    int ATIMELEN_XSTAR = 12;
+
+    /**
+     * Offset inside the header for the ctime field in xstar archives.
+     *
+     * @since 1.22
+     * @see TarArchiveEntry
+     */
+    int XSTAR_CTIME_OFFSET = 488;
+
+    /**
+     * The length of the created time field in a xstar header buffer.
+     *
+     * @since 1.11
+     */
+    int CTIMELEN_XSTAR = 12;
 }
