@@ -13,13 +13,13 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 
 package org.apache.commons.compress.archivers.zip;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
 
+import java.util.Arrays;
 import java.util.zip.CRC32;
 import java.util.zip.ZipException;
 
@@ -32,15 +32,30 @@ public abstract class AbstractUnicodeExtraField implements ZipExtraField {
     private byte[] unicodeName;
     private byte[] data;
 
+    /**
+     * Constructs a new instance.
+     */
     protected AbstractUnicodeExtraField() {
     }
 
     /**
      * Assemble as unicode extension from the name/comment and
-     * encoding of the original zip entry.
+     * encoding of the original ZIP entry.
      *
      * @param text The file name or comment.
-     * @param bytes The encoded of the file name or comment in the zip
+     * @param bytes The encoded of the file name or comment in the ZIP
+     * file.
+     */
+    protected AbstractUnicodeExtraField(final String text, final byte[] bytes) {
+        this(text, bytes, 0, bytes.length);
+    }
+
+    /**
+     * Assemble as unicode extension from the name/comment and
+     * encoding of the original ZIP entry.
+     *
+     * @param text The file name or comment.
+     * @param bytes The encoded of the file name or comment in the ZIP
      * file.
      * @param off The offset of the encoded file name or comment in
      * {@code bytes}.
@@ -55,18 +70,6 @@ public abstract class AbstractUnicodeExtraField implements ZipExtraField {
         unicodeName = text.getBytes(UTF_8);
     }
 
-    /**
-     * Assemble as unicode extension from the name/comment and
-     * encoding of the original zip entry.
-     *
-     * @param text The file name or comment.
-     * @param bytes The encoded of the file name or comment in the zip
-     * file.
-     */
-    protected AbstractUnicodeExtraField(final String text, final byte[] bytes) {
-        this(text, bytes, 0, bytes.length);
-    }
-
     private void assembleData() {
         if (unicodeName == null) {
             return;
@@ -79,49 +82,6 @@ public abstract class AbstractUnicodeExtraField implements ZipExtraField {
         System.arraycopy(unicodeName, 0, data, 5, unicodeName.length);
     }
 
-    /**
-     * @return The CRC32 checksum of the file name or comment as
-     *         encoded in the central directory of the zip file.
-     */
-    public long getNameCRC32() {
-        return nameCRC32;
-    }
-
-    /**
-     * @param nameCRC32 The CRC32 checksum of the file name as encoded
-     *         in the central directory of the zip file to set.
-     */
-    public void setNameCRC32(final long nameCRC32) {
-        this.nameCRC32 = nameCRC32;
-        data = null;
-    }
-
-    /**
-     * @return The UTF-8 encoded name.
-     */
-    public byte[] getUnicodeName() {
-        byte[] b = null;
-        if (unicodeName != null) {
-            b = new byte[unicodeName.length];
-            System.arraycopy(unicodeName, 0, b, 0, b.length);
-        }
-        return b;
-    }
-
-    /**
-     * @param unicodeName The UTF-8 encoded name to set.
-     */
-    public void setUnicodeName(final byte[] unicodeName) {
-        if (unicodeName != null) {
-            this.unicodeName = new byte[unicodeName.length];
-            System.arraycopy(unicodeName, 0, this.unicodeName, 0,
-                             unicodeName.length);
-        } else {
-            this.unicodeName = null;
-        }
-        data = null;
-    }
-
     @Override
     public byte[] getCentralDirectoryData() {
         if (data == null) {
@@ -129,8 +89,7 @@ public abstract class AbstractUnicodeExtraField implements ZipExtraField {
         }
         byte[] b = null;
         if (data != null) {
-            b = new byte[data.length];
-            System.arraycopy(data, 0, b, 0, b.length);
+            b = Arrays.copyOf(data, data.length);
         }
         return b;
     }
@@ -153,6 +112,35 @@ public abstract class AbstractUnicodeExtraField implements ZipExtraField {
         return getCentralDirectoryLength();
     }
 
+    /**
+     * Gets the CRC32 checksum of the file name or comment as encoded in the central directory of the ZIP file.
+     *
+     * @return The CRC32 checksum of the file name or comment as encoded in the central directory of the ZIP file.
+     */
+    public long getNameCRC32() {
+        return nameCRC32;
+    }
+
+    /**
+     * Gets The UTF-8 encoded name.
+     *
+     * @return The UTF-8 encoded name.
+     */
+    public byte[] getUnicodeName() {
+        return unicodeName != null ? Arrays.copyOf(unicodeName, unicodeName.length) : null;
+    }
+
+    /**
+     * Doesn't do anything special since this class always uses the
+     * same data in central directory and local file data.
+     */
+    @Override
+    public void parseFromCentralDirectoryData(final byte[] buffer, final int offset,
+                                              final int length)
+        throws ZipException {
+        parseFromLocalFileData(buffer, offset, length);
+    }
+
     @Override
     public void parseFromLocalFileData(final byte[] buffer, final int offset, final int length)
         throws ZipException {
@@ -175,13 +163,26 @@ public abstract class AbstractUnicodeExtraField implements ZipExtraField {
     }
 
     /**
-     * Doesn't do anything special since this class always uses the
-     * same data in central directory and local file data.
+     * Gets The CRC32 checksum of the file name as encoded in the central directory of the ZIP file to set.
+     *
+     * @param nameCRC32 The CRC32 checksum of the file name as encoded in the central directory of the ZIP file to set.
      */
-    @Override
-    public void parseFromCentralDirectoryData(final byte[] buffer, final int offset,
-                                              final int length)
-        throws ZipException {
-        parseFromLocalFileData(buffer, offset, length);
+    public void setNameCRC32(final long nameCRC32) {
+        this.nameCRC32 = nameCRC32;
+        data = null;
+    }
+
+    /**
+     * Gets the UTF-8 encoded name to set.
+     *
+     * @param unicodeName The UTF-8 encoded name to set.
+     */
+    public void setUnicodeName(final byte[] unicodeName) {
+        if (unicodeName != null) {
+            this.unicodeName = Arrays.copyOf(unicodeName, unicodeName.length);
+        } else {
+            this.unicodeName = null;
+        }
+        data = null;
     }
 }
