@@ -57,6 +57,7 @@ public class AsiExtraField implements ZipExtraField, UnixStat, Cloneable {
 
     private static final ZipShort HEADER_ID = new ZipShort(0x756E);
     private static final int      MIN_SIZE = WORD + SHORT + WORD + SHORT + SHORT;
+
     /**
      * Standard Unix stat(2) file mode.
      */
@@ -89,6 +90,44 @@ public class AsiExtraField implements ZipExtraField, UnixStat, Cloneable {
     public AsiExtraField() {
     }
 
+    @Override
+    public Object clone() {
+        try {
+            final AsiExtraField cloned = (AsiExtraField) super.clone();
+            cloned.crc = new CRC32();
+            return cloned;
+        } catch (final CloneNotSupportedException cnfe) {
+            // impossible
+            throw new UnsupportedOperationException(cnfe); //NOSONAR
+        }
+    }
+
+    /**
+     * Delegate to local file data.
+     * @return the local file data
+     */
+    @Override
+    public byte[] getCentralDirectoryData() {
+        return getLocalFileDataData();
+    }
+
+    /**
+     * Delegate to local file data.
+     * @return the centralDirectory length
+     */
+    @Override
+    public ZipShort getCentralDirectoryLength() {
+        return getLocalFileDataLength();
+    }
+
+    /**
+     * Gets the group id.
+     * @return the group id
+     */
+    public int getGroupId() {
+        return gid;
+    }
+
     /**
      * The Header-ID.
      * @return the value for the header id for this extrafield
@@ -99,30 +138,13 @@ public class AsiExtraField implements ZipExtraField, UnixStat, Cloneable {
     }
 
     /**
-     * Length of the extra field in the local file data - without
-     * Header-ID or length specifier.
-     * @return a {@code ZipShort} for the length of the data of this extra field
+     * Name of linked file
+     *
+     * @return name of the file this entry links to if it is a
+     *         symbolic link, the empty string otherwise.
      */
-    @Override
-    public ZipShort getLocalFileDataLength() {
-        // @formatter:off
-        return new ZipShort(WORD      // CRC
-                          + 2         // Mode
-                          + WORD      // SizDev
-                          + 2         // UID
-                          + 2         // GID
-                          + getLinkedFile().getBytes(Charset.defaultCharset()).length);
-                          // Uses default charset - see class Javadoc
-        // @formatter:on
-    }
-
-    /**
-     * Delegate to local file data.
-     * @return the centralDirectory length
-     */
-    @Override
-    public ZipShort getCentralDirectoryLength() {
-        return getLocalFileDataLength();
+    public String getLinkedFile() {
+        return link;
     }
 
     /**
@@ -157,81 +179,21 @@ public class AsiExtraField implements ZipExtraField, UnixStat, Cloneable {
     }
 
     /**
-     * Delegate to local file data.
-     * @return the local file data
+     * Length of the extra field in the local file data - without
+     * Header-ID or length specifier.
+     * @return a {@code ZipShort} for the length of the data of this extra field
      */
     @Override
-    public byte[] getCentralDirectoryData() {
-        return getLocalFileDataData();
-    }
-
-    /**
-     * Set the user id.
-     * @param uid the user id
-     */
-    public void setUserId(final int uid) {
-        this.uid = uid;
-    }
-
-    /**
-     * Get the user id.
-     * @return the user id
-     */
-    public int getUserId() {
-        return uid;
-    }
-
-    /**
-     * Set the group id.
-     * @param gid the group id
-     */
-    public void setGroupId(final int gid) {
-        this.gid = gid;
-    }
-
-    /**
-     * Get the group id.
-     * @return the group id
-     */
-    public int getGroupId() {
-        return gid;
-    }
-
-    /**
-     * Indicate that this entry is a symbolic link to the given file name.
-     *
-     * @param name Name of the file this entry links to, empty String
-     *             if it is not a symbolic link.
-     */
-    public void setLinkedFile(final String name) {
-        link = name;
-        mode = getMode(mode);
-    }
-
-    /**
-     * Name of linked file
-     *
-     * @return name of the file this entry links to if it is a
-     *         symbolic link, the empty string otherwise.
-     */
-    public String getLinkedFile() {
-        return link;
-    }
-
-    /**
-     * Is this entry a symbolic link?
-     * @return true if this is a symbolic link
-     */
-    public boolean isLink() {
-        return !getLinkedFile().isEmpty();
-    }
-
-    /**
-     * File mode of this file.
-     * @param mode the file mode
-     */
-    public void setMode(final int mode) {
-        this.mode = getMode(mode);
+    public ZipShort getLocalFileDataLength() {
+        // @formatter:off
+        return new ZipShort(WORD      // CRC
+                          + 2         // Mode
+                          + WORD      // SizDev
+                          + 2         // UID
+                          + 2         // GID
+                          + getLinkedFile().getBytes(Charset.defaultCharset()).length);
+                          // Uses default charset - see class Javadoc
+        // @formatter:on
     }
 
     /**
@@ -243,12 +205,26 @@ public class AsiExtraField implements ZipExtraField, UnixStat, Cloneable {
     }
 
     /**
-     * Indicate whether this entry is a directory.
-     * @param dirFlag if true, this entry is a directory
+     * Gets the file mode for given permissions with the correct file type.
+     * @param mode the mode
+     * @return the type with the mode
      */
-    public void setDirectory(final boolean dirFlag) {
-        this.dirFlag = dirFlag;
-        mode = getMode(mode);
+    protected int getMode(final int mode) {
+        int type = FILE_FLAG;
+        if (isLink()) {
+            type = LINK_FLAG;
+        } else if (isDirectory()) {
+            type = DIR_FLAG;
+        }
+        return type | mode & PERM_MASK;
+    }
+
+    /**
+     * Gets the user id.
+     * @return the user id
+     */
+    public int getUserId() {
+        return uid;
     }
 
     /**
@@ -259,6 +235,25 @@ public class AsiExtraField implements ZipExtraField, UnixStat, Cloneable {
         return dirFlag && !isLink();
     }
 
+    /**
+     * Is this entry a symbolic link?
+     * @return true if this is a symbolic link
+     */
+    public boolean isLink() {
+        return !getLinkedFile().isEmpty();
+    }
+
+    /**
+     * Doesn't do anything special since this class always uses the
+     * same data in central directory and local file data.
+     */
+    @Override
+    public void parseFromCentralDirectoryData(final byte[] buffer, final int offset,
+                                              final int length)
+        throws ZipException {
+        parseFromLocalFileData(buffer, offset, length);
+    }
+
     /**
      * Populate data from this array as if it was in local file data.
      * @param data an array of bytes
@@ -309,40 +304,46 @@ public class AsiExtraField implements ZipExtraField, UnixStat, Cloneable {
     }
 
     /**
-     * Doesn't do anything special since this class always uses the
-     * same data in central directory and local file data.
+     * Indicate whether this entry is a directory.
+     * @param dirFlag if true, this entry is a directory
      */
-    @Override
-    public void parseFromCentralDirectoryData(final byte[] buffer, final int offset,
-                                              final int length)
-        throws ZipException {
-        parseFromLocalFileData(buffer, offset, length);
+    public void setDirectory(final boolean dirFlag) {
+        this.dirFlag = dirFlag;
+        mode = getMode(mode);
     }
 
     /**
-     * Get the file mode for given permissions with the correct file type.
-     * @param mode the mode
-     * @return the type with the mode
+     * Sets the group id.
+     * @param gid the group id
      */
-    protected int getMode(final int mode) {
-        int type = FILE_FLAG;
-        if (isLink()) {
-            type = LINK_FLAG;
-        } else if (isDirectory()) {
-            type = DIR_FLAG;
-        }
-        return type | (mode & PERM_MASK);
+    public void setGroupId(final int gid) {
+        this.gid = gid;
     }
 
-    @Override
-    public Object clone() {
-        try {
-            final AsiExtraField cloned = (AsiExtraField) super.clone();
-            cloned.crc = new CRC32();
-            return cloned;
-        } catch (final CloneNotSupportedException cnfe) {
-            // impossible
-            throw new IllegalStateException(cnfe); //NOSONAR
-        }
+    /**
+     * Indicate that this entry is a symbolic link to the given file name.
+     *
+     * @param name Name of the file this entry links to, empty String
+     *             if it is not a symbolic link.
+     */
+    public void setLinkedFile(final String name) {
+        link = name;
+        mode = getMode(mode);
+    }
+
+    /**
+     * File mode of this file.
+     * @param mode the file mode
+     */
+    public void setMode(final int mode) {
+        this.mode = getMode(mode);
+    }
+
+    /**
+     * Sets the user id.
+     * @param uid the user id
+     */
+    public void setUserId(final int uid) {
+        this.uid = uid;
     }
 }
