@@ -38,7 +38,7 @@ import org.apache.commons.compress.utils.InputStreamStatistics;
  *
  * @since 1.7
  */
-class ExplodingInputStream extends InputStream implements InputStreamStatistics {
+final class ExplodingInputStream extends InputStream implements InputStreamStatistics {
 
     /** The underlying stream containing the compressed data */
     private final InputStream in;
@@ -91,61 +91,6 @@ class ExplodingInputStream extends InputStream implements InputStreamStatistics
         this.in = in;
     }
 
-    /**
-     * Reads the encoded binary trees and prepares the bit stream.
-     *
-     * @throws IOException
-     */
-    private void init() throws IOException {
-        if (bits == null) {
-            // we do not want to close in
-            try (CountingInputStream i = new CountingInputStream(new CloseShieldFilterInputStream(in))) {
-                if (numberOfTrees == 3) {
-                    literalTree = BinaryTree.decode(i, 256);
-                }
-
-                lengthTree = BinaryTree.decode(i, 64);
-                distanceTree = BinaryTree.decode(i, 64);
-                treeSizes += i.getBytesRead();
-            }
-
-            bits = new BitStream(in);
-        }
-    }
-
-    @Override
-    public int read() throws IOException {
-        if (!buffer.available()) {
-            try {
-                fillBuffer();
-            } catch (final IllegalArgumentException ex) {
-                throw new IOException("bad IMPLODE stream", ex);
-            }
-        }
-
-        final int ret = buffer.get();
-        if (ret > -1) {
-            uncompressedCount++;
-        }
-        return ret;
-    }
-
-    /**
-     * @since 1.17
-     */
-    @Override
-    public long getCompressedCount() {
-        return bits.getBytesRead() + treeSizes;
-    }
-
-    /**
-     * @since 1.17
-     */
-    @Override
-    public long getUncompressedCount() {
-        return uncompressedCount;
-    }
-
     /**
      * @since 1.17
      */
@@ -156,7 +101,7 @@ class ExplodingInputStream extends InputStream implements InputStreamStatistics
 
     /**
      * Fill the sliding dictionary with more data.
-     * @throws IOException
+     * @throws IOException on error.
      */
     private void fillBuffer() throws IOException {
         init();
@@ -208,4 +153,59 @@ class ExplodingInputStream extends InputStream implements InputStreamStatistics
         }
     }
 
+    /**
+     * @since 1.17
+     */
+    @Override
+    public long getCompressedCount() {
+        return bits.getBytesRead() + treeSizes;
+    }
+
+    /**
+     * @since 1.17
+     */
+    @Override
+    public long getUncompressedCount() {
+        return uncompressedCount;
+    }
+
+    /**
+     * Reads the encoded binary trees and prepares the bit stream.
+     *
+     * @throws IOException
+     */
+    private void init() throws IOException {
+        if (bits == null) {
+            // we do not want to close in
+            try (CountingInputStream i = new CountingInputStream(new CloseShieldFilterInputStream(in))) {
+                if (numberOfTrees == 3) {
+                    literalTree = BinaryTree.decode(i, 256);
+                }
+
+                lengthTree = BinaryTree.decode(i, 64);
+                distanceTree = BinaryTree.decode(i, 64);
+                treeSizes += i.getBytesRead();
+            }
+
+            bits = new BitStream(in);
+        }
+    }
+
+    @Override
+    public int read() throws IOException {
+        if (!buffer.available()) {
+            try {
+                fillBuffer();
+            } catch (final IllegalArgumentException ex) {
+                throw new IOException("bad IMPLODE stream", ex);
+            }
+        }
+
+        final int ret = buffer.get();
+        if (ret > -1) {
+            uncompressedCount++;
+        }
+        return ret;
+    }
+
 }
