@@ -13,7 +13,6 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 package org.apache.commons.compress.archivers.zip;
 
@@ -35,27 +34,23 @@ import org.apache.commons.compress.parallel.ScatterGatherBackingStore;
 import org.apache.commons.compress.utils.BoundedInputStream;
 
 /**
- * A zip output stream that is optimized for multi-threaded scatter/gather construction of zip files.
+ * A ZIP output stream that is optimized for multi-threaded scatter/gather construction of ZIP files.
  * <p>
- * The internal data format of the entries used by this class are entirely private to this class
- * and are not part of any public api whatsoever.
+ * The internal data format of the entries used by this class are entirely private to this class and are not part of any public api whatsoever.
  * </p>
- * <p>It is possible to extend this class to support different kinds of backing storage, the default
- * implementation only supports file-based backing.
+ * <p>
+ * It is possible to extend this class to support different kinds of backing storage, the default implementation only supports file-based backing.
+ * </p>
+ * <p>
+ * Thread safety: This class supports multiple threads. But the "writeTo" method must be called by the thread that originally created the
+ * {@link ZipArchiveEntry}.
  * </p>
- * Thread safety: This class supports multiple threads. But the "writeTo" method must be called
- * by the thread that originally created the {@link ZipArchiveEntry}.
  *
  * @since 1.10
  */
 public class ScatterZipOutputStream implements Closeable {
-    private final Queue<CompressedEntry> items = new ConcurrentLinkedQueue<>();
-    private final ScatterGatherBackingStore backingStore;
-    private final StreamCompressor streamCompressor;
-    private final AtomicBoolean isClosed = new AtomicBoolean();
-    private ZipEntryWriter zipEntryWriter;
 
-    private static class CompressedEntry {
+    private static final class CompressedEntry {
         final ZipArchiveEntryRequest zipArchiveEntryRequest;
         final long crc;
         final long compressedSize;
@@ -69,12 +64,12 @@ public class ScatterZipOutputStream implements Closeable {
         }
 
         /**
-         * Update the original {@link ZipArchiveEntry} with sizes/crc
-         * Do not use this methods from threads that did not create the instance itself !
-         * @return the zipArchiveEntry that is basis for this request
+         * Updates the original {@link ZipArchiveEntry} with sizes/crc.
+         * Do not use this method from threads that did not create the instance itself!
+         * @return the zipArchiveEntry that is the basis for this request.
          */
 
-        public ZipArchiveEntry transferToArchiveEntry(){
+        public ZipArchiveEntry transferToArchiveEntry() {
             final ZipArchiveEntry entry = zipArchiveEntryRequest.getZipArchiveEntry();
             entry.setCompressedSize(compressedSize);
             entry.setSize(size);
@@ -84,45 +79,6 @@ public class ScatterZipOutputStream implements Closeable {
         }
     }
 
-    public ScatterZipOutputStream(final ScatterGatherBackingStore backingStore,
-                                  final StreamCompressor streamCompressor) {
-        this.backingStore = backingStore;
-        this.streamCompressor = streamCompressor;
-    }
-
-    /**
-     * Add an archive entry to this scatter stream.
-     *
-     * @param zipArchiveEntryRequest The entry to write.
-     * @throws IOException    If writing fails
-     */
-    public void addArchiveEntry(final ZipArchiveEntryRequest zipArchiveEntryRequest) throws IOException {
-        try (final InputStream payloadStream = zipArchiveEntryRequest.getPayloadStream()) {
-            streamCompressor.deflate(payloadStream, zipArchiveEntryRequest.getMethod());
-        }
-        items.add(new CompressedEntry(zipArchiveEntryRequest, streamCompressor.getCrc32(),
-                                      streamCompressor.getBytesWrittenForLastEntry(), streamCompressor.getBytesRead()));
-    }
-
-    /**
-     * Write the contents of this scatter stream to a target archive.
-     *
-     * @param target The archive to receive the contents of this {@link ScatterZipOutputStream}.
-     * @throws IOException If writing fails
-     * @see #zipEntryWriter()
-     */
-    public void writeTo(final ZipArchiveOutputStream target) throws IOException {
-        backingStore.closeForWriting();
-        try (final InputStream data = backingStore.getInputStream()) {
-            for (final CompressedEntry compressedEntry : items) {
-                try (final BoundedInputStream rawStream = new BoundedInputStream(data,
-                        compressedEntry.compressedSize)) {
-                    target.addRawArchiveEntry(compressedEntry.transferToArchiveEntry(), rawStream);
-                }
-            }
-        }
-    }
-
     public static class ZipEntryWriter implements Closeable {
         private final Iterator<CompressedEntry> itemsIterator;
         private final InputStream itemsIteratorData;
@@ -149,15 +105,82 @@ public class ScatterZipOutputStream implements Closeable {
     }
 
     /**
-     * Get a zip entry writer for this scatter stream.
-     * @throws IOException If getting scatter stream input stream
-     * @return the ZipEntryWriter created on first call of the method
+     * Creates a {@link ScatterZipOutputStream} with default compression level that is backed by a file
+     *
+     * @param file The file to offload compressed data into.
+     * @return A ScatterZipOutputStream that is ready for use.
+     * @throws FileNotFoundException if the file cannot be found
      */
-    public ZipEntryWriter zipEntryWriter() throws IOException {
-        if (zipEntryWriter == null) {
-            zipEntryWriter = new ZipEntryWriter(this);
+    public static ScatterZipOutputStream fileBased(final File file) throws FileNotFoundException {
+        return pathBased(file.toPath(), Deflater.DEFAULT_COMPRESSION);
+    }
+
+    /**
+     * Creates a {@link ScatterZipOutputStream} that is backed by a file
+     *
+     * @param file             The file to offload compressed data into.
+     * @param compressionLevel The compression level to use, @see #Deflater
+     * @return A  ScatterZipOutputStream that is ready for use.
+     * @throws FileNotFoundException if the file cannot be found
+     */
+    public static ScatterZipOutputStream fileBased(final File file, final int compressionLevel) throws FileNotFoundException {
+        return pathBased(file.toPath(), compressionLevel);
+    }
+
+    /**
+     * Creates a {@link ScatterZipOutputStream} with default compression level that is backed by a file
+     * @param path The path to offload compressed data into.
+     * @return A ScatterZipOutputStream that is ready for use.
+     * @throws FileNotFoundException if the path cannot be found
+     * @since 1.22
+     */
+    public static ScatterZipOutputStream pathBased(final Path path) throws FileNotFoundException {
+        return pathBased(path, Deflater.DEFAULT_COMPRESSION);
+    }
+
+    /**
+     * Creates a {@link ScatterZipOutputStream} that is backed by a file
+     * @param path The path to offload compressed data into.
+     * @param compressionLevel The compression level to use, @see #Deflater
+     * @return A ScatterZipOutputStream that is ready for use.
+     * @throws FileNotFoundException if the path cannot be found
+     * @since 1.22
+     */
+    public static ScatterZipOutputStream pathBased(final Path path, final int compressionLevel) throws FileNotFoundException {
+        final ScatterGatherBackingStore bs = new FileBasedScatterGatherBackingStore(path);
+        // lifecycle is bound to the ScatterZipOutputStream returned
+        final StreamCompressor sc = StreamCompressor.create(compressionLevel, bs); //NOSONAR
+        return new ScatterZipOutputStream(bs, sc);
+    }
+
+    private final Queue<CompressedEntry> items = new ConcurrentLinkedQueue<>();
+
+    private final ScatterGatherBackingStore backingStore;
+
+    private final StreamCompressor streamCompressor;
+
+    private final AtomicBoolean isClosed = new AtomicBoolean();
+
+    private ZipEntryWriter zipEntryWriter;
+
+    public ScatterZipOutputStream(final ScatterGatherBackingStore backingStore,
+                                  final StreamCompressor streamCompressor) {
+        this.backingStore = backingStore;
+        this.streamCompressor = streamCompressor;
+    }
+
+    /**
+     * Adds an archive entry to this scatter stream.
+     *
+     * @param zipArchiveEntryRequest The entry to write.
+     * @throws IOException    If writing fails
+     */
+    public void addArchiveEntry(final ZipArchiveEntryRequest zipArchiveEntryRequest) throws IOException {
+        try (final InputStream payloadStream = zipArchiveEntryRequest.getPayloadStream()) {
+            streamCompressor.deflate(payloadStream, zipArchiveEntryRequest.getMethod());
         }
-        return zipEntryWriter;
+        items.add(new CompressedEntry(zipArchiveEntryRequest, streamCompressor.getCrc32(),
+                                      streamCompressor.getBytesWrittenForLastEntry(), streamCompressor.getBytesRead()));
     }
 
     /**
@@ -180,51 +203,33 @@ public class ScatterZipOutputStream implements Closeable {
     }
 
     /**
-     * Create a {@link ScatterZipOutputStream} with default compression level that is backed by a file
+     * Writes the contents of this scatter stream to a target archive.
      *
-     * @param file The file to offload compressed data into.
-     * @return A ScatterZipOutputStream that is ready for use.
-     * @throws FileNotFoundException if the file cannot be found
+     * @param target The archive to receive the contents of this {@link ScatterZipOutputStream}.
+     * @throws IOException If writing fails
+     * @see #zipEntryWriter()
      */
-    public static ScatterZipOutputStream fileBased(final File file) throws FileNotFoundException {
-        return pathBased(file.toPath(), Deflater.DEFAULT_COMPRESSION);
+    public void writeTo(final ZipArchiveOutputStream target) throws IOException {
+        backingStore.closeForWriting();
+        try (final InputStream data = backingStore.getInputStream()) {
+            for (final CompressedEntry compressedEntry : items) {
+                try (final BoundedInputStream rawStream = new BoundedInputStream(data,
+                        compressedEntry.compressedSize)) {
+                    target.addRawArchiveEntry(compressedEntry.transferToArchiveEntry(), rawStream);
+                }
+            }
+        }
     }
 
     /**
-     * Create a {@link ScatterZipOutputStream} with default compression level that is backed by a file
-     * @param path The path to offload compressed data into.
-     * @return A ScatterZipOutputStream that is ready for use.
-     * @throws FileNotFoundException if the path cannot be found
-     * @since 1.22
+     * Gets a ZIP entry writer for this scatter stream.
+     * @throws IOException If getting scatter stream input stream
+     * @return the ZipEntryWriter created on first call of the method
      */
-    public static ScatterZipOutputStream pathBased(final Path path) throws FileNotFoundException {
-        return pathBased(path, Deflater.DEFAULT_COMPRESSION);
-    }
-
-    /**
-     * Create a {@link ScatterZipOutputStream} that is backed by a file
-     *
-     * @param file             The file to offload compressed data into.
-     * @param compressionLevel The compression level to use, @see #Deflater
-     * @return A  ScatterZipOutputStream that is ready for use.
-     * @throws FileNotFoundException if the file cannot be found
-     */
-    public static ScatterZipOutputStream fileBased(final File file, final int compressionLevel) throws FileNotFoundException {
-        return pathBased(file.toPath(), compressionLevel);
-    }
-
-    /**
-     * Create a {@link ScatterZipOutputStream} that is backed by a file
-     * @param path The path to offload compressed data into.
-     * @param compressionLevel The compression level to use, @see #Deflater
-     * @return A ScatterZipOutputStream that is ready for use.
-     * @throws FileNotFoundException if the path cannot be found
-     * @since 1.22
-     */
-    public static ScatterZipOutputStream pathBased(final Path path, final int compressionLevel) throws FileNotFoundException {
-        final ScatterGatherBackingStore bs = new FileBasedScatterGatherBackingStore(path);
-        // lifecycle is bound to the ScatterZipOutputStream returned
-        final StreamCompressor sc = StreamCompressor.create(compressionLevel, bs); //NOSONAR
-        return new ScatterZipOutputStream(bs, sc);
+    public ZipEntryWriter zipEntryWriter() throws IOException {
+        if (zipEntryWriter == null) {
+            zipEntryWriter = new ZipEntryWriter(this);
+        }
+        return zipEntryWriter;
     }
 }
