@@ -29,7 +29,7 @@ import org.apache.commons.compress.compressors.lzw.LZWInputStream;
  * @NotThreadSafe
  * @since 1.7
  */
-class UnshrinkingInputStream extends LZWInputStream {
+final class UnshrinkingInputStream extends LZWInputStream {
     private static final int MAX_CODE_SIZE = 13;
     private static final int MAX_TABLE_SIZE = 1 << MAX_CODE_SIZE;
     private final boolean[] isUsed;
@@ -44,7 +44,7 @@ class UnshrinkingInputStream extends LZWInputStream {
         setClearCode(DEFAULT_CODE_SIZE);
         initializeTables(MAX_CODE_SIZE);
         isUsed = new boolean[getPrefixesLength()];
-        for (int i = 0; i < (1 << 8); i++) {
+        for (int i = 0; i < 1 << 8; i++) {
             isUsed[i] = true;
         }
         setTableSize(getClearCode() + 1);
@@ -53,7 +53,7 @@ class UnshrinkingInputStream extends LZWInputStream {
     @Override
     protected int addEntry(final int previousCode, final byte character) throws IOException {
         int tableSize = getTableSize();
-        while ((tableSize < MAX_TABLE_SIZE) && isUsed[tableSize]) {
+        while (tableSize < MAX_TABLE_SIZE && isUsed[tableSize]) {
             tableSize++;
         }
         setTableSize(tableSize);
@@ -64,21 +64,6 @@ class UnshrinkingInputStream extends LZWInputStream {
         return idx;
     }
 
-    private void partialClear() {
-        final boolean[] isParent = new boolean[MAX_TABLE_SIZE];
-        for (int i = 0; i < isUsed.length; i++) {
-            if (isUsed[i] && getPrefix(i) != UNUSED_PREFIX) {
-                isParent[getPrefix(i)] = true;
-            }
-        }
-        for (int i = getClearCode() + 1; i < isParent.length; i++) {
-            if (!isParent[i]) {
-                isUsed[i] = false;
-                setPrefix(i, UNUSED_PREFIX);
-            }
-        }
-    }
-
     @Override
     protected int decompressNextSymbol() throws IOException {
         //
@@ -123,4 +108,19 @@ class UnshrinkingInputStream extends LZWInputStream {
         }
         return 0;
     }
+
+    private void partialClear() {
+        final boolean[] isParent = new boolean[MAX_TABLE_SIZE];
+        for (int i = 0; i < isUsed.length; i++) {
+            if (isUsed[i] && getPrefix(i) != UNUSED_PREFIX) {
+                isParent[getPrefix(i)] = true;
+            }
+        }
+        for (int i = getClearCode() + 1; i < isParent.length; i++) {
+            if (!isParent[i]) {
+                isUsed[i] = false;
+                setPrefix(i, UNUSED_PREFIX);
+            }
+        }
+    }
 }
