@@ -13,18 +13,17 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 package org.apache.commons.compress.archivers.zip;
 
+import static org.apache.commons.compress.archivers.zip.ZipConstants.BYTE_MASK;
+
 import java.io.Serializable;
 import java.math.BigInteger;
 
-import static org.apache.commons.compress.archivers.zip.ZipConstants.BYTE_MASK;
-
 /**
  * Utility class that represents an eight byte integer with conversion
- * rules for the big endian byte order of ZIP files.
+ * rules for the little endian byte order of ZIP files.
  * @Immutable
  *
  * @since 1.2
@@ -63,85 +62,17 @@ public final class ZipEightByteInteger implements Serializable {
     private static final int LEFTMOST_BIT_SHIFT = 63;
     private static final byte LEFTMOST_BIT = (byte) 0x80;
 
-    private final BigInteger value;
-
     public static final ZipEightByteInteger ZERO = new ZipEightByteInteger(0);
 
     /**
-     * Create instance from a number.
-     * @param value the long to store as a ZipEightByteInteger
-     */
-    public ZipEightByteInteger(long value) {
-        this(BigInteger.valueOf(value));
-    }
-
-    /**
-     * Create instance from a number.
-     * @param value the BigInteger to store as a ZipEightByteInteger
-     */
-    public ZipEightByteInteger(BigInteger value) {
-        this.value = value;
-    }
-
-    /**
-     * Create instance from bytes.
-     * @param bytes the bytes to store as a ZipEightByteInteger
-     */
-    public ZipEightByteInteger (byte[] bytes) {
-        this(bytes, 0);
-    }
-
-    /**
-     * Create instance from the eight bytes starting at offset.
-     * @param bytes the bytes to store as a ZipEightByteInteger
-     * @param offset the offset to start
-     */
-    public ZipEightByteInteger (byte[] bytes, int offset) {
-        value = ZipEightByteInteger.getValue(bytes, offset);
-    }
-
-    /**
-     * Get value as eight bytes in big endian byte order.
-     * @return value as eight bytes in big endian order
-     */
-    public byte[] getBytes() {
-        return ZipEightByteInteger.getBytes(value);
-    }
-
-    /**
-     * Get value as Java long.
-     * @return value as a long
-     */
-    public long getLongValue() {
-        return value.longValue();
-    }
-
-    /**
-     * Get value as Java long.
-     * @return value as a long
-     */
-    public BigInteger getValue() {
-        return value;
-    }
-
-    /**
-     * Get value as eight bytes in big endian byte order.
+     * Gets value as eight bytes in big endian byte order.
      * @param value the value to convert
      * @return value as eight bytes in big endian byte order
      */
-    public static byte[] getBytes(long value) {
-        return getBytes(BigInteger.valueOf(value));
-    }
-
-    /**
-     * Get value as eight bytes in big endian byte order.
-     * @param value the value to convert
-     * @return value as eight bytes in big endian byte order
-     */
-    public static byte[] getBytes(BigInteger value) {
-        byte[] result = new byte[8];
-        long val = value.longValue();
-        result[0] = (byte) ((val & BYTE_MASK));
+    public static byte[] getBytes(final BigInteger value) {
+        final byte[] result = new byte[8];
+        final long val = value.longValue();
+        result[0] = (byte) (val & BYTE_MASK);
         result[BYTE_1] = (byte) ((val & BYTE_1_MASK) >> BYTE_1_SHIFT);
         result[BYTE_2] = (byte) ((val & BYTE_2_MASK) >> BYTE_2_SHIFT);
         result[BYTE_3] = (byte) ((val & BYTE_3_MASK) >> BYTE_3_SHIFT);
@@ -155,6 +86,24 @@ public final class ZipEightByteInteger implements Serializable {
         return result;
     }
 
+    /**
+     * Gets value as eight bytes in big endian byte order.
+     * @param value the value to convert
+     * @return value as eight bytes in big endian byte order
+     */
+    public static byte[] getBytes(final long value) {
+        return getBytes(BigInteger.valueOf(value));
+    }
+
+    /**
+     * Helper method to get the value as a Java long from an eight-byte array
+     * @param bytes the array of bytes
+     * @return the corresponding Java long value
+     */
+    public static long getLongValue(final byte[] bytes) {
+        return getLongValue(bytes, 0);
+    }
+
     /**
      * Helper method to get the value as a Java long from eight bytes
      * starting at given array offset
@@ -162,10 +111,19 @@ public final class ZipEightByteInteger implements Serializable {
      * @param offset the offset to start
      * @return the corresponding Java long value
      */
-    public static long getLongValue(byte[] bytes, int offset) {
+    public static long getLongValue(final byte[] bytes, final int offset) {
         return getValue(bytes, offset).longValue();
     }
 
+    /**
+     * Helper method to get the value as a Java long from an eight-byte array
+     * @param bytes the array of bytes
+     * @return the corresponding Java BigInteger value
+     */
+    public static BigInteger getValue(final byte[] bytes) {
+        return getValue(bytes, 0);
+    }
+
     /**
      * Helper method to get the value as a Java BigInteger from eight
      * bytes starting at given array offset
@@ -173,36 +131,53 @@ public final class ZipEightByteInteger implements Serializable {
      * @param offset the offset to start
      * @return the corresponding Java BigInteger value
      */
-    public static BigInteger getValue(byte[] bytes, int offset) {
-        long value = ((long) bytes[offset + BYTE_7] << BYTE_7_SHIFT) & BYTE_7_MASK;
-        value += ((long) bytes[offset + BYTE_6] << BYTE_6_SHIFT) & BYTE_6_MASK;
-        value += ((long) bytes[offset + BYTE_5] << BYTE_5_SHIFT) & BYTE_5_MASK;
-        value += ((long) bytes[offset + BYTE_4] << BYTE_4_SHIFT) & BYTE_4_MASK;
-        value += ((long) bytes[offset + BYTE_3] << BYTE_3_SHIFT) & BYTE_3_MASK;
-        value += ((long) bytes[offset + BYTE_2] << BYTE_2_SHIFT) & BYTE_2_MASK;
-        value += ((long) bytes[offset + BYTE_1] << BYTE_1_SHIFT) & BYTE_1_MASK;
-        value += ((long) bytes[offset] & BYTE_MASK);
-        BigInteger val = BigInteger.valueOf(value);
+    public static BigInteger getValue(final byte[] bytes, final int offset) {
+        long value = (long) bytes[offset + BYTE_7] << BYTE_7_SHIFT & BYTE_7_MASK;
+        value += (long) bytes[offset + BYTE_6] << BYTE_6_SHIFT & BYTE_6_MASK;
+        value += (long) bytes[offset + BYTE_5] << BYTE_5_SHIFT & BYTE_5_MASK;
+        value += (long) bytes[offset + BYTE_4] << BYTE_4_SHIFT & BYTE_4_MASK;
+        value += (long) bytes[offset + BYTE_3] << BYTE_3_SHIFT & BYTE_3_MASK;
+        value += (long) bytes[offset + BYTE_2] << BYTE_2_SHIFT & BYTE_2_MASK;
+        value += (long) bytes[offset + BYTE_1] << BYTE_1_SHIFT & BYTE_1_MASK;
+        value += (long) bytes[offset] & BYTE_MASK;
+        final BigInteger val = BigInteger.valueOf(value);
         return (bytes[offset + BYTE_7] & LEFTMOST_BIT) == LEFTMOST_BIT
             ? val.setBit(LEFTMOST_BIT_SHIFT) : val;
     }
 
+    private final BigInteger value;
+
     /**
-     * Helper method to get the value as a Java long from an eight-byte array
-     * @param bytes the array of bytes
-     * @return the corresponding Java long value
+     * Create instance from a number.
+     * @param value the BigInteger to store as a ZipEightByteInteger
      */
-    public static long getLongValue(byte[] bytes) {
-        return getLongValue(bytes, 0);
+    public ZipEightByteInteger(final BigInteger value) {
+        this.value = value;
     }
 
     /**
-     * Helper method to get the value as a Java long from an eight-byte array
-     * @param bytes the array of bytes
-     * @return the corresponding Java BigInteger value
+     * Create instance from bytes.
+     * @param bytes the bytes to store as a ZipEightByteInteger
      */
-    public static BigInteger getValue(byte[] bytes) {
-        return getValue(bytes, 0);
+    public ZipEightByteInteger (final byte[] bytes) {
+        this(bytes, 0);
+    }
+
+    /**
+     * Create instance from the eight bytes starting at offset.
+     * @param bytes the bytes to store as a ZipEightByteInteger
+     * @param offset the offset to start
+     */
+    public ZipEightByteInteger (final byte[] bytes, final int offset) {
+        value = ZipEightByteInteger.getValue(bytes, offset);
+    }
+
+    /**
+     * Create instance from a number.
+     * @param value the long to store as a ZipEightByteInteger
+     */
+    public ZipEightByteInteger(final long value) {
+        this(BigInteger.valueOf(value));
     }
 
     /**
@@ -211,16 +186,40 @@ public final class ZipEightByteInteger implements Serializable {
      * @return true if the objects are equal
      */
     @Override
-    public boolean equals(Object o) {
-        if (o == null || !(o instanceof ZipEightByteInteger)) {
+    public boolean equals(final Object o) {
+        if (!(o instanceof ZipEightByteInteger)) {
             return false;
         }
         return value.equals(((ZipEightByteInteger) o).getValue());
     }
 
+    /**
+     * Gets value as eight bytes in big endian byte order.
+     * @return value as eight bytes in big endian order
+     */
+    public byte[] getBytes() {
+        return ZipEightByteInteger.getBytes(value);
+    }
+
+    /**
+     * Gets value as Java long.
+     * @return value as a long
+     */
+    public long getLongValue() {
+        return value.longValue();
+    }
+
+    /**
+     * Gets value as Java BigInteger.
+     * @return value as a BigInteger
+     */
+    public BigInteger getValue() {
+        return value;
+    }
+
     /**
      * Override to make two instances with same value equal.
-     * @return the hashCode of the value stored in the ZipEightByteInteger
+     * @return the hash code of the value stored in the ZipEightByteInteger
      */
     @Override
     public int hashCode() {
