@@ -13,7 +13,6 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 package org.apache.commons.compress.archivers.zip;
 
@@ -35,53 +34,8 @@ public final class ZipShort implements Cloneable, Serializable {
 
     private static final long serialVersionUID = 1L;
 
-    private final int value;
-
     /**
-     * Create instance from a number.
-     * @param value the int to store as a ZipShort
-     */
-    public ZipShort (final int value) {
-        this.value = value;
-    }
-
-    /**
-     * Create instance from bytes.
-     * @param bytes the bytes to store as a ZipShort
-     */
-    public ZipShort (final byte[] bytes) {
-        this(bytes, 0);
-    }
-
-    /**
-     * Create instance from the two bytes starting at offset.
-     * @param bytes the bytes to store as a ZipShort
-     * @param offset the offset to start
-     */
-    public ZipShort (final byte[] bytes, final int offset) {
-        value = ZipShort.getValue(bytes, offset);
-    }
-
-    /**
-     * Get value as two bytes in big endian byte order.
-     * @return the value as a a two byte array in big endian byte order
-     */
-    public byte[] getBytes() {
-        final byte[] result = new byte[2];
-        ByteUtils.toLittleEndian(result, value, 0, 2);
-        return result;
-    }
-
-    /**
-     * Get value as Java int.
-     * @return value as a Java int
-     */
-    public int getValue() {
-        return value;
-    }
-
-    /**
-     * Get value as two bytes in big endian byte order.
+     * Gets value as two bytes in big endian byte order.
      * @param value the Java int to convert to bytes
      * @return the converted int as a byte array in big endian byte order
      */
@@ -91,6 +45,25 @@ public final class ZipShort implements Cloneable, Serializable {
         return result;
     }
 
+    /**
+     * Helper method to get the value as a java int from a two-byte array
+     * @param bytes the array of bytes
+     * @return the corresponding java int value
+     */
+    public static int getValue(final byte[] bytes) {
+        return getValue(bytes, 0);
+    }
+
+    /**
+     * Helper method to get the value as a java int from two bytes starting at given array offset
+     * @param bytes the array of bytes
+     * @param offset the offset to start
+     * @return the corresponding java int value
+     */
+    public static int getValue(final byte[] bytes, final int offset) {
+        return (int) ByteUtils.fromLittleEndian(bytes, offset, 2);
+    }
+
     /**
      * put the value as two bytes in big endian byte order.
      * @param value the Java int to convert to bytes
@@ -103,23 +76,41 @@ public final class ZipShort implements Cloneable, Serializable {
         ByteUtils.toLittleEndian(buf, value, offset, 2);
     }
 
+    private final int value;
+
     /**
-     * Helper method to get the value as a java int from two bytes starting at given array offset
-     * @param bytes the array of bytes
-     * @param offset the offset to start
-     * @return the corresponding java int value
+     * Create instance from bytes.
+     * @param bytes the bytes to store as a ZipShort
      */
-    public static int getValue(final byte[] bytes, final int offset) {
-        return (int) ByteUtils.fromLittleEndian(bytes, offset, 2);
+    public ZipShort(final byte[] bytes) {
+        this(bytes, 0);
     }
 
     /**
-     * Helper method to get the value as a java int from a two-byte array
-     * @param bytes the array of bytes
-     * @return the corresponding java int value
+     * Create instance from the two bytes starting at offset.
+     * @param bytes the bytes to store as a ZipShort
+     * @param offset the offset to start
      */
-    public static int getValue(final byte[] bytes) {
-        return getValue(bytes, 0);
+    public ZipShort(final byte[] bytes, final int offset) {
+        value = ZipShort.getValue(bytes, offset);
+    }
+
+    /**
+     * Create instance from a number.
+     * @param value the int to store as a ZipShort
+     */
+    public ZipShort(final int value) {
+        this.value = value;
+    }
+
+    @Override
+    public Object clone() {
+        try {
+            return super.clone();
+        } catch (final CloneNotSupportedException cnfe) {
+            // impossible
+            throw new UnsupportedOperationException(cnfe); //NOSONAR
+        }
     }
 
     /**
@@ -135,6 +126,24 @@ public final class ZipShort implements Cloneable, Serializable {
         return value == ((ZipShort) o).getValue();
     }
 
+    /**
+     * Gets value as two bytes in big endian byte order.
+     * @return the value as a two byte array in big endian byte order
+     */
+    public byte[] getBytes() {
+        final byte[] result = new byte[2];
+        ByteUtils.toLittleEndian(result, value, 0, 2);
+        return result;
+    }
+
+    /**
+     * Gets value as Java int.
+     * @return value as a Java int
+     */
+    public int getValue() {
+        return value;
+    }
+
     /**
      * Override to make two instances with same value equal.
      * @return the value stored in the ZipShort
@@ -144,16 +153,6 @@ public final class ZipShort implements Cloneable, Serializable {
         return value;
     }
 
-    @Override
-    public Object clone() {
-        try {
-            return super.clone();
-        } catch (final CloneNotSupportedException cnfe) {
-            // impossible
-            throw new IllegalStateException(cnfe); //NOSONAR
-        }
-    }
-
     @Override
     public String toString() {
         return "ZipShort value: " + value;
