@@ -23,10 +23,9 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
-import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.Locale;
+import java.util.ServiceLoader;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.TreeMap;
@@ -60,8 +59,6 @@ import org.apache.commons.compress.compressors.zstandard.ZstdCompressorInputStre
 import org.apache.commons.compress.compressors.zstandard.ZstdCompressorOutputStream;
 import org.apache.commons.compress.compressors.zstandard.ZstdUtils;
 import org.apache.commons.compress.utils.IOUtils;
-import org.apache.commons.compress.utils.Lists;
-import org.apache.commons.compress.utils.ServiceLoaderIterator;
 import org.apache.commons.compress.utils.Sets;
 
 /**
@@ -99,8 +96,6 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
 
     private static final CompressorStreamFactory SINGLETON = new CompressorStreamFactory();
 
-
-
     /**
      * Constant (value {@value}) used to identify the BROTLI compression
      * algorithm.
@@ -213,8 +208,102 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
     private static final String YOU_NEED_XZ_JAVA = youNeed("XZ for Java", "https://tukaani.org/xz/java.html");
     private static final String YOU_NEED_ZSTD_JNI = youNeed("Zstd JNI", "https://github.com/luben/zstd-jni");
 
-    private static String youNeed(String name, String url) {
-        return " In addition to Apache Commons Compress you need the " + name + " library - see " + url;
+    private static final Set<String> ALL_NAMES = Sets.newHashSet(BZIP2, GZIP, PACK200, SNAPPY_FRAMED, Z, DEFLATE, XZ, LZMA, LZ4_FRAMED, ZSTANDARD);
+
+    private static Iterable<CompressorStreamProvider> archiveStreamProviderIterable() {
+        return ServiceLoader.load(CompressorStreamProvider.class, ClassLoader.getSystemClassLoader());
+    }
+
+    /**
+     * Detects the type of compressor stream.
+     *
+     * @param inputStream input stream
+     * @return type of compressor stream detected
+     * @throws CompressorException if no compressor stream type was detected
+     *                             or if something else went wrong
+     * @throws IllegalArgumentException if stream is null or does not support mark
+     *
+     * @since 1.14
+     */
+    public static String detect(final InputStream inputStream) throws CompressorException {
+        return detect(inputStream, ALL_NAMES);
+    }
+
+    /**
+     * Detects the type of compressor stream while limiting the type to the provided set of compressor names.
+     *
+     * @param inputStream input stream
+     * @param compressorNames compressor names to limit autodetection
+     * @return type of compressor stream detected
+     * @throws CompressorException if no compressor stream type was detected
+     *                             or if something else went wrong
+     * @throws IllegalArgumentException if stream is null or does not support mark
+     */
+    static String detect(final InputStream inputStream, final Set<String> compressorNames) throws CompressorException {
+        if (inputStream == null) {
+            throw new IllegalArgumentException("Stream must not be null.");
+        }
+
+        if (compressorNames == null || compressorNames.isEmpty()) {
+            throw new IllegalArgumentException("Compressor names cannot be null or empty");
+        }
+
+        if (!inputStream.markSupported()) {
+            throw new IllegalArgumentException("Mark is not supported.");
+        }
+
+        final byte[] signature = new byte[12];
+        inputStream.mark(signature.length);
+        int signatureLength = -1;
+        try {
+            signatureLength = IOUtils.readFully(inputStream, signature);
+            inputStream.reset();
+        } catch (final IOException e) {
+            throw new CompressorException("IOException while reading signature.", e);
+        }
+
+        if (compressorNames.contains(BZIP2) && BZip2CompressorInputStream.matches(signature, signatureLength)) {
+            return BZIP2;
+        }
+
+        if (compressorNames.contains(GZIP) && GzipCompressorInputStream.matches(signature, signatureLength)) {
+            return GZIP;
+        }
+
+        if (compressorNames.contains(PACK200) && Pack200CompressorInputStream.matches(signature, signatureLength)) {
+            return PACK200;
+        }
+
+        if (compressorNames.contains(SNAPPY_FRAMED) &&
+                FramedSnappyCompressorInputStream.matches(signature, signatureLength)) {
+            return SNAPPY_FRAMED;
+        }
+
+        if (compressorNames.contains(Z) && ZCompressorInputStream.matches(signature, signatureLength)) {
+            return Z;
+        }
+
+        if (compressorNames.contains(DEFLATE) && DeflateCompressorInputStream.matches(signature, signatureLength)) {
+            return DEFLATE;
+        }
+
+        if (compressorNames.contains(XZ) && XZUtils.matches(signature, signatureLength)) {
+            return XZ;
+        }
+
+        if (compressorNames.contains(LZMA) && LZMAUtils.matches(signature, signatureLength)) {
+            return LZMA;
+        }
+
+        if (compressorNames.contains(LZ4_FRAMED) && FramedLZ4CompressorInputStream.matches(signature, signatureLength)) {
+            return LZ4_FRAMED;
+        }
+
+        if (compressorNames.contains(ZSTANDARD) && ZstdUtils.matches(signature, signatureLength)) {
+            return ZSTANDARD;
+        }
+
+        throw new CompressorException("No Compressor found for the stream signature.");
     }
 
     /**
@@ -245,16 +334,11 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
      * @since 1.13
      */
     public static SortedMap<String, CompressorStreamProvider> findAvailableCompressorInputStreamProviders() {
-        return AccessController.doPrivileged(new PrivilegedAction<SortedMap<String, CompressorStreamProvider>>() {
-            @Override
-            public SortedMap<String, CompressorStreamProvider> run() {
-                final TreeMap<String, CompressorStreamProvider> map = new TreeMap<>();
-                putAll(SINGLETON.getInputStreamCompressorNames(), SINGLETON, map);
-                for (final CompressorStreamProvider provider : findCompressorStreamProviders()) {
-                    putAll(provider.getInputStreamCompressorNames(), provider, map);
-                }
-                return map;
-            }
+        return AccessController.doPrivileged((PrivilegedAction<SortedMap<String, CompressorStreamProvider>>) () -> {
+            final TreeMap<String, CompressorStreamProvider> map = new TreeMap<>();
+            putAll(SINGLETON.getInputStreamCompressorNames(), SINGLETON, map);
+            archiveStreamProviderIterable().forEach(provider -> putAll(provider.getInputStreamCompressorNames(), provider, map));
+            return map;
         });
     }
 
@@ -286,22 +370,13 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
      * @since 1.13
      */
     public static SortedMap<String, CompressorStreamProvider> findAvailableCompressorOutputStreamProviders() {
-        return AccessController.doPrivileged(new PrivilegedAction<SortedMap<String, CompressorStreamProvider>>() {
-            @Override
-            public SortedMap<String, CompressorStreamProvider> run() {
-                final TreeMap<String, CompressorStreamProvider> map = new TreeMap<>();
-                putAll(SINGLETON.getOutputStreamCompressorNames(), SINGLETON, map);
-                for (final CompressorStreamProvider provider : findCompressorStreamProviders()) {
-                    putAll(provider.getOutputStreamCompressorNames(), provider, map);
-                }
-                return map;
-            }
-
+        return AccessController.doPrivileged((PrivilegedAction<SortedMap<String, CompressorStreamProvider>>) () -> {
+            final TreeMap<String, CompressorStreamProvider> map = new TreeMap<>();
+            putAll(SINGLETON.getOutputStreamCompressorNames(), SINGLETON, map);
+            archiveStreamProviderIterable().forEach(provider -> putAll(provider.getOutputStreamCompressorNames(), provider, map));
+            return map;
         });
     }
-    private static ArrayList<CompressorStreamProvider> findCompressorStreamProviders() {
-        return Lists.newArrayList(serviceLoaderIterator());
-    }
 
     public static String getBrotli() {
         return BROTLI;
@@ -327,6 +402,14 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
         return GZIP;
     }
 
+    public static String getLZ4Block() {
+        return LZ4_BLOCK;
+    }
+
+    public static String getLZ4Framed() {
+        return LZ4_FRAMED;
+    }
+
     public static String getLzma() {
         return LZMA;
     }
@@ -355,33 +438,22 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
         return Z;
     }
 
-    public static String getLZ4Framed() {
-        return LZ4_FRAMED;
-    }
-
-    public static String getLZ4Block() {
-        return LZ4_BLOCK;
-    }
-
     public static String getZstandard() {
         return ZSTANDARD;
     }
 
-    static void putAll(final Set<String> names, final CompressorStreamProvider provider,
-            final TreeMap<String, CompressorStreamProvider> map) {
-        for (final String name : names) {
-            map.put(toKey(name), provider);
-        }
-    }
-
-    private static Iterator<CompressorStreamProvider> serviceLoaderIterator() {
-        return new ServiceLoaderIterator<>(CompressorStreamProvider.class);
+    static void putAll(final Set<String> names, final CompressorStreamProvider provider, final TreeMap<String, CompressorStreamProvider> map) {
+        names.forEach(name -> map.put(toKey(name), provider));
     }
 
     private static String toKey(final String name) {
         return name.toUpperCase(Locale.ROOT);
     }
 
+    private static String youNeed(final String name, final String url) {
+        return " In addition to Apache Commons Compress you need the " + name + " library - see " + url;
+    }
+
     /**
      * If true, decompress until the end of the input. If false, stop after the
      * first stream and leave the input position to point to the next byte after
@@ -402,11 +474,12 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
      * first stream and leave the input position to point to the next byte after
      * the stream
      */
-    private volatile boolean decompressConcatenated = false;
+    private volatile boolean decompressConcatenated;
 
     private final int memoryLimitInKb;
+
     /**
-     * Create an instance with the decompress Concatenated option set to false.
+     * Constructs an instance with the decompress Concatenated option set to false.
      */
     public CompressorStreamFactory() {
         this.decompressUntilEOF = null;
@@ -414,14 +487,27 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
     }
 
     /**
-     * Create an instance with the provided decompress Concatenated option.
+     * Constructs an instance with the provided decompress Concatenated option.
      *
      * @param decompressUntilEOF
      *            if true, decompress until the end of the input; if false, stop
      *            after the first stream and leave the input position to point
      *            to the next byte after the stream. This setting applies to the
-     *            gzip, bzip2 and xz formats only.
+     *            gzip, bzip2 and XZ formats only.
+     * @since 1.10
+     */
+    public CompressorStreamFactory(final boolean decompressUntilEOF) {
+        this(decompressUntilEOF, -1);
+    }
+
+    /**
+     * Constructs an instance with the provided decompress Concatenated option.
      *
+     * @param decompressUntilEOF
+     *            if true, decompress until the end of the input; if false, stop
+     *            after the first stream and leave the input position to point
+     *            to the next byte after the stream. This setting applies to the
+     *            gzip, bzip2 and XZ formats only.
      * @param memoryLimitInKb
      *            Some streams require allocation of potentially significant
      *            byte arrays/tables, and they can offer checks to prevent OOMs
@@ -437,95 +523,8 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
         this.memoryLimitInKb = memoryLimitInKb;
     }
 
-
     /**
-     * Create an instance with the provided decompress Concatenated option.
-     *
-     * @param decompressUntilEOF
-     *            if true, decompress until the end of the input; if false, stop
-     *            after the first stream and leave the input position to point
-     *            to the next byte after the stream. This setting applies to the
-     *            gzip, bzip2 and xz formats only.
-     * @since 1.10
-     */
-    public CompressorStreamFactory(final boolean decompressUntilEOF) {
-        this(decompressUntilEOF, -1);
-    }
-
-    /**
-     * Try to detect the type of compressor stream.
-     *
-     * @param inputStream input stream
-     * @return type of compressor stream detected
-     * @throws CompressorException if no compressor stream type was detected
-     *                             or if something else went wrong
-     * @throws IllegalArgumentException if stream is null or does not support mark
-     *
-     * @since 1.14
-     */
-    public static String detect(final InputStream inputStream) throws CompressorException {
-        if (inputStream == null) {
-            throw new IllegalArgumentException("Stream must not be null.");
-        }
-
-        if (!inputStream.markSupported()) {
-            throw new IllegalArgumentException("Mark is not supported.");
-        }
-
-        final byte[] signature = new byte[12];
-        inputStream.mark(signature.length);
-        int signatureLength = -1;
-        try {
-            signatureLength = IOUtils.readFully(inputStream, signature);
-            inputStream.reset();
-        } catch (IOException e) {
-            throw new CompressorException("IOException while reading signature.", e);
-        }
-
-        if (BZip2CompressorInputStream.matches(signature, signatureLength)) {
-            return BZIP2;
-        }
-
-        if (GzipCompressorInputStream.matches(signature, signatureLength)) {
-            return GZIP;
-        }
-
-        if (Pack200CompressorInputStream.matches(signature, signatureLength)) {
-            return PACK200;
-        }
-
-        if (FramedSnappyCompressorInputStream.matches(signature, signatureLength)) {
-            return SNAPPY_FRAMED;
-        }
-
-        if (ZCompressorInputStream.matches(signature, signatureLength)) {
-            return Z;
-        }
-
-        if (DeflateCompressorInputStream.matches(signature, signatureLength)) {
-            return DEFLATE;
-        }
-
-        if (XZUtils.matches(signature, signatureLength)) {
-            return XZ;
-        }
-
-        if (LZMAUtils.matches(signature, signatureLength)) {
-            return LZMA;
-        }
-
-        if (FramedLZ4CompressorInputStream.matches(signature, signatureLength)) {
-            return LZ4_FRAMED;
-        }
-
-        if (ZstdUtils.matches(signature, signatureLength)) {
-            return ZSTANDARD;
-        }
-
-        throw new CompressorException("No Compressor found for the stream signature.");
-    }
-    /**
-     * Create an compressor input stream from an input stream, autodetecting the
+     * Creates a compressor input stream from an input stream, auto-detecting the
      * compressor type from the first few bytes of the stream. The InputStream
      * must support marks, like BufferedInputStream.
      *
@@ -542,6 +541,27 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
         return createCompressorInputStream(detect(in), in);
     }
 
+    /**
+     * Creates a compressor input stream from an input stream, auto-detecting the
+     * compressor type from the first few bytes of the stream while limiting the detected type
+     * to the provided set of compressor names. The InputStream must support marks, like BufferedInputStream.
+     *
+     * @param in
+     *            the input stream
+     * @param compressorNames
+     *            compressor names to limit autodetection
+     * @return the compressor input stream
+     * @throws CompressorException
+     *             if the autodetected compressor is not in the provided set of compressor names
+     * @throws IllegalArgumentException
+     *             if the stream is null or does not support mark
+     * @since 1.25.0
+     */
+    public CompressorInputStream createCompressorInputStream(final InputStream in, final Set<String> compressorNames)
+            throws CompressorException {
+        return createCompressorInputStream(detect(in, compressorNames), in);
+    }
+
     /**
      * Creates a compressor input stream from a compressor name and an input
      * stream.
@@ -657,7 +677,7 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
     }
 
     /**
-     * Creates an compressor output stream from an compressor name and an output
+     * Creates a compressor output stream from a compressor name and an output
      * stream.
      *
      * @param name
@@ -747,7 +767,7 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
         return compressorOutputStreamProviders;
     }
 
-    // For Unit tests
+    /** For tests. */
     boolean getDecompressConcatenated() {
         return decompressConcatenated;
     }
@@ -768,11 +788,11 @@ public class CompressorStreamFactory implements CompressorStreamProvider {
     }
 
     /**
-     * Whether to decompress the full input or only the first stream in formats
+     * Sets whether to decompress the full input or only the first stream in formats
      * supporting multiple concatenated input streams.
      *
      * <p>
-     * This setting applies to the gzip, bzip2 and xz formats only.
+     * This setting applies to the gzip, bzip2 and XZ formats only.
      * </p>
      *
      * @param decompressConcatenated
