@@ -45,19 +45,35 @@ public abstract class BZip2Utils {
         fileNameUtil = new FileNameUtil(uncompressSuffix, ".bz2");
     }
 
-    /** Private constructor to prevent instantiation of this utility class. */
-    private BZip2Utils() {
+    /**
+     * Maps the given file name to the name that the file should have after
+     * compression with bzip2. Currently this method simply appends the suffix
+     * ".bz2" to the file name based on the standard behavior of the "bzip2"
+     * program, but a future version may implement a more complex mapping if
+     * a new widely used naming pattern emerges.
+     *
+     * @param fileName name of a file
+     * @return name of the corresponding compressed file
+     * @deprecated Use {@link #getCompressedFileName(String)}.
+     */
+    @Deprecated
+    public static String getCompressedFilename(final String fileName) {
+        return fileNameUtil.getCompressedFileName(fileName);
     }
 
     /**
-     * Detects common bzip2 suffixes in the given file name.
+     * Maps the given file name to the name that the file should have after
+     * compression with bzip2. Currently this method simply appends the suffix
+     * ".bz2" to the file name based on the standard behavior of the "bzip2"
+     * program, but a future version may implement a more complex mapping if
+     * a new widely used naming pattern emerges.
      *
      * @param fileName name of a file
-     * @return {@code true} if the file name has a common bzip2 suffix,
-     *         {@code false} otherwise
+     * @return name of the corresponding compressed file
+     * @since 1.25.0
      */
-    public static boolean isCompressedFilename(final String fileName) {
-        return fileNameUtil.isCompressedFilename(fileName);
+    public static String getCompressedFileName(final String fileName) {
+        return fileNameUtil.getCompressedFileName(fileName);
     }
 
     /**
@@ -72,23 +88,58 @@ public abstract class BZip2Utils {
      *
      * @param fileName name of a file
      * @return name of the corresponding uncompressed file
+     * @deprecated Use {@link #getUncompressedFileName(String)}.
      */
+    @Deprecated
     public static String getUncompressedFilename(final String fileName) {
-        return fileNameUtil.getUncompressedFilename(fileName);
+        return fileNameUtil.getUncompressedFileName(fileName);
     }
 
     /**
-     * Maps the given file name to the name that the file should have after
-     * compression with bzip2. Currently this method simply appends the suffix
-     * ".bz2" to the file name based on the standard behavior of the "bzip2"
-     * program, but a future version may implement a more complex mapping if
-     * a new widely used naming pattern emerges.
+     * Maps the given name of a bzip2-compressed file to the name that the
+     * file should have after uncompression. Commonly used file type specific
+     * suffixes like ".tbz" or ".tbz2" are automatically detected and
+     * correctly mapped. For example the name "package.tbz2" is mapped to
+     * "package.tar". And any file names with the generic ".bz2" suffix
+     * (or any other generic bzip2 suffix) is mapped to a name without that
+     * suffix. If no bzip2 suffix is detected, then the file name is returned
+     * unmapped.
      *
      * @param fileName name of a file
-     * @return name of the corresponding compressed file
+     * @return name of the corresponding uncompressed file
+     * @since 1.25.0
      */
-    public static String getCompressedFilename(final String fileName) {
-        return fileNameUtil.getCompressedFilename(fileName);
+    public static String getUncompressedFileName(final String fileName) {
+        return fileNameUtil.getUncompressedFileName(fileName);
+    }
+
+    /**
+     * Detects common bzip2 suffixes in the given file name.
+     *
+     * @param fileName name of a file
+     * @return {@code true} if the file name has a common bzip2 suffix,
+     *         {@code false} otherwise
+     * @deprecated Use {@link #isCompressedFileName(String)}.
+     */
+    @Deprecated
+    public static boolean isCompressedFilename(final String fileName) {
+        return fileNameUtil.isCompressedFileName(fileName);
+    }
+
+    /**
+     * Detects common bzip2 suffixes in the given file name.
+     *
+     * @param fileName name of a file
+     * @return {@code true} if the file name has a common bzip2 suffix,
+     *         {@code false} otherwise
+     * @since 1.25.0
+     */
+    public static boolean isCompressedFileName(final String fileName) {
+        return fileNameUtil.isCompressedFileName(fileName);
+    }
+
+    /** Private constructor to prevent instantiation of this utility class. */
+    private BZip2Utils() {
     }
 
 }
