@@ -78,7 +78,7 @@ import java.util.BitSet;
  *
  * @NotThreadSafe
  */
-class BlockSort {
+final class BlockSort {
 
     /*
      * Some of the constructs used in the C code cannot be ported
@@ -123,81 +123,48 @@ class BlockSort {
     private static final int STACK_SIZE =
             Math.max(QSORT_STACK_SIZE, FALLBACK_QSORT_STACK_SIZE);
 
+    private static final int FALLBACK_QSORT_SMALL_THRESH = 10;
+    /*
+     * LBZ2: Knuth's increments seem to work better than Incerpi-Sedgewick here.
+     * Possibly because the number of elems to sort is usually small, typically
+     * &lt;= 20.
+     */
+    private static final int[] INCS = { 1, 4, 13, 40, 121, 364, 1093, 3280,
+                                        9841, 29524, 88573, 265720, 797161,
+                                        2391484 };
+    private static final int SMALL_THRESH = 20;
+
+    private static final int DEPTH_THRESH = 10;
+    private static final int WORK_FACTOR = 30;
+    private static final int SETMASK = 1 << 21;
+
+    private static final int CLEARMASK = ~SETMASK;
+    private static int med3(final int a, final int b, final int c) {
+        return a < b ? b < c ? b : a < c ? c : a : b > c ? b : a > c ? c
+                                                        : a;
+    }
+    private static void vswap(final int[] fmap, int p1, int p2, int n) {
+        n += p1;
+        while (p1 < n) {
+            final int t = fmap[p1];
+            fmap[p1++] = fmap[p2];
+            fmap[p2++] = t;
+        }
+    }
+
     /*
      * Used when sorting. If too many long comparisons happen, we stop sorting,
      * and use fallbackSort instead.
      */
     private int workDone;
+
     private int workLimit;
+
     private boolean firstAttempt;
 
     private final int[] stack_ll = new int[STACK_SIZE]; // 4000 byte
+
     private final int[] stack_hh = new int[STACK_SIZE]; // 4000 byte
-    private final int[] stack_dd = new int[QSORT_STACK_SIZE]; // 4000 byte
-
-    private final int[] mainSort_runningOrder = new int[256]; // 1024 byte
-    private final int[] mainSort_copy = new int[256]; // 1024 byte
-    private final boolean[] mainSort_bigDone = new boolean[256]; // 256 byte
-
-    private final int[] ftab = new int[FTAB_LENGTH]; // 262148 byte
-
-    /**
-     * Array instance identical to Data's sfmap, both are used only
-     * temporarily and indepently, so we do not need to allocate
-     * additional memory.
-     */
-    private final char[] quadrant;
-
-    BlockSort(final BZip2CompressorOutputStream.Data data) {
-        this.quadrant = data.sfmap;
-    }
-
-    void blockSort(final BZip2CompressorOutputStream.Data data, final int last) {
-        this.workLimit = WORK_FACTOR * last;
-        this.workDone = 0;
-        this.firstAttempt = true;
-
-        if (last + 1 < 10000) {
-            fallbackSort(data, last);
-        } else {
-            mainSort(data, last);
-
-            if (this.firstAttempt && (this.workDone > this.workLimit)) {
-                fallbackSort(data, last);
-            }
-        }
-
-        final int[] fmap = data.fmap;
-        data.origPtr = -1;
-        for (int i = 0; i <= last; i++) {
-            if (fmap[i] == 0) {
-                data.origPtr = i;
-                break;
-            }
-        }
-
-        // assert (data.origPtr != -1) : data.origPtr;
-    }
-
-    /**
-     * Adapt fallbackSort to the expected interface of the rest of the
-     * code, in particular deal with the fact that block starts at
-     * offset 1 (in libbzip2 1.0.6 it starts at 0).
-     */
-    final void fallbackSort(final BZip2CompressorOutputStream.Data data,
-                            final int last) {
-        data.block[0] = data.block[last + 1];
-        fallbackSort(data.fmap, data.block, last + 1);
-        for (int i = 0; i < last + 1; i++) {
-            --data.fmap[i];
-        }
-        for (int i = 0; i < last + 1; i++) {
-            if (data.fmap[i] == -1) {
-                data.fmap[i] = last;
-                break;
-            }
-        }
-    }
 
 /*---------------------------------------------*/
 
@@ -256,76 +223,68 @@ class BlockSort {
      *
      */
 
-    /**
-     * @param fmap points to the index of the starting point of a
-     *        permutation inside the block of data in the current
-     *        partially sorted order
-     * @param eclass points from the index of a character inside the
-     *        block to the first index in fmap that contains the
-     *        bucket of its suffix that is sorted in this step.
-     * @param lo lower boundary of the fmap-interval to be sorted
-     * @param hi upper boundary of the fmap-interval to be sorted
-     */
-    private void fallbackSimpleSort(final int[] fmap,
-                                    final int[] eclass,
-                                    final int lo,
-                                    final int hi) {
-        if (lo == hi) {
-            return;
-        }
+    private final int[] stack_dd = new int[QSORT_STACK_SIZE]; // 4000 byte
 
-        int j;
-        if (hi - lo > 3) {
-            for (int i = hi - 4; i >= lo; i--) {
-                final int tmp = fmap[i];
-                final int ec_tmp = eclass[tmp];
-                for (j = i + 4; j <= hi && ec_tmp > eclass[fmap[j]];
-                     j += 4) {
-                    fmap[j - 4] = fmap[j];
-                }
-                fmap[j - 4] = tmp;
+    private final int[] mainSort_runningOrder = new int[256]; // 1024 byte
+
+    private final int[] mainSort_copy = new int[256]; // 1024 byte
+
+    private final boolean[] mainSort_bigDone = new boolean[256]; // 256 byte
+
+    private final int[] ftab = new int[FTAB_LENGTH]; // 262148 byte
+
+    /**
+     * Array instance identical to Data's sfmap, both are used only
+     * temporarily and indepently, so we do not need to allocate
+     * additional memory.
+     */
+    private final char[] quadrant;
+
+    private int[] eclass;
+
+
+/*---------------------------------------------*/
+
+    BlockSort(final BZip2CompressorOutputStream.Data data) {
+        this.quadrant = data.sfmap;
+    }
+
+    void blockSort(final BZip2CompressorOutputStream.Data data, final int last) {
+        this.workLimit = WORK_FACTOR * last;
+        this.workDone = 0;
+        this.firstAttempt = true;
+
+        if (last + 1 < 10000) {
+            fallbackSort(data, last);
+        } else {
+            mainSort(data, last);
+
+            if (this.firstAttempt && this.workDone > this.workLimit) {
+                fallbackSort(data, last);
             }
         }
 
-        for (int i = hi - 1; i >= lo; i--) {
-            final int tmp = fmap[i];
-            final int ec_tmp = eclass[tmp];
-            for (j = i + 1; j <= hi && ec_tmp > eclass[fmap[j]]; j++) {
-                fmap[j - 1] = fmap[j];
+        final int[] fmap = data.fmap;
+        data.origPtr = -1;
+        for (int i = 0; i <= last; i++) {
+            if (fmap[i] == 0) {
+                data.origPtr = i;
+                break;
             }
-            fmap[j-1] = tmp;
         }
+
+        // assert (data.origPtr != -1) : data.origPtr;
     }
 
-    private static final int FALLBACK_QSORT_SMALL_THRESH = 10;
-
-    /**
-     * swaps two values in fmap
+    /*
+     * The C code uses an array of ints (each int holding 32 flags) to
+     * represents the bucket-start flags (bhtab).  It also contains
+     * optimizations to skip over 32 consecutively set or
+     * consecutively unset bits on word boundaries at once.  For now
+     * I've chosen to use the simpler but potentially slower code
+     * using BitSet - also in the hope that using the BitSet#nextXXX
+     * methods may be fast enough.
      */
-    private void fswap(final int[] fmap, final int zz1, final int zz2) {
-        final int zztmp = fmap[zz1];
-        fmap[zz1] = fmap[zz2];
-        fmap[zz2] = zztmp;
-    }
-
-    /**
-     * swaps two intervals starting at yyp1 and yyp2 of length yyn inside fmap.
-     */
-    private void fvswap(final int[] fmap, int yyp1, int yyp2, int yyn) {
-        while (yyn > 0) {
-            fswap(fmap, yyp1, yyp2);
-            yyp1++; yyp2++; yyn--;
-        }
-    }
-
-    private void fpush(final int sp, final int lz, final int hz) {
-        stack_ll[sp] = lz;
-        stack_hh[sp] = hz;
-    }
-
-    private int[] fpop(final int sp) {
-        return new int[] { stack_ll[sp], stack_hh[sp] };
-    }
 
     /**
      * @param fmap points to the index of the starting point of a
@@ -363,13 +322,13 @@ class BlockSort {
                7621 and 32768 is taken from Sedgewick's algorithms
                book, chapter 35.
             */
-            r = ((r * 7621) + 1) % 32768;
+            r = (r * 7621 + 1) % 32768;
             final long r3 = r % 3;
             final long med;
             if (r3 == 0) {
                 med = eclass[fmap[lo]];
             } else if (r3 == 1) {
-                med = eclass[fmap[(lo + hi) >>> 1]];
+                med = eclass[fmap[lo + hi >>> 1]];
             } else {
                 med = eclass[fmap[hi]];
             }
@@ -438,27 +397,76 @@ class BlockSort {
         }
     }
 
-
 /*---------------------------------------------*/
 
-    private int[] eclass;
+    /**
+     * @param fmap points to the index of the starting point of a
+     *        permutation inside the block of data in the current
+     *        partially sorted order
+     * @param eclass points from the index of a character inside the
+     *        block to the first index in fmap that contains the
+     *        bucket of its suffix that is sorted in this step.
+     * @param lo lower boundary of the fmap-interval to be sorted
+     * @param hi upper boundary of the fmap-interval to be sorted
+     */
+    private void fallbackSimpleSort(final int[] fmap,
+                                    final int[] eclass,
+                                    final int lo,
+                                    final int hi) {
+        if (lo == hi) {
+            return;
+        }
 
-    private int[] getEclass() {
-        if (eclass == null) {
-            eclass = new int[quadrant.length / 2];
+        int j;
+        if (hi - lo > 3) {
+            for (int i = hi - 4; i >= lo; i--) {
+                final int tmp = fmap[i];
+                final int ec_tmp = eclass[tmp];
+                for (j = i + 4; j <= hi && ec_tmp > eclass[fmap[j]];
+                     j += 4) {
+                    fmap[j - 4] = fmap[j];
+                }
+                fmap[j - 4] = tmp;
+            }
+        }
+
+        for (int i = hi - 1; i >= lo; i--) {
+            final int tmp = fmap[i];
+            final int ec_tmp = eclass[tmp];
+            for (j = i + 1; j <= hi && ec_tmp > eclass[fmap[j]]; j++) {
+                fmap[j - 1] = fmap[j];
+            }
+            fmap[j-1] = tmp;
         }
-        return eclass;
     }
 
-    /*
-     * The C code uses an array of ints (each int holding 32 flags) to
-     * represents the bucket-start flags (bhtab).  It also contains
-     * optimizations to skip over 32 consecutively set or
-     * consecutively unset bits on word boundaries at once.  For now
-     * I've chosen to use the simpler but potentially slower code
-     * using BitSet - also in the hope that using the BitSet#nextXXX
-     * methods may be fast enough.
+    /**
+     * Adapt fallbackSort to the expected interface of the rest of the
+     * code, in particular deal with the fact that block starts at
+     * offset 1 (in libbzip2 1.0.6 it starts at 0).
      */
+    final void fallbackSort(final BZip2CompressorOutputStream.Data data,
+                            final int last) {
+        data.block[0] = data.block[last + 1];
+        fallbackSort(data.fmap, data.block, last + 1);
+        for (int i = 0; i < last + 1; i++) {
+            --data.fmap[i];
+        }
+        for (int i = 0; i < last + 1; i++) {
+            if (data.fmap[i] == -1) {
+                data.fmap[i] = last;
+                break;
+            }
+        }
+    }
+
+/*--
+   LBZ2: The following is an implementation of
+   an elegant 3-way quicksort for strings,
+   described in a paper "Fast Algorithms for
+   Sorting and Searching Strings", by Robert
+   Sedgewick and Jon L. Bentley.
+--*/
 
     /**
      * @param fmap points to the index of the starting point of a
@@ -548,7 +556,7 @@ class BlockSort {
 
                 /*-- LBZ2: now [l, r] bracket current bucket --*/
                 if (r > l) {
-                    nNotDone += (r - l + 1);
+                    nNotDone += r - l + 1;
                     fallbackQSort3(fmap, eclass, l, r);
 
                     /*-- LBZ2: scan bucket and generate header bits-- */
@@ -570,23 +578,149 @@ class BlockSort {
         }
     }
 
-/*---------------------------------------------*/
+    private int[] fpop(final int sp) {
+        return new int[] { stack_ll[sp], stack_hh[sp] };
+    }
 
-    /*
-     * LBZ2: Knuth's increments seem to work better than Incerpi-Sedgewick here.
-     * Possibly because the number of elems to sort is usually small, typically
-     * &lt;= 20.
+    private void fpush(final int sp, final int lz, final int hz) {
+        stack_ll[sp] = lz;
+        stack_hh[sp] = hz;
+    }
+    /**
+     * swaps two values in fmap
      */
-    private static final int[] INCS = { 1, 4, 13, 40, 121, 364, 1093, 3280,
-                                        9841, 29524, 88573, 265720, 797161,
-                                        2391484 };
+    private void fswap(final int[] fmap, final int zz1, final int zz2) {
+        final int zztmp = fmap[zz1];
+        fmap[zz1] = fmap[zz2];
+        fmap[zz2] = zztmp;
+    }
+    /**
+     * swaps two intervals starting at yyp1 and yyp2 of length yyn inside fmap.
+     */
+    private void fvswap(final int[] fmap, int yyp1, int yyp2, int yyn) {
+        while (yyn > 0) {
+            fswap(fmap, yyp1, yyp2);
+            yyp1++; yyp2++; yyn--;
+        }
+    }
 
+    private int[] getEclass() {
+        if (eclass == null) {
+            eclass = new int[quadrant.length / 2];
+        }
+        return eclass;
+    }
+
+    /**
+     * Method "mainQSort3", file "blocksort.c", BZip2 1.0.2
+     */
+    private void mainQSort3(final BZip2CompressorOutputStream.Data dataShadow,
+                            final int loSt, final int hiSt, final int dSt,
+                            final int last) {
+        final int[] stack_ll = this.stack_ll;
+        final int[] stack_hh = this.stack_hh;
+        final int[] stack_dd = this.stack_dd;
+        final int[] fmap = dataShadow.fmap;
+        final byte[] block = dataShadow.block;
+
+        stack_ll[0] = loSt;
+        stack_hh[0] = hiSt;
+        stack_dd[0] = dSt;
+
+        for (int sp = 1; --sp >= 0;) {
+            final int lo = stack_ll[sp];
+            final int hi = stack_hh[sp];
+            final int d = stack_dd[sp];
+
+            if (hi - lo < SMALL_THRESH || d > DEPTH_THRESH) {
+                if (mainSimpleSort(dataShadow, lo, hi, d, last)) {
+                    return;
+                }
+            } else {
+                final int d1 = d + 1;
+                final int med = med3(block[fmap[lo] + d1] & 0xff,
+                                     block[fmap[hi] + d1] & 0xff,
+                                     block[fmap[lo + hi >>> 1] + d1] & 0xff);
+
+                int unLo = lo;
+                int unHi = hi;
+                int ltLo = lo;
+                int gtHi = hi;
+
+                while (true) {
+                    while (unLo <= unHi) {
+                        final int n = (block[fmap[unLo] + d1] & 0xff)
+                            - med;
+                        if (n == 0) {
+                            final int temp = fmap[unLo];
+                            fmap[unLo++] = fmap[ltLo];
+                            fmap[ltLo++] = temp;
+                        } else if (n < 0) {
+                            unLo++;
+                        } else {
+                            break;
+                        }
+                    }
+
+                    while (unLo <= unHi) {
+                        final int n = (block[fmap[unHi] + d1] & 0xff)
+                            - med;
+                        if (n == 0) {
+                            final int temp = fmap[unHi];
+                            fmap[unHi--] = fmap[gtHi];
+                            fmap[gtHi--] = temp;
+                        } else if (n > 0) {
+                            unHi--;
+                        } else {
+                            break;
+                        }
+                    }
+
+                    if (unLo > unHi) {
+                        break;
+                    }
+                    final int temp = fmap[unLo];
+                    fmap[unLo++] = fmap[unHi];
+                    fmap[unHi--] = temp;
+                }
+
+                if (gtHi < ltLo) {
+                    stack_ll[sp] = lo;
+                    stack_hh[sp] = hi;
+                    stack_dd[sp] = d1;
+                } else {
+                    int n = Math.min(ltLo - lo, unLo - ltLo);
+                    vswap(fmap, lo, unLo - n, n);
+                    int m = Math.min(hi - gtHi, gtHi - unHi);
+                    vswap(fmap, unLo, hi - m + 1, m);
+
+                    n = lo + unLo - ltLo - 1;
+                    m = hi - (gtHi - unHi) + 1;
+
+                    stack_ll[sp] = lo;
+                    stack_hh[sp] = n;
+                    stack_dd[sp] = d;
+                    sp++;
+
+                    stack_ll[sp] = n + 1;
+                    stack_hh[sp] = m - 1;
+                    stack_dd[sp] = d1;
+                    sp++;
+
+                    stack_ll[sp] = m;
+                    stack_hh[sp] = hi;
+                    stack_dd[sp] = d;
+                }
+                sp++;
+            }
+        }
+    }
     /**
      * This is the most hammered method of this class.
      *
      * <p>
      * This is the version using unrolled loops. Normally I never use such ones
-     * in Java code. The unrolling has shown a noticable performance improvement
+     * in Java code. The unrolling has shown a noticeable performance improvement
      * on JRE 1.4.2 (Linux i586 / HotSpot Client). Of course it depends on the
      * JIT compiler of the vm.
      * </p>
@@ -596,7 +730,7 @@ class BlockSort {
                                    final int lastShadow) {
         final int bigN = hi - lo + 1;
         if (bigN < 2) {
-            return this.firstAttempt && (this.workDone > this.workLimit);
+            return this.firstAttempt && this.workDone > this.workLimit;
         }
 
         int hp = 0;
@@ -621,7 +755,7 @@ class BlockSort {
 
             for (int i = lo + h; i <= hi;) {
                 // copy
-                for (int k = 3; (i <= hi) && (--k >= 0); i++) {
+                for (int k = 3; i <= hi && --k >= 0; i++) {
                     final int v = fmap[i];
                     final int vd = v + d;
                     int j = i;
@@ -660,7 +794,7 @@ class BlockSort {
                                 if (block[i1 + 3] == block[i2 + 3]) {
                                     if (block[i1 + 4] == block[i2 + 4]) {
                                         if (block[i1 + 5] == block[i2 + 5]) {
-                                            if (block[(i1 += 6)] == block[(i2 += 6)]) { //NOSONAR
+                                            if (block[i1 += 6] == block[i2 += 6]) { //NOSONAR
                                                 int x = lastShadow;
                                                 X: while (x > 0) {
                                                     x -= 4;
@@ -681,7 +815,7 @@ class BlockSort {
                                                                                     workDoneShadow++;
                                                                                     continue X;
                                                                                 }
-                                                                                if ((quadrant[i1 + 3] > quadrant[i2 + 3])) {
+                                                                                if (quadrant[i1 + 3] > quadrant[i2 + 3]) {
                                                                                     continue HAMMER;
                                                                                 }
                                                                                 break HAMMER;
@@ -691,7 +825,7 @@ class BlockSort {
                                                                             }
                                                                             break HAMMER;
                                                                         }
-                                                                        if ((quadrant[i1 + 2] > quadrant[i2 + 2])) {
+                                                                        if (quadrant[i1 + 2] > quadrant[i2 + 2]) {
                                                                             continue HAMMER;
                                                                         }
                                                                         break HAMMER;
@@ -701,7 +835,7 @@ class BlockSort {
                                                                     }
                                                                     break HAMMER;
                                                                 }
-                                                                if ((quadrant[i1 + 1] > quadrant[i2 + 1])) {
+                                                                if (quadrant[i1 + 1] > quadrant[i2 + 1]) {
                                                                     continue HAMMER;
                                                                 }
                                                                 break HAMMER;
@@ -711,7 +845,7 @@ class BlockSort {
                                                             }
                                                             break HAMMER;
                                                         }
-                                                        if ((quadrant[i1] > quadrant[i2])) {
+                                                        if (quadrant[i1] > quadrant[i2]) {
                                                             continue HAMMER;
                                                         }
                                                         break HAMMER;
@@ -760,152 +894,17 @@ class BlockSort {
                     fmap[j] = v;
                 }
 
-                if (firstAttemptShadow && (i <= hi)
-                    && (workDoneShadow > workLimitShadow)) {
+                if (firstAttemptShadow && i <= hi
+                    && workDoneShadow > workLimitShadow) {
                     break HP;
                 }
             }
         }
 
         this.workDone = workDoneShadow;
-        return firstAttemptShadow && (workDoneShadow > workLimitShadow);
+        return firstAttemptShadow && workDoneShadow > workLimitShadow;
     }
 
-/*--
-   LBZ2: The following is an implementation of
-   an elegant 3-way quicksort for strings,
-   described in a paper "Fast Algorithms for
-   Sorting and Searching Strings", by Robert
-   Sedgewick and Jon L. Bentley.
---*/
-
-    private static void vswap(final int[] fmap, int p1, int p2, int n) {
-        n += p1;
-        while (p1 < n) {
-            final int t = fmap[p1];
-            fmap[p1++] = fmap[p2];
-            fmap[p2++] = t;
-        }
-    }
-
-    private static int med3(final int a, final int b, final int c) {
-        return (a < b) ? (b < c ? b : a < c ? c : a) : (b > c ? b : a > c ? c
-                                                        : a);
-    }
-
-    private static final int SMALL_THRESH = 20;
-    private static final int DEPTH_THRESH = 10;
-    private static final int WORK_FACTOR = 30;
-
-    /**
-     * Method "mainQSort3", file "blocksort.c", BZip2 1.0.2
-     */
-    private void mainQSort3(final BZip2CompressorOutputStream.Data dataShadow,
-                            final int loSt, final int hiSt, final int dSt,
-                            final int last) {
-        final int[] stack_ll = this.stack_ll;
-        final int[] stack_hh = this.stack_hh;
-        final int[] stack_dd = this.stack_dd;
-        final int[] fmap = dataShadow.fmap;
-        final byte[] block = dataShadow.block;
-
-        stack_ll[0] = loSt;
-        stack_hh[0] = hiSt;
-        stack_dd[0] = dSt;
-
-        for (int sp = 1; --sp >= 0;) {
-            final int lo = stack_ll[sp];
-            final int hi = stack_hh[sp];
-            final int d = stack_dd[sp];
-
-            if ((hi - lo < SMALL_THRESH) || (d > DEPTH_THRESH)) {
-                if (mainSimpleSort(dataShadow, lo, hi, d, last)) {
-                    return;
-                }
-            } else {
-                final int d1 = d + 1;
-                final int med = med3(block[fmap[lo] + d1] & 0xff,
-                                     block[fmap[hi] + d1] & 0xff,
-                                     block[fmap[(lo + hi) >>> 1] + d1] & 0xff);
-
-                int unLo = lo;
-                int unHi = hi;
-                int ltLo = lo;
-                int gtHi = hi;
-
-                while (true) {
-                    while (unLo <= unHi) {
-                        final int n = (block[fmap[unLo] + d1] & 0xff)
-                            - med;
-                        if (n == 0) {
-                            final int temp = fmap[unLo];
-                            fmap[unLo++] = fmap[ltLo];
-                            fmap[ltLo++] = temp;
-                        } else if (n < 0) {
-                            unLo++;
-                        } else {
-                            break;
-                        }
-                    }
-
-                    while (unLo <= unHi) {
-                        final int n = (block[fmap[unHi] + d1] & 0xff)
-                            - med;
-                        if (n == 0) {
-                            final int temp = fmap[unHi];
-                            fmap[unHi--] = fmap[gtHi];
-                            fmap[gtHi--] = temp;
-                        } else if (n > 0) {
-                            unHi--;
-                        } else {
-                            break;
-                        }
-                    }
-
-                    if (unLo > unHi) {
-                        break;
-                    }
-                    final int temp = fmap[unLo];
-                    fmap[unLo++] = fmap[unHi];
-                    fmap[unHi--] = temp;
-                }
-
-                if (gtHi < ltLo) {
-                    stack_ll[sp] = lo;
-                    stack_hh[sp] = hi;
-                    stack_dd[sp] = d1;
-                    sp++;
-                } else {
-                    int n = Math.min(ltLo - lo, unLo - ltLo);
-                    vswap(fmap, lo, unLo - n, n);
-                    int m = Math.min(hi - gtHi, gtHi - unHi);
-                    vswap(fmap, unLo, hi - m + 1, m);
-
-                    n = lo + unLo - ltLo - 1;
-                    m = hi - (gtHi - unHi) + 1;
-
-                    stack_ll[sp] = lo;
-                    stack_hh[sp] = n;
-                    stack_dd[sp] = d;
-                    sp++;
-
-                    stack_ll[sp] = n + 1;
-                    stack_hh[sp] = m - 1;
-                    stack_dd[sp] = d1;
-                    sp++;
-
-                    stack_ll[sp] = m;
-                    stack_hh[sp] = hi;
-                    stack_dd[sp] = d;
-                    sp++;
-                }
-            }
-        }
-    }
-
-    private static final int SETMASK = (1 << 21);
-    private static final int CLEARMASK = (~SETMASK);
-
     final void mainSort(final BZip2CompressorOutputStream.Data dataShadow,
                         final int lastShadow) {
         final int[] runningOrder = this.mainSort_runningOrder;
@@ -927,7 +926,7 @@ class BlockSort {
          * for block.
          */
         for (int i = 0; i < BZip2Constants.NUM_OVERSHOOT_BYTES; i++) {
-            block[lastShadow + i + 2] = block[(i % (lastShadow + 1)) + 1];
+            block[lastShadow + i + 2] = block[i % (lastShadow + 1) + 1];
         }
         for (int i = lastShadow + BZip2Constants.NUM_OVERSHOOT_BYTES +1; --i >= 0;) {
             quadrant[i] = 0;
@@ -970,10 +969,10 @@ class BlockSort {
             h /= 3;
             for (int i = h; i <= 255; i++) {
                 final int vv = runningOrder[i];
-                final int a = ftab[(vv + 1) << 8] - ftab[vv << 8];
+                final int a = ftab[vv + 1 << 8] - ftab[vv << 8];
                 final int b = h - 1;
                 int j = i;
-                for (int ro = runningOrder[j - h]; (ftab[(ro + 1) << 8] - ftab[ro << 8]) > a; ro = runningOrder[j
+                for (int ro = runningOrder[j - h]; ftab[ro + 1 << 8] - ftab[ro << 8] > a; ro = runningOrder[j
                                                                                                                 - h]) {
                     runningOrder[j] = ro;
                     j -= h;
@@ -1010,7 +1009,7 @@ class BlockSort {
                     if (hi > lo) {
                         mainQSort3(dataShadow, lo, hi, 2, lastShadow);
                         if (firstAttemptShadow
-                            && (this.workDone > workLimitShadow)) {
+                            && this.workDone > workLimitShadow) {
                             return;
                         }
                     }
@@ -1026,11 +1025,11 @@ class BlockSort {
                 copy[j] = ftab[(j << 8) + ss] & CLEARMASK;
             }
 
-            for (int j = ftab[ss << 8] & CLEARMASK, hj = (ftab[(ss + 1) << 8] & CLEARMASK); j < hj; j++) {
+            for (int j = ftab[ss << 8] & CLEARMASK, hj = ftab[ss + 1 << 8] & CLEARMASK; j < hj; j++) {
                 final int fmap_j = fmap[j];
                 c1 = block[fmap_j] & 0xff;
                 if (!bigDone[c1]) {
-                    fmap[copy[c1]] = (fmap_j == 0) ? lastShadow : (fmap_j - 1);
+                    fmap[copy[c1]] = fmap_j == 0 ? lastShadow : fmap_j - 1;
                     copy[c1]++;
                 }
             }
@@ -1051,10 +1050,10 @@ class BlockSort {
 
             if (i < 255) {
                 final int bbStart = ftab[ss << 8] & CLEARMASK;
-                final int bbSize = (ftab[(ss + 1) << 8] & CLEARMASK) - bbStart;
+                final int bbSize = (ftab[ss + 1 << 8] & CLEARMASK) - bbStart;
                 int shifts = 0;
 
-                while ((bbSize >> shifts) > 65534) {
+                while (bbSize >> shifts > 65534) {
                     shifts++;
                 }
 
