@@ -43,10 +43,10 @@ public class FramedLZ4CompressorInputStream extends CompressorInputStream
     implements InputStreamStatistics {
 
     // used by FramedLZ4CompressorOutputStream as well
-    static final byte[] LZ4_SIGNATURE = new byte[] { //NOSONAR
+    static final byte[] LZ4_SIGNATURE = { //NOSONAR
         4, 0x22, 0x4d, 0x18
     };
-    private static final byte[] SKIPPABLE_FRAME_TRAILER = new byte[] {
+    private static final byte[] SKIPPABLE_FRAME_TRAILER = {
         0x2a, 0x4d, 0x18
     };
     private static final byte SKIPPABLE_FRAME_PREFIX_BYTE_MASK = 0x50;
@@ -60,25 +60,55 @@ public class FramedLZ4CompressorInputStream extends CompressorInputStream
     static final int BLOCK_MAX_SIZE_MASK = 0x70;
     static final int UNCOMPRESSED_FLAG_MASK = 0x80000000;
 
+    private static boolean isSkippableFrameSignature(final byte[] b) {
+        if ((b[0] & SKIPPABLE_FRAME_PREFIX_BYTE_MASK) != SKIPPABLE_FRAME_PREFIX_BYTE_MASK) {
+            return false;
+        }
+        for (int i = 1; i < 4; i++) {
+            if (b[i] != SKIPPABLE_FRAME_TRAILER[i - 1]) {
+                return false;
+            }
+        }
+        return true;
+    }
+
+    /**
+     * Checks if the signature matches what is expected for a .lz4 file.
+     *
+     * <p>.lz4 files start with a four byte signature.</p>
+     *
+     * @param signature the bytes to check
+     * @param length    the number of bytes to check
+     * @return          true if this is a .sz stream, false otherwise
+     */
+    public static boolean matches(final byte[] signature, final int length) {
+
+        if (length < LZ4_SIGNATURE.length) {
+            return false;
+        }
+
+        byte[] shortenedSig = signature;
+        if (signature.length > LZ4_SIGNATURE.length) {
+            shortenedSig = Arrays.copyOf(signature, LZ4_SIGNATURE.length);
+        }
+
+        return Arrays.equals(shortenedSig, LZ4_SIGNATURE);
+    }
+
     // used in no-arg read method
     private final byte[] oneByte = new byte[1];
+    private final ByteUtils.ByteSupplier supplier = this::readOneByte;
 
-    private final ByteUtils.ByteSupplier supplier = new ByteUtils.ByteSupplier() {
-        @Override
-        public int getAsByte() throws IOException {
-            return readOneByte();
-        }
-    };
-
-    private final CountingInputStream in;
+    private final CountingInputStream inputStream;
     private final boolean decompressConcatenated;
-
     private boolean expectBlockChecksum;
     private boolean expectBlockDependency;
+
     private boolean expectContentSize;
     private boolean expectContentChecksum;
 
     private InputStream currentBlock;
+
     private boolean endReached, inUncompressed;
 
     // used for frame header checksum and content checksum, if present
@@ -97,7 +127,7 @@ public class FramedLZ4CompressorInputStream extends CompressorInputStream
      * @param in  the InputStream from which to read the compressed data
      * @throws IOException if reading fails
      */
-    public FramedLZ4CompressorInputStream(InputStream in) throws IOException {
+    public FramedLZ4CompressorInputStream(final InputStream in) throws IOException {
         this(in, false);
     }
 
@@ -111,16 +141,23 @@ public class FramedLZ4CompressorInputStream extends CompressorInputStream
      *          after the frame stream
      * @throws IOException if reading fails
      */
-    public FramedLZ4CompressorInputStream(InputStream in, boolean decompressConcatenated) throws IOException {
-        this.in = new CountingInputStream(in);
+    public FramedLZ4CompressorInputStream(final InputStream in, final boolean decompressConcatenated) throws IOException {
+        this.inputStream = new CountingInputStream(in);
         this.decompressConcatenated = decompressConcatenated;
         init(true);
     }
 
-    /** {@inheritDoc} */
-    @Override
-    public int read() throws IOException {
-        return read(oneByte, 0, 1) == -1 ? -1 : oneByte[0] & 0xFF;
+    private void appendToBlockDependencyBuffer(final byte[] b, final int off, int len) {
+        len = Math.min(len, blockDependencyBuffer.length);
+        if (len > 0) {
+            final int keep = blockDependencyBuffer.length - len;
+            if (keep > 0) {
+                // move last keep bytes towards the start of the buffer
+                System.arraycopy(blockDependencyBuffer, len, blockDependencyBuffer, 0, keep);
+            }
+            // append new data
+            System.arraycopy(b, off, blockDependencyBuffer, keep, len);
+        }
     }
 
     /** {@inheritDoc} */
@@ -132,13 +169,79 @@ public class FramedLZ4CompressorInputStream extends CompressorInputStream
                 currentBlock = null;
             }
         } finally {
-            in.close();
+            inputStream.close();
+        }
+    }
+
+    /**
+     * @since 1.17
+     */
+    @Override
+    public long getCompressedCount() {
+        return inputStream.getBytesRead();
+    }
+
+    private void init(final boolean firstFrame) throws IOException {
+        if (readSignature(firstFrame)) {
+            readFrameDescriptor();
+            nextBlock();
+        }
+    }
+
+    private void maybeFinishCurrentBlock() throws IOException {
+        if (currentBlock != null) {
+            currentBlock.close();
+            currentBlock = null;
+            if (expectBlockChecksum) {
+                verifyChecksum(blockHash, "block");
+                blockHash.reset();
+            }
+        }
+    }
+
+    private void nextBlock() throws IOException {
+        maybeFinishCurrentBlock();
+        final long len = ByteUtils.fromLittleEndian(supplier, 4);
+        final boolean uncompressed = (len & UNCOMPRESSED_FLAG_MASK) != 0;
+        final int realLen = (int) (len & ~UNCOMPRESSED_FLAG_MASK);
+        if (realLen == 0) {
+            verifyContentChecksum();
+            if (!decompressConcatenated) {
+                endReached = true;
+            } else {
+                init(false);
+            }
+            return;
+        }
+        InputStream capped = new BoundedInputStream(inputStream, realLen);
+        if (expectBlockChecksum) {
+            capped = new ChecksumCalculatingInputStream(blockHash, capped);
+        }
+        if (uncompressed) {
+            inUncompressed = true;
+            currentBlock = capped;
+        } else {
+            inUncompressed = false;
+            final BlockLZ4CompressorInputStream s = new BlockLZ4CompressorInputStream(capped);
+            if (expectBlockDependency) {
+                s.prefill(blockDependencyBuffer);
+            }
+            currentBlock = s;
         }
     }
 
+    /** {@inheritDoc} */
+    @Override
+    public int read() throws IOException {
+        return read(oneByte, 0, 1) == -1 ? -1 : oneByte[0] & 0xFF;
+    }
+
     /** {@inheritDoc} */
     @Override
     public int read(final byte[] b, final int off, final int len) throws IOException {
+        if (len == 0) {
+            return 0;
+        }
         if (endReached) {
             return -1;
         }
@@ -160,25 +263,77 @@ public class FramedLZ4CompressorInputStream extends CompressorInputStream
         return r;
     }
 
-    /**
-     * @since 1.17
-     */
-    @Override
-    public long getCompressedCount() {
-        return in.getBytesRead();
-    }
-
-    private void init(boolean firstFrame) throws IOException {
-        if (readSignature(firstFrame)) {
-            readFrameDescriptor();
-            nextBlock();
+    private void readFrameDescriptor() throws IOException {
+        final int flags = readOneByte();
+        if (flags == -1) {
+            throw new IOException("Premature end of stream while reading frame flags");
+        }
+        contentHash.update(flags);
+        if ((flags & VERSION_MASK) != SUPPORTED_VERSION) {
+            throw new IOException("Unsupported version " + (flags >> 6));
+        }
+        expectBlockDependency = (flags & BLOCK_INDEPENDENCE_MASK) == 0;
+        if (expectBlockDependency) {
+            if (blockDependencyBuffer == null) {
+                blockDependencyBuffer = new byte[BlockLZ4CompressorInputStream.WINDOW_SIZE];
+            }
+        } else {
+            blockDependencyBuffer = null;
+        }
+        expectBlockChecksum = (flags & BLOCK_CHECKSUM_MASK) != 0;
+        expectContentSize = (flags & CONTENT_SIZE_MASK) != 0;
+        expectContentChecksum = (flags & CONTENT_CHECKSUM_MASK) != 0;
+        final int bdByte = readOneByte();
+        if (bdByte == -1) { // max size is irrelevant for this implementation
+            throw new IOException("Premature end of stream while reading frame BD byte");
+        }
+        contentHash.update(bdByte);
+        if (expectContentSize) { // for now, we don't care, contains the uncompressed size
+            final byte[] contentSize = new byte[8];
+            final int skipped = IOUtils.readFully(inputStream, contentSize);
+            count(skipped);
+            if (8 != skipped) {
+                throw new IOException("Premature end of stream while reading content size");
+            }
+            contentHash.update(contentSize, 0, contentSize.length);
+        }
+        final int headerHash = readOneByte();
+        if (headerHash == -1) { // partial hash of header.
+            throw new IOException("Premature end of stream while reading frame header checksum");
+        }
+        final int expectedHash = (int) (contentHash.getValue() >> 8 & 0xff);
+        contentHash.reset();
+        if (headerHash != expectedHash) {
+            throw new IOException("Frame header checksum mismatch");
         }
     }
 
-    private boolean readSignature(boolean firstFrame) throws IOException {
-        String garbageMessage = firstFrame ? "Not a LZ4 frame stream" : "LZ4 frame stream followed by garbage";
+    private int readOnce(final byte[] b, final int off, final int len) throws IOException {
+        if (inUncompressed) {
+            final int cnt = currentBlock.read(b, off, len);
+            count(cnt);
+            return cnt;
+        }
+        final BlockLZ4CompressorInputStream l = (BlockLZ4CompressorInputStream) currentBlock;
+        final long before = l.getBytesRead();
+        final int cnt = currentBlock.read(b, off, len);
+        count(l.getBytesRead() - before);
+        return cnt;
+    }
+
+    private int readOneByte() throws IOException {
+        final int b = inputStream.read();
+        if (b != -1) {
+            count(1);
+            return b & 0xFF;
+        }
+        return -1;
+    }
+
+    private boolean readSignature(final boolean firstFrame) throws IOException {
+        final String garbageMessage = firstFrame ? "Not a LZ4 frame stream" : "LZ4 frame stream followed by garbage";
         final byte[] b = new byte[4];
-        int read = IOUtils.readFully(in, b);
+        int read = IOUtils.readFully(inputStream, b);
         count(read);
         if (0 == read && !firstFrame) {
             // good LZ4 frame and nothing after it
@@ -201,93 +356,42 @@ public class FramedLZ4CompressorInputStream extends CompressorInputStream
         return true;
     }
 
-    private void readFrameDescriptor() throws IOException {
-        int flags = readOneByte();
-        if (flags == -1) {
-            throw new IOException("Premature end of stream while reading frame flags");
-        }
-        contentHash.update(flags);
-        if ((flags & VERSION_MASK) != SUPPORTED_VERSION) {
-            throw new IOException("Unsupported version " + (flags >> 6));
-        }
-        expectBlockDependency = (flags & BLOCK_INDEPENDENCE_MASK) == 0;
-        if (expectBlockDependency) {
-            if (blockDependencyBuffer == null) {
-                blockDependencyBuffer = new byte[BlockLZ4CompressorInputStream.WINDOW_SIZE];
+    /**
+     * Skips over the contents of a skippable frame as well as
+     * skippable frames following it.
+     *
+     * <p>It then tries to read four more bytes which are supposed to
+     * hold an LZ4 signature and returns the number of bytes read
+     * while storing the bytes in the given array.</p>
+     */
+    private int skipSkippableFrame(final byte[] b) throws IOException {
+        int read = 4;
+        while (read == 4 && isSkippableFrameSignature(b)) {
+            final long len = ByteUtils.fromLittleEndian(supplier, 4);
+            if (len < 0) {
+                throw new IOException("Found illegal skippable frame with negative size");
             }
-        } else {
-            blockDependencyBuffer = null;
-        }
-        expectBlockChecksum = (flags & BLOCK_CHECKSUM_MASK) != 0;
-        expectContentSize = (flags & CONTENT_SIZE_MASK) != 0;
-        expectContentChecksum = (flags & CONTENT_CHECKSUM_MASK) != 0;
-        int bdByte = readOneByte();
-        if (bdByte == -1) { // max size is irrelevant for this implementation
-            throw new IOException("Premature end of stream while reading frame BD byte");
-        }
-        contentHash.update(bdByte);
-        if (expectContentSize) { // for now we don't care, contains the uncompressed size
-            byte[] contentSize = new byte[8];
-            int skipped = IOUtils.readFully(in, contentSize);
+            final long skipped = IOUtils.skip(inputStream, len);
             count(skipped);
-            if (8 != skipped) {
-                throw new IOException("Premature end of stream while reading content size");
+            if (len != skipped) {
+                throw new IOException("Premature end of stream while skipping frame");
             }
-            contentHash.update(contentSize, 0, contentSize.length);
-        }
-        int headerHash = readOneByte();
-        if (headerHash == -1) { // partial hash of header.
-            throw new IOException("Premature end of stream while reading frame header checksum");
-        }
-        int expectedHash = (int) ((contentHash.getValue() >> 8) & 0xff);
-        contentHash.reset();
-        if (headerHash != expectedHash) {
-            throw new IOException("Frame header checksum mismatch");
+            read = IOUtils.readFully(inputStream, b);
+            count(read);
         }
+        return read;
     }
 
-    private void nextBlock() throws IOException {
-        maybeFinishCurrentBlock();
-        long len = ByteUtils.fromLittleEndian(supplier, 4);
-        boolean uncompressed = (len & UNCOMPRESSED_FLAG_MASK) != 0;
-        int realLen = (int) (len & (~UNCOMPRESSED_FLAG_MASK));
-        if (realLen < 0) {
-            throw new IOException("Found illegal block with negative size");
+    private void verifyChecksum(final XXHash32 hash, final String kind) throws IOException {
+        final byte[] checksum = new byte[4];
+        final int read = IOUtils.readFully(inputStream, checksum);
+        count(read);
+        if (4 != read) {
+            throw new IOException("Premature end of stream while reading " + kind + " checksum");
         }
-        if (realLen == 0) {
-            verifyContentChecksum();
-            if (!decompressConcatenated) {
-                endReached = true;
-            } else {
-                init(false);
-            }
-            return;
-        }
-        InputStream capped = new BoundedInputStream(in, realLen);
-        if (expectBlockChecksum) {
-            capped = new ChecksumCalculatingInputStream(blockHash, capped);
-        }
-        if (uncompressed) {
-            inUncompressed = true;
-            currentBlock = capped;
-        } else {
-            inUncompressed = false;
-            BlockLZ4CompressorInputStream s = new BlockLZ4CompressorInputStream(capped);
-            if (expectBlockDependency) {
-                s.prefill(blockDependencyBuffer);
-            }
-            currentBlock = s;
-        }
-    }
-
-    private void maybeFinishCurrentBlock() throws IOException {
-        if (currentBlock != null) {
-            currentBlock.close();
-            currentBlock = null;
-            if (expectBlockChecksum) {
-                verifyChecksum(blockHash, "block");
-                blockHash.reset();
-            }
+        final long expectedHash = hash.getValue();
+        if (expectedHash != ByteUtils.fromLittleEndian(checksum)) {
+            throw new IOException(kind + " checksum mismatch.");
         }
     }
 
@@ -297,114 +401,4 @@ public class FramedLZ4CompressorInputStream extends CompressorInputStream
         }
         contentHash.reset();
     }
-
-    private void verifyChecksum(XXHash32 hash, String kind) throws IOException {
-        byte[] checksum = new byte[4];
-        int read = IOUtils.readFully(in, checksum);
-        count(read);
-        if (4 != read) {
-            throw new IOException("Premature end of stream while reading " + kind + " checksum");
-        }
-        long expectedHash = hash.getValue();
-        if (expectedHash != ByteUtils.fromLittleEndian(checksum)) {
-            throw new IOException(kind + " checksum mismatch.");
-        }
-    }
-
-    private int readOneByte() throws IOException {
-        final int b = in.read();
-        if (b != -1) {
-            count(1);
-            return b & 0xFF;
-        }
-        return -1;
-    }
-
-    private int readOnce(byte[] b, int off, int len) throws IOException {
-        if (inUncompressed) {
-            int cnt = currentBlock.read(b, off, len);
-            count(cnt);
-            return cnt;
-        }
-        BlockLZ4CompressorInputStream l = (BlockLZ4CompressorInputStream) currentBlock;
-        long before = l.getBytesRead();
-        int cnt = currentBlock.read(b, off, len);
-        count(l.getBytesRead() - before);
-        return cnt;
-    }
-
-    private static boolean isSkippableFrameSignature(byte[] b) {
-        if ((b[0] & SKIPPABLE_FRAME_PREFIX_BYTE_MASK) != SKIPPABLE_FRAME_PREFIX_BYTE_MASK) {
-            return false;
-        }
-        for (int i = 1; i < 4; i++) {
-            if (b[i] != SKIPPABLE_FRAME_TRAILER[i - 1]) {
-                return false;
-            }
-        }
-        return true;
-    }
-
-    /**
-     * Skips over the contents of a skippable frame as well as
-     * skippable frames following it.
-     *
-     * <p>It then tries to read four more bytes which are supposed to
-     * hold an LZ4 signature and returns the number of bytes read
-     * while storing the bytes in the given array.</p>
-     */
-    private int skipSkippableFrame(byte[] b) throws IOException {
-        int read = 4;
-        while (read == 4 && isSkippableFrameSignature(b)) {
-            final long len = ByteUtils.fromLittleEndian(supplier, 4);
-            if (len < 0) {
-                throw new IOException("Found illegal skippable frame with negative size");
-            }
-            long skipped = IOUtils.skip(in, len);
-            count(skipped);
-            if (len != skipped) {
-                throw new IOException("Premature end of stream while skipping frame");
-            }
-            read = IOUtils.readFully(in, b);
-            count(read);
-        }
-        return read;
-    }
-
-    private void appendToBlockDependencyBuffer(final byte[] b, final int off, int len) {
-        len = Math.min(len, blockDependencyBuffer.length);
-        if (len > 0) {
-            int keep = blockDependencyBuffer.length - len;
-            if (keep > 0) {
-                // move last keep bytes towards the start of the buffer
-                System.arraycopy(blockDependencyBuffer, len, blockDependencyBuffer, 0, keep);
-            }
-            // append new data
-            System.arraycopy(b, off, blockDependencyBuffer, keep, len);
-        }
-    }
-
-    /**
-     * Checks if the signature matches what is expected for a .lz4 file.
-     *
-     * <p>.lz4 files start with a four byte signature.</p>
-     *
-     * @param signature the bytes to check
-     * @param length    the number of bytes to check
-     * @return          true if this is a .sz stream, false otherwise
-     */
-    public static boolean matches(final byte[] signature, final int length) {
-
-        if (length < LZ4_SIGNATURE.length) {
-            return false;
-        }
-
-        byte[] shortenedSig = signature;
-        if (signature.length > LZ4_SIGNATURE.length) {
-            shortenedSig = new byte[LZ4_SIGNATURE.length];
-            System.arraycopy(signature, 0, shortenedSig, 0, LZ4_SIGNATURE.length);
-        }
-
-        return Arrays.equals(shortenedSig, LZ4_SIGNATURE);
-    }
 }
