@@ -55,13 +55,44 @@ public class FramedSnappyCompressorInputStream extends CompressorInputStream
     private static final int MAX_SKIPPABLE_TYPE = 0xfd;
 
     // used by FramedSnappyCompressorOutputStream as well
-    static final byte[] SZ_SIGNATURE = new byte[] { //NOSONAR
+    static final byte[] SZ_SIGNATURE = { //NOSONAR
         (byte) STREAM_IDENTIFIER_TYPE, // tag
         6, 0, 0, // length
         's', 'N', 'a', 'P', 'p', 'Y'
     };
 
+    /**
+     * Checks if the signature matches what is expected for a .sz file.
+     *
+     * <p>.sz files start with a chunk with tag 0xff and content sNaPpY.</p>
+     *
+     * @param signature the bytes to check
+     * @param length    the number of bytes to check
+     * @return          true if this is a .sz stream, false otherwise
+     */
+    public static boolean matches(final byte[] signature, final int length) {
+
+        if (length < SZ_SIGNATURE.length) {
+            return false;
+        }
+
+        byte[] shortenedSig = signature;
+        if (signature.length > SZ_SIGNATURE.length) {
+            shortenedSig = Arrays.copyOf(signature, SZ_SIGNATURE.length);
+        }
+
+        return Arrays.equals(shortenedSig, SZ_SIGNATURE);
+    }
+    static long unmask(long x) {
+        // ugly, maybe we should just have used ints and deal with the
+        // overflow
+        x -= MASK_OFFSET;
+        x &= 0xffffFFFFL;
+        return (x >> 17 | x << 15) & 0xffffFFFFL;
+    }
+
     private long unreadBytes;
+
     private final CountingInputStream countingStream;
 
     /** The underlying stream to read compressed data from */
@@ -74,12 +105,12 @@ public class FramedSnappyCompressorInputStream extends CompressorInputStream
 
     // used in no-arg read method
     private final byte[] oneByte = new byte[1];
-
     private boolean endReached, inUncompressedChunk;
-
     private int uncompressedBytesRemaining;
     private long expectedChecksum = -1;
+
     private final int blockSize;
+
     private final PureJavaCrc32C checksum = new PureJavaCrc32C();
 
     private final ByteUtils.ByteSupplier supplier = this::readOneByte;
@@ -136,8 +167,15 @@ public class FramedSnappyCompressorInputStream extends CompressorInputStream
 
     /** {@inheritDoc} */
     @Override
-    public int read() throws IOException {
-        return read(oneByte, 0, 1) == -1 ? -1 : oneByte[0] & 0xFF;
+    public int available() throws IOException {
+        if (inUncompressedChunk) {
+            return Math.min(uncompressedBytesRemaining,
+                            inputStream.available());
+        }
+        if (currentCompressedChunk != null) {
+            return currentCompressedChunk.available();
+        }
+        return 0;
     }
 
     /** {@inheritDoc} */
@@ -153,6 +191,20 @@ public class FramedSnappyCompressorInputStream extends CompressorInputStream
         }
     }
 
+    /**
+     * @since 1.17
+     */
+    @Override
+    public long getCompressedCount() {
+        return countingStream.getBytesRead() - unreadBytes;
+    }
+
+    /** {@inheritDoc} */
+    @Override
+    public int read() throws IOException {
+        return read(oneByte, 0, 1) == -1 ? -1 : oneByte[0] & 0xFF;
+    }
+
     /** {@inheritDoc} */
     @Override
     public int read(final byte[] b, final int off, final int len) throws IOException {
@@ -170,25 +222,63 @@ public class FramedSnappyCompressorInputStream extends CompressorInputStream
         return read;
     }
 
-    /** {@inheritDoc} */
-    @Override
-    public int available() throws IOException {
-        if (inUncompressedChunk) {
-            return Math.min(uncompressedBytesRemaining,
-                            inputStream.available());
+    private long readCrc() throws IOException {
+        final byte[] b = new byte[4];
+        final int read = IOUtils.readFully(inputStream, b);
+        count(read);
+        if (read != 4) {
+            throw new IOException("Premature end of stream");
         }
-        if (currentCompressedChunk != null) {
-            return currentCompressedChunk.available();
-        }
-        return 0;
+        return ByteUtils.fromLittleEndian(b);
     }
 
-    /**
-     * @since 1.17
-     */
-    @Override
-    public long getCompressedCount() {
-        return countingStream.getBytesRead() - unreadBytes;
+    private void readNextBlock() throws IOException {
+        verifyLastChecksumAndReset();
+        inUncompressedChunk = false;
+        final int type = readOneByte();
+        if (type == -1) {
+            endReached = true;
+        } else if (type == STREAM_IDENTIFIER_TYPE) {
+            inputStream.unread(type);
+            unreadBytes++;
+            pushedBackBytes(1);
+            readStreamIdentifier();
+            readNextBlock();
+        } else if (type == PADDING_CHUNK_TYPE
+                   || type > MAX_UNSKIPPABLE_TYPE && type <= MAX_SKIPPABLE_TYPE) {
+            skipBlock();
+            readNextBlock();
+        } else if (type >= MIN_UNSKIPPABLE_TYPE && type <= MAX_UNSKIPPABLE_TYPE) {
+            throw new IOException("Unskippable chunk with type " + type
+                                  + " (hex " + Integer.toHexString(type) + ")"
+                                  + " detected.");
+        } else if (type == UNCOMPRESSED_CHUNK_TYPE) {
+            inUncompressedChunk = true;
+            uncompressedBytesRemaining = readSize() - 4 /* CRC */;
+            if (uncompressedBytesRemaining < 0) {
+                throw new IOException("Found illegal chunk with negative size");
+            }
+            expectedChecksum = unmask(readCrc());
+        } else if (type == COMPRESSED_CHUNK_TYPE) {
+            final boolean expectChecksum = dialect.usesChecksumWithCompressedChunks();
+            final long size = readSize() - (expectChecksum ? 4L : 0L);
+            if (size < 0) {
+                throw new IOException("Found illegal chunk with negative size");
+            }
+            if (expectChecksum) {
+                expectedChecksum = unmask(readCrc());
+            } else {
+                expectedChecksum = -1;
+            }
+            currentCompressedChunk =
+                new SnappyCompressorInputStream(new BoundedInputStream(inputStream, size), blockSize);
+            // constructor reads uncompressed size
+            count(currentCompressedChunk.getBytesRead());
+        } else {
+            // impossible as all potential byte values have been covered
+            throw new IOException("Unknown chunk type " + type
+                                  + " detected.");
+        }
     }
 
     /**
@@ -226,77 +316,28 @@ public class FramedSnappyCompressorInputStream extends CompressorInputStream
         return read;
     }
 
-    private void readNextBlock() throws IOException {
-        verifyLastChecksumAndReset();
-        inUncompressedChunk = false;
-        final int type = readOneByte();
-        if (type == -1) {
-            endReached = true;
-        } else if (type == STREAM_IDENTIFIER_TYPE) {
-            inputStream.unread(type);
-            unreadBytes++;
-            pushedBackBytes(1);
-            readStreamIdentifier();
-            readNextBlock();
-        } else if (type == PADDING_CHUNK_TYPE
-                   || (type > MAX_UNSKIPPABLE_TYPE && type <= MAX_SKIPPABLE_TYPE)) {
-            skipBlock();
-            readNextBlock();
-        } else if (type >= MIN_UNSKIPPABLE_TYPE && type <= MAX_UNSKIPPABLE_TYPE) {
-            throw new IOException("Unskippable chunk with type " + type
-                                  + " (hex " + Integer.toHexString(type) + ")"
-                                  + " detected.");
-        } else if (type == UNCOMPRESSED_CHUNK_TYPE) {
-            inUncompressedChunk = true;
-            uncompressedBytesRemaining = readSize() - 4 /* CRC */;
-            if (uncompressedBytesRemaining < 0) {
-                throw new IOException("Found illegal chunk with negative size");
-            }
-            expectedChecksum = unmask(readCrc());
-        } else if (type == COMPRESSED_CHUNK_TYPE) {
-            final boolean expectChecksum = dialect.usesChecksumWithCompressedChunks();
-            final long size = readSize() - (expectChecksum ? 4L : 0L);
-            if (size < 0) {
-                throw new IOException("Found illegal chunk with negative size");
-            }
-            if (expectChecksum) {
-                expectedChecksum = unmask(readCrc());
-            } else {
-                expectedChecksum = -1;
-            }
-            currentCompressedChunk =
-                new SnappyCompressorInputStream(new BoundedInputStream(inputStream, size), blockSize);
-            // constructor reads uncompressed size
-            count(currentCompressedChunk.getBytesRead());
-        } else {
-            // impossible as all potential byte values have been covered
-            throw new IOException("Unknown chunk type " + type
-                                  + " detected.");
+    private int readOneByte() throws IOException {
+        final int b = inputStream.read();
+        if (b != -1) {
+            count(1);
+            return b & 0xFF;
         }
-    }
-
-    private long readCrc() throws IOException {
-        final byte[] b = new byte[4];
-        final int read = IOUtils.readFully(inputStream, b);
-        count(read);
-        if (read != 4) {
-            throw new IOException("Premature end of stream");
-        }
-        return ByteUtils.fromLittleEndian(b);
-    }
-
-    static long unmask(long x) {
-        // ugly, maybe we should just have used ints and deal with the
-        // overflow
-        x -= MASK_OFFSET;
-        x &= 0xffffFFFFL;
-        return ((x >> 17) | (x << 15)) & 0xffffFFFFL;
+        return -1;
     }
 
     private int readSize() throws IOException {
         return (int) ByteUtils.fromLittleEndian(supplier, 3);
     }
 
+    private void readStreamIdentifier() throws IOException {
+        final byte[] b = new byte[10];
+        final int read = IOUtils.readFully(inputStream, b);
+        count(read);
+        if (10 != read || !matches(b, 10)) {
+            throw new IOException("Not a framed Snappy stream");
+        }
+    }
+
     private void skipBlock() throws IOException {
         final int size = readSize();
         if (size < 0) {
@@ -309,24 +350,6 @@ public class FramedSnappyCompressorInputStream extends CompressorInputStream
         }
     }
 
-    private void readStreamIdentifier() throws IOException {
-        final byte[] b = new byte[10];
-        final int read = IOUtils.readFully(inputStream, b);
-        count(read);
-        if (10 != read || !matches(b, 10)) {
-            throw new IOException("Not a framed Snappy stream");
-        }
-    }
-
-    private int readOneByte() throws IOException {
-        final int b = inputStream.read();
-        if (b != -1) {
-            count(1);
-            return b & 0xFF;
-        }
-        return -1;
-    }
-
     private void verifyLastChecksumAndReset() throws IOException {
         if (expectedChecksum >= 0 && expectedChecksum != checksum.getValue()) {
             throw new IOException("Checksum verification failed");
@@ -335,28 +358,4 @@ public class FramedSnappyCompressorInputStream extends CompressorInputStream
         checksum.reset();
     }
 
-    /**
-     * Checks if the signature matches what is expected for a .sz file.
-     *
-     * <p>.sz files start with a chunk with tag 0xff and content sNaPpY.</p>
-     *
-     * @param signature the bytes to check
-     * @param length    the number of bytes to check
-     * @return          true if this is a .sz stream, false otherwise
-     */
-    public static boolean matches(final byte[] signature, final int length) {
-
-        if (length < SZ_SIGNATURE.length) {
-            return false;
-        }
-
-        byte[] shortenedSig = signature;
-        if (signature.length > SZ_SIGNATURE.length) {
-            shortenedSig = new byte[SZ_SIGNATURE.length];
-            System.arraycopy(signature, 0, shortenedSig, 0, SZ_SIGNATURE.length);
-        }
-
-        return Arrays.equals(shortenedSig, SZ_SIGNATURE);
-    }
-
 }
