@@ -64,7 +64,6 @@ import org.apache.commons.compress.utils.ExactMath;
  * character in the name ({@link #BYTE1}, {@link #UNSIGNED5}) gives a clue as to the B value. Those that start with U
  * ({@link #UDELTA5}, {@link #UNSIGNED5}) are unsigned; otherwise, in most cases, they are signed. The presence of the
  * word Delta ({@link #DELTA5}, {@link #UDELTA5}) indicates a delta encoding is used.
- *
  */
 public final class BHSDCodec extends Codec {
 
@@ -187,12 +186,12 @@ public final class BHSDCodec extends Codec {
             result = cardinality() / 2 - 1;
             break;
         case 2:
-            result = (3L * cardinality()) / 4 - 1;
+            result = 3L * cardinality() / 4 - 1;
             break;
         default:
             throw new Error("Unknown s value");
         }
-        return Math.min((s == 0 ? ((long) Integer.MAX_VALUE) << 1 : Integer.MAX_VALUE) - 1, result);
+        return Math.min((s == 0 ? (long) Integer.MAX_VALUE << 1 : Integer.MAX_VALUE) - 1, result);
     }
 
     private long calculateSmallest() {
@@ -244,7 +243,7 @@ public final class BHSDCodec extends Codec {
         }
 
         if (isSigned()) {
-            final int u = ((1 << s) - 1);
+            final int u = (1 << s) - 1;
             if ((z & u) == u) {
                 z = z >>> s ^ -1L;
             } else {
@@ -255,7 +254,7 @@ public final class BHSDCodec extends Codec {
         // in for now for readability
         // if (isSigned()) {
         // long u = z;
-        // long twoPowS = (long)Math.pow(2, s);
+        // long twoPowS = (long) Math.pow(2, s);
         // double twoPowSMinusOne = twoPowS-1;
         // if (u % twoPowS < twoPowSMinusOne) {
         // if (cardinality < Math.pow(2, 32)) {
