@@ -31,23 +31,27 @@ import org.objectweb.asm.Label;
  */
 public class BcBands extends BandSet {
 
+    private static final int MULTIANEWARRAY = 197;
+    private static final int ALOAD_0 = 42;
+
+    private static final int WIDE = 196;
+
+    private static final int INVOKEINTERFACE = 185;
+    private static final int TABLESWITCH = 170;
+    private static final int IINC = 132;
+    private static final int LOOKUPSWITCH = 171;
+    private static final int endMarker = 255;
     private final CpBands cpBands;
+
     private final Segment segment;
-
-    public BcBands(final CpBands cpBands, final Segment segment, final int effort) {
-        super(effort, segment.getSegmentHeader());
-        this.cpBands = cpBands;
-        this.segment = segment;
-    }
-
     private final IntList bcCodes = new IntList();
     private final IntList bcCaseCount = new IntList();
     private final IntList bcCaseValue = new IntList();
     private final IntList bcByte = new IntList();
     private final IntList bcShort = new IntList();
     private final IntList bcLocal = new IntList();
-    
-    // Integers and/or Labels?
+
+    // Integers and Labels
     private final List bcLabel = new ArrayList();
     private final List<CPInt> bcIntref = new ArrayList<>();
     private final List<CPFloat> bcFloatRef = new ArrayList<>();
@@ -56,36 +60,30 @@ public class BcBands extends BandSet {
     private final List<CPString> bcStringRef = new ArrayList<>();
     private final List<CPClass> bcClassRef = new ArrayList<>();
     private final List<CPMethodOrField> bcFieldRef = new ArrayList<>();
+
     private final List<CPMethodOrField> bcMethodRef = new ArrayList<>();
     private final List<CPMethodOrField> bcIMethodRef = new ArrayList<>();
+
+    // Integers and CPMethodOrField
     private List bcThisField = new ArrayList<>();
+
     private final List bcSuperField = new ArrayList<>();
     private List bcThisMethod = new ArrayList<>();
     private List bcSuperMethod = new ArrayList<>();
     private List bcInitRef = new ArrayList<>();
-
     private String currentClass;
     private String superClass;
     private String currentNewClass;
-
-    private static final int MULTIANEWARRAY = 197;
-    private static final int ALOAD_0 = 42;
-    private static final int WIDE = 196;
-    private static final int INVOKEINTERFACE = 185;
-    private static final int TABLESWITCH = 170;
-    private static final int IINC = 132;
-    private static final int LOOKUPSWITCH = 171;
-    private static final int endMarker = 255;
-
     private final IntList bciRenumbering = new IntList();
+
     private final Map<Label, Integer> labelsToOffsets = new HashMap<>();
     private int byteCodeOffset;
     private int renumberedOffset;
     private final IntList bcLabelRelativeOffsets = new IntList();
-
-    public void setCurrentClass(final String name, final String superName) {
-        currentClass = name;
-        superClass = superName;
+    public BcBands(final CpBands cpBands, final Segment segment, final int effort) {
+        super(effort, segment.getSegmentHeader());
+        this.cpBands = cpBands;
+        this.segment = segment;
     }
 
     /**
@@ -99,6 +97,14 @@ public class BcBands extends BandSet {
         bcInitRef = getIndexInClassForConstructor(bcInitRef);
     }
 
+    private List<Integer> getIndexInClass(final List<CPMethodOrField> cPMethodOrFieldList) {
+        return cPMethodOrFieldList.stream().collect(Collectors.mapping(CPMethodOrField::getIndexInClass, Collectors.toList()));
+    }
+
+    private List<Integer> getIndexInClassForConstructor(final List<CPMethodOrField> cPMethodList) {
+        return cPMethodList.stream().collect(Collectors.mapping(CPMethodOrField::getIndexInClassForConstructor, Collectors.toList()));
+    }
+
     @Override
     public void pack(final OutputStream out) throws IOException, Pack200Exception {
         PackingUtils.log("Writing byte code bands...");
@@ -195,12 +201,20 @@ public class BcBands extends BandSet {
         // out.write(encodeBandInt(integerListToArray(bcEscByte), Codec.BYTE1));
     }
 
-    private List<Integer> getIndexInClass(final List<CPMethodOrField> cPMethodOrFieldList) {
-        return cPMethodOrFieldList.stream().collect(Collectors.mapping(CPMethodOrField::getIndexInClass, Collectors.toList()));
+    public void setCurrentClass(final String name, final String superName) {
+        currentClass = name;
+        superClass = superName;
     }
 
-    private List<Integer> getIndexInClassForConstructor(final List<CPMethodOrField> cPMethodList) {
-        return cPMethodList.stream().collect(Collectors.mapping(CPMethodOrField::getIndexInClassForConstructor, Collectors.toList()));
+    private void updateRenumbering() {
+        if (bciRenumbering.isEmpty()) {
+            bciRenumbering.add(0);
+        }
+        renumberedOffset++;
+        for (int i = bciRenumbering.size(); i < byteCodeOffset; i++) {
+            bciRenumbering.add(-1);
+        }
+        bciRenumbering.add(renumberedOffset);
     }
 
     public void visitEnd() {
@@ -236,15 +250,11 @@ public class BcBands extends BandSet {
         }
     }
 
-    public void visitLabel(final Label label) {
-        labelsToOffsets.put(label, Integer.valueOf(byteCodeOffset));
-    }
-
     public void visitFieldInsn(int opcode, final String owner, final String name, final String desc) {
         byteCodeOffset += 3;
         updateRenumbering();
         boolean aload_0 = false;
-        if (bcCodes.size() > 0 && (bcCodes.get(bcCodes.size() - 1)) == ALOAD_0) {
+        if (bcCodes.size() > 0 && bcCodes.get(bcCodes.size() - 1) == ALOAD_0) {
             bcCodes.remove(bcCodes.size() - 1);
             aload_0 = true;
         }
@@ -271,17 +281,6 @@ public class BcBands extends BandSet {
         bcCodes.add(opcode);
     }
 
-    private void updateRenumbering() {
-        if (bciRenumbering.isEmpty()) {
-            bciRenumbering.add(0);
-        }
-        renumberedOffset++;
-        for (int i = bciRenumbering.size(); i < byteCodeOffset; i++) {
-            bciRenumbering.add(-1);
-        }
-        bciRenumbering.add(renumberedOffset);
-    }
-
     public void visitIincInsn(final int var, final int increment) {
         if (var > 255 || increment > 255) {
             byteCodeOffset += 6;
@@ -331,6 +330,10 @@ public class BcBands extends BandSet {
         updateRenumbering();
     }
 
+    public void visitLabel(final Label label) {
+        labelsToOffsets.put(label, Integer.valueOf(byteCodeOffset));
+    }
+
     public void visitLdcInsn(final Object cst) {
         final CPConstant<?> constant = cpBands.getConstant(cst);
         if (segment.lastConstantHadWideIndex() || constant instanceof CPLong || constant instanceof CPDouble) {
@@ -385,7 +388,7 @@ public class BcBands extends BandSet {
             bcLabel.add(labels[i]);
             bcLabelRelativeOffsets.add(byteCodeOffset);
         }
-        final int padding = (byteCodeOffset + 1) % 4 == 0 ? 0 : 4 - ((byteCodeOffset + 1) % 4);
+        final int padding = (byteCodeOffset + 1) % 4 == 0 ? 0 : 4 - (byteCodeOffset + 1) % 4;
         byteCodeOffset += 1 + padding + 8 + 8 * keys.length;
         updateRenumbering();
     }
@@ -397,7 +400,7 @@ public class BcBands extends BandSet {
         case 183: // invokespecial
         case 184: // invokestatic
             boolean aload_0 = false;
-            if (bcCodes.size() > 0 && (bcCodes.get(bcCodes.size() - 1)) == (ALOAD_0)) {
+            if (bcCodes.size() > 0 && bcCodes.get(bcCodes.size() - 1) == ALOAD_0) {
                 bcCodes.remove(bcCodes.size() - 1);
                 aload_0 = true;
                 opcode += 7;
@@ -467,8 +470,8 @@ public class BcBands extends BandSet {
             bcLabel.add(labels[i]);
             bcLabelRelativeOffsets.add(byteCodeOffset);
         }
-        final int padding = byteCodeOffset % 4 == 0 ? 0 : 4 - (byteCodeOffset % 4);
-        byteCodeOffset += (padding + 12 + 4 * labels.length);
+        final int padding = byteCodeOffset % 4 == 0 ? 0 : 4 - byteCodeOffset % 4;
+        byteCodeOffset += padding + 12 + 4 * labels.length;
         updateRenumbering();
     }
 
