@@ -66,6 +66,18 @@ public class CodecEncoding {
         new BHSDCodec(4, 240, 1, 1), new BHSDCodec(4, 248, 0, 1), new BHSDCodec(4, 248, 1, 1)};
 
     private static Map<BHSDCodec, Integer> canonicalCodecsToSpecifiers;
+    
+    static {
+        final HashMap<BHSDCodec, Integer> reverseMap = new HashMap<>(canonicalCodec.length);
+        for (int i = 0; i < canonicalCodec.length; i++) {
+            reverseMap.put(canonicalCodec[i], Integer.valueOf(i));
+        }
+        canonicalCodecsToSpecifiers = reverseMap;
+    }
+
+    public static BHSDCodec getCanonicalCodec(final int i) {
+        return canonicalCodec[i];
+    }
 
     /**
      * Returns the codec specified by the given value byte and optional byte header. If the value is &gt;= 116, then
@@ -104,8 +116,8 @@ public class CodecEncoding {
             if (code == -1) {
                 throw new EOFException("End of buffer read whilst trying to decode codec");
             }
-            final int d = (code & 0x01);
-            final int s = (code >> 1 & 0x03);
+            final int d = code & 0x01;
+            final int s = code >> 1 & 0x03;
             final int b = (code >> 3 & 0x07) + 1; // this might result in an invalid
             // number, but it's checked in the
             // Codec constructor
@@ -128,7 +140,7 @@ public class CodecEncoding {
             if (adef && bdef) {
                 throw new Pack200Exception("ADef and BDef should never both be true");
             }
-            final int kb = (kbflag ? in.read() : 3);
+            final int kb = kbflag ? in.read() : 3;
             final int k = (kb + 1) * (int) Math.pow(16, kx);
             Codec aCodec, bCodec;
             if (adef) {
@@ -143,7 +155,7 @@ public class CodecEncoding {
             }
             return new RunCodec(k, aCodec, bCodec);
         }
-        if ((value < 141) || (value > 188)) {
+        if (value < 141 || value > 188) {
             throw new Pack200Exception("Invalid codec encoding byte (" + value + ") found");
         }
         final int offset = value - 141;
@@ -158,8 +170,8 @@ public class CodecEncoding {
         // which
         // they are read from the stream is important
         if (tdef) {
-            final Codec fCodec = (fdef ? defaultCodec : getCodec(in.read(), in, defaultCodec));
-            final Codec uCodec = (udef ? defaultCodec : getCodec(in.read(), in, defaultCodec));
+            final Codec fCodec = fdef ? defaultCodec : getCodec(in.read(), in, defaultCodec);
+            final Codec uCodec = udef ? defaultCodec : getCodec(in.read(), in, defaultCodec);
             // Unfortunately, if tdef, then tCodec depends both on l and
             // also on k, the
             // number of items read from the fCodec. So we don't know in
@@ -167,26 +179,13 @@ public class CodecEncoding {
             // the codec will be.
             return new PopulationCodec(fCodec, l, uCodec);
         }
-        final Codec fCodec = (fdef ? defaultCodec : getCodec(in.read(), in, defaultCodec));
+        final Codec fCodec = fdef ? defaultCodec : getCodec(in.read(), in, defaultCodec);
         final Codec tCodec = getCodec(in.read(), in, defaultCodec);
-        final Codec uCodec = (udef ? defaultCodec : getCodec(in.read(), in, defaultCodec));
+        final Codec uCodec = udef ? defaultCodec : getCodec(in.read(), in, defaultCodec);
         return new PopulationCodec(fCodec, tCodec, uCodec);
     }
 
-    public static int getSpecifierForDefaultCodec(final BHSDCodec defaultCodec) {
-        return getSpecifier(defaultCodec, null)[0];
-    }
-
     public static int[] getSpecifier(final Codec codec, final Codec defaultForBand) {
-        // lazy initialization
-        if (canonicalCodecsToSpecifiers == null) {
-            final HashMap<BHSDCodec, Integer> reverseMap = new HashMap<>(canonicalCodec.length);
-            for (int i = 0; i < canonicalCodec.length; i++) {
-                reverseMap.put(canonicalCodec[i], Integer.valueOf(i));
-            }
-            canonicalCodecsToSpecifiers = reverseMap;
-        }
-
 		if (canonicalCodecsToSpecifiers.containsKey(codec)) {
 			return new int[] { canonicalCodecsToSpecifiers.get(codec).intValue() };
 		}
@@ -225,7 +224,7 @@ public class CodecEncoding {
             } else if (bCodec.equals(defaultForBand)) {
                 abDef = 2;
             }
-            final int first = 117 + kb + (kx == 3 ? 0 : 4) + (8 * abDef);
+            final int first = 117 + kb + (kx == 3 ? 0 : 4) + 8 * abDef;
             final int[] aSpecifier = abDef == 1 ? new int[0] : getSpecifier(aCodec, defaultForBand);
             final int[] bSpecifier = abDef == 2 ? new int[0] : getSpecifier(bCodec, defaultForBand);
             final int[] specifier = new int[1 + (kx == 3 ? 0 : 1) + aSpecifier.length + bSpecifier.length];
@@ -235,11 +234,11 @@ public class CodecEncoding {
                 specifier[1] = kx;
                 index++;
             }
-            for (int element : aSpecifier) {
+            for (final int element : aSpecifier) {
                 specifier[index] = element;
                 index++;
             }
-            for (int element : bSpecifier) {
+            for (final int element : bSpecifier) {
                 specifier[index] = element;
                 index++;
             }
@@ -270,7 +269,7 @@ public class CodecEncoding {
                     }
                 }
             }
-            final int first = 141 + fDef + (2 * uDef) + (4 * tDefL);
+            final int first = 141 + fDef + 2 * uDef + 4 * tDefL;
             final int[] favouredSpecifier = fDef == 1 ? new int[0] : getSpecifier(favouredCodec, defaultForBand);
             final int[] tokenSpecifier = tDefL != 0 ? new int[0] : getSpecifier(tokenCodec, defaultForBand);
             final int[] unfavouredSpecifier = uDef == 1 ? new int[0] : getSpecifier(unfavouredCodec, defaultForBand);
@@ -278,15 +277,15 @@ public class CodecEncoding {
                 + tokenSpecifier.length];
             specifier[0] = first;
             int index = 1;
-            for (int element : favouredSpecifier) {
+            for (final int element : favouredSpecifier) {
                 specifier[index] = element;
                 index++;
             }
-            for (int element : tokenSpecifier) {
+            for (final int element : tokenSpecifier) {
                 specifier[index] = element;
                 index++;
             }
-            for (int element : unfavouredSpecifier) {
+            for (final int element : unfavouredSpecifier) {
                 specifier[index] = element;
                 index++;
             }
@@ -296,7 +295,7 @@ public class CodecEncoding {
         return null;
     }
 
-    public static BHSDCodec getCanonicalCodec(final int i) {
-        return canonicalCodec[i];
+    public static int getSpecifierForDefaultCodec(final BHSDCodec defaultCodec) {
+        return getSpecifier(defaultCodec, null)[0];
     }
 }
