@@ -32,7 +32,7 @@ public class MetadataBandGroup extends BandSet {
     public static final int CONTEXT_METHOD = 2;
 
     private final String type;
-    private int numBackwardsCalls = 0;
+    private int numBackwardsCalls;
 
     public IntList param_NB = new IntList(); // TODO: Lazy instantiation?
     public IntList anno_N = new IntList();
@@ -73,6 +73,182 @@ public class MetadataBandGroup extends BandSet {
         this.context = context;
     }
 
+    /**
+     * Add an annotation to this set of bands
+     *
+     * @param desc TODO
+     * @param nameRU TODO
+     * @param tags TODO
+     * @param values TODO
+     * @param caseArrayN TODO
+     * @param nestTypeRS TODO
+     * @param nestNameRU TODO
+     * @param nestPairN TODO
+     */
+	public void addAnnotation(final String desc, final List<String> nameRU, final List<String> tags,
+			final List<Object> values, final List<Integer> caseArrayN, final List<String> nestTypeRS,
+			final List<String> nestNameRU, final List<Integer> nestPairN) {
+		type_RS.add(cpBands.getCPSignature(desc));
+		pair_N.add(nameRU.size());
+		nameRU.forEach(name -> name_RU.add(cpBands.getCPUtf8(name)));
+
+		final Iterator<Object> valuesIterator = values.iterator();
+		for (final String tag : tags) {
+			T.add(tag);
+            switch (tag) {
+                case "B":
+                case "C":
+                case "I":
+                case "S":
+                case "Z": {
+                    caseI_KI.add(cpBands.getConstant(valuesIterator.next()));
+                    break;
+                }
+                case "D": {
+                    caseD_KD.add(cpBands.getConstant(valuesIterator.next()));
+                    break;
+                }
+                case "F": {
+                    caseF_KF.add(cpBands.getConstant(valuesIterator.next()));
+                    break;
+                }
+                case "J": {
+                    caseJ_KJ.add(cpBands.getConstant(valuesIterator.next()));
+                    break;
+                }
+                case "c": {
+                    casec_RS.add(cpBands.getCPSignature(nextString(valuesIterator)));
+                    break;
+                }
+                case "e": {
+                    caseet_RS.add(cpBands.getCPSignature(nextString(valuesIterator)));
+                    caseec_RU.add(cpBands.getCPUtf8(nextString(valuesIterator)));
+                    break;
+                }
+                case "s": {
+                    cases_RU.add(cpBands.getCPUtf8(nextString(valuesIterator)));
+                    break;
+                }
+            }
+			// do nothing here for [ or @ (handled below)
+		}
+		for (final Integer element : caseArrayN) {
+			final int arraySize = element.intValue();
+			casearray_N.add(arraySize);
+			numBackwardsCalls += arraySize;
+		}
+		nestTypeRS.forEach(element -> nesttype_RS.add(cpBands.getCPSignature(element)));
+		nestNameRU.forEach(element -> nestname_RU.add(cpBands.getCPUtf8(element)));
+		for (final Integer numPairs : nestPairN) {
+			nestpair_N.add(numPairs.intValue());
+			numBackwardsCalls += numPairs.intValue();
+		}
+	}
+
+    /**
+     * Add an annotation to this set of bands.
+     *
+     * @param numParams TODO
+     * @param annoN TODO
+     * @param pairN TODO
+     * @param typeRS TODO
+     * @param nameRU TODO
+     * @param tags TODO
+     * @param values TODO
+     * @param caseArrayN TODO
+     * @param nestTypeRS TODO
+     * @param nestNameRU TODO
+     * @param nestPairN TODO
+     */
+	public void addParameterAnnotation(final int numParams, final int[] annoN, final IntList pairN,
+			final List<String> typeRS, final List<String> nameRU, final List<String> tags, final List<Object> values,
+			final List<Integer> caseArrayN, final List<String> nestTypeRS, final List<String> nestNameRU,
+			final List<Integer> nestPairN) {
+		param_NB.add(numParams);
+		for (final int element : annoN) {
+			anno_N.add(element);
+		}
+		pair_N.addAll(pairN);
+        typeRS.forEach(desc -> type_RS.add(cpBands.getCPSignature(desc)));
+        nameRU.forEach(name -> name_RU.add(cpBands.getCPUtf8(name)));
+		final Iterator<Object> valuesIterator = values.iterator();
+		for (final String tag : tags) {
+			T.add(tag);
+            switch (tag) {
+                case "B":
+                case "C":
+                case "I":
+                case "S":
+                case "Z": {
+                    caseI_KI.add(cpBands.getConstant(valuesIterator.next()));
+                    break;
+                }
+                case "D": {
+                    caseD_KD.add(cpBands.getConstant(valuesIterator.next()));
+                    break;
+                }
+                case "F": {
+                    caseF_KF.add(cpBands.getConstant(valuesIterator.next()));
+                    break;
+                }
+                case "J": {
+                    caseJ_KJ.add(cpBands.getConstant(valuesIterator.next()));
+                    break;
+                }
+                case "c": {
+                    casec_RS.add(cpBands.getCPSignature(nextString(valuesIterator)));
+                    break;
+                }
+                case "e": {
+                    caseet_RS.add(cpBands.getCPSignature(nextString(valuesIterator)));
+                    caseec_RU.add(cpBands.getCPUtf8(nextString(valuesIterator)));
+                    break;
+                }
+                case "s": {
+                    cases_RU.add(cpBands.getCPUtf8(nextString(valuesIterator)));
+                    break;
+                }
+            }
+			// do nothing here for [ or @ (handled below)
+		}
+		for (final Integer element : caseArrayN) {
+			final int arraySize = element.intValue();
+			casearray_N.add(arraySize);
+			numBackwardsCalls += arraySize;
+		}
+		nestTypeRS.forEach(type -> nesttype_RS.add(cpBands.getCPSignature(type)));
+		nestNameRU.forEach(name -> nestname_RU.add(cpBands.getCPUtf8(name)));
+		for (final Integer numPairs : nestPairN) {
+			nestpair_N.add(numPairs.intValue());
+			numBackwardsCalls += numPairs.intValue();
+		}
+	}
+
+    /**
+     * Returns true if any annotations have been added to this set of bands.
+     *
+     * @return true if any annotations have been added to this set of bands.
+     */
+    public boolean hasContent() {
+        return type_RS.size() > 0;
+    }
+
+    public void incrementAnnoN() {
+        anno_N.increment(anno_N.size() - 1);
+    }
+
+    public void newEntryInAnnoN() {
+        anno_N.add(1);
+    }
+
+    private String nextString(final Iterator<Object> valuesIterator) {
+        return (String) valuesIterator.next();
+    }
+
+    public int numBackwardsCalls() {
+        return numBackwardsCalls;
+    }
+
     /*
      * (non-Javadoc)
      *
@@ -90,7 +266,7 @@ public class MetadataBandGroup extends BandSet {
             } else {
                 contextStr = "Method";
             }
-            byte[] encodedBand = null;
+            byte[] encodedBand;
             if (!type.equals("AD")) {
                 if (type.indexOf('P') != -1) {
                     // Parameter annotation so we need to transmit param_NB
@@ -199,178 +375,6 @@ public class MetadataBandGroup extends BandSet {
         }
     }
 
-    private int[] tagListToArray(final List<String> list) {
-        return list.stream().mapToInt(s -> s.charAt(0)).toArray();
-    }
-
-    /**
-     * Add an annotation to this set of bands.
-     *
-     * @param numParams TODO
-     * @param annoN TODO
-     * @param pairN TODO
-     * @param typeRS TODO
-     * @param nameRU TODO
-     * @param t TODO
-     * @param values TODO
-     * @param caseArrayN TODO
-     * @param nestTypeRS TODO
-     * @param nestNameRU TODO
-     * @param nestPairN TODO
-     */
-	public void addParameterAnnotation(final int numParams, final int[] annoN, final IntList pairN,
-			final List<String> typeRS, final List<String> nameRU, final List<String> t, final List<Object> values,
-			final List<Integer> caseArrayN, final List<String> nestTypeRS, final List<String> nestNameRU,
-			final List<Integer> nestPairN) {
-		param_NB.add(numParams);
-		for (int element : annoN) {
-			anno_N.add(element);
-		}
-		pair_N.addAll(pairN);
-		for (String desc : typeRS) {
-			type_RS.add(cpBands.getCPSignature(desc));
-		}
-		for (String name : nameRU) {
-			name_RU.add(cpBands.getCPUtf8(name));
-		}
-		final Iterator<Object> valuesIterator = values.iterator();
-		for (String tag : t) {
-			T.add(tag);
-			if (tag.equals("B") || tag.equals("C") || tag.equals("I") || tag.equals("S") || tag.equals("Z")) {
-				final Integer value = (Integer) valuesIterator.next();
-				caseI_KI.add(cpBands.getConstant(value));
-			} else if (tag.equals("D")) {
-				final Double value = (Double) valuesIterator.next();
-				caseD_KD.add(cpBands.getConstant(value));
-			} else if (tag.equals("F")) {
-				final Float value = (Float) valuesIterator.next();
-				caseF_KF.add(cpBands.getConstant(value));
-			} else if (tag.equals("J")) {
-				final Long value = (Long) valuesIterator.next();
-				caseJ_KJ.add(cpBands.getConstant(value));
-			} else if (tag.equals("c")) {
-				final String value = (String) valuesIterator.next();
-				casec_RS.add(cpBands.getCPSignature(value));
-			} else if (tag.equals("e")) {
-				final String value = (String) valuesIterator.next();
-				final String value2 = (String) valuesIterator.next();
-				caseet_RS.add(cpBands.getCPSignature(value));
-				caseec_RU.add(cpBands.getCPUtf8(value2));
-			} else if (tag.equals("s")) {
-				final String value = (String) valuesIterator.next();
-				cases_RU.add(cpBands.getCPUtf8(value));
-			}
-			// do nothing here for [ or @ (handled below)
-		}
-		for (Integer element : caseArrayN) {
-			final int arraySize = element.intValue();
-			casearray_N.add(arraySize);
-			numBackwardsCalls += arraySize;
-		}
-		for (String type : nestTypeRS) {
-			nesttype_RS.add(cpBands.getCPSignature(type));
-		}
-		for (String name : nestNameRU) {
-			nestname_RU.add(cpBands.getCPUtf8(name));
-		}
-		for (Integer numPairs : nestPairN) {
-			nestpair_N.add(numPairs.intValue());
-			numBackwardsCalls += numPairs.intValue();
-		}
-	}
-
-    /**
-     * Add an annotation to this set of bands
-     *
-     * @param desc TODO
-     * @param nameRU TODO
-     * @param tags TODO
-     * @param values TODO
-     * @param caseArrayN TODO
-     * @param nestTypeRS TODO
-     * @param nestNameRU TODO
-     * @param nestPairN TODO
-     */
-	public void addAnnotation(final String desc, final List<String> nameRU, final List<String> tags,
-			final List<Object> values, final List<Integer> caseArrayN, final List<String> nestTypeRS,
-			final List<String> nestNameRU, final List<Integer> nestPairN) {
-		type_RS.add(cpBands.getCPSignature(desc));
-		pair_N.add(nameRU.size());
-
-		for (String name : nameRU) {
-			name_RU.add(cpBands.getCPUtf8(name));
-		}
-
-		final Iterator<Object> valuesIterator = values.iterator();
-		for (String tag : tags) {
-			T.add(tag);
-			if (tag.equals("B") || tag.equals("C") || tag.equals("I") || tag.equals("S") || tag.equals("Z")) {
-				final Integer value = (Integer) valuesIterator.next();
-				caseI_KI.add(cpBands.getConstant(value));
-			} else if (tag.equals("D")) {
-				final Double value = (Double) valuesIterator.next();
-				caseD_KD.add(cpBands.getConstant(value));
-			} else if (tag.equals("F")) {
-				final Float value = (Float) valuesIterator.next();
-				caseF_KF.add(cpBands.getConstant(value));
-			} else if (tag.equals("J")) {
-				final Long value = (Long) valuesIterator.next();
-				caseJ_KJ.add(cpBands.getConstant(value));
-			} else if (tag.equals("c")) {
-				final String value = (String) valuesIterator.next();
-				casec_RS.add(cpBands.getCPSignature(value));
-			} else if (tag.equals("e")) {
-				final String value = (String) valuesIterator.next();
-				final String value2 = (String) valuesIterator.next();
-				caseet_RS.add(cpBands.getCPSignature(value));
-				caseec_RU.add(cpBands.getCPUtf8(value2));
-			} else if (tag.equals("s")) {
-				final String value = (String) valuesIterator.next();
-				cases_RU.add(cpBands.getCPUtf8(value));
-			}
-			// do nothing here for [ or @ (handled below)
-		}
-		for (Integer element : caseArrayN) {
-			final int arraySize = element.intValue();
-			casearray_N.add(arraySize);
-			numBackwardsCalls += arraySize;
-		}
-		for (String element : nestTypeRS) {
-			final String type = element;
-			nesttype_RS.add(cpBands.getCPSignature(type));
-		}
-		for (String element : nestNameRU) {
-			final String name = element;
-			nestname_RU.add(cpBands.getCPUtf8(name));
-		}
-		for (Integer element : nestPairN) {
-			final Integer numPairs = element;
-			nestpair_N.add(numPairs.intValue());
-			numBackwardsCalls += numPairs.intValue();
-		}
-	}
-
-    /**
-     * Returns true if any annotations have been added to this set of bands.
-     *
-     * @return true if any annotations have been added to this set of bands.
-     */
-    public boolean hasContent() {
-        return type_RS.size() > 0;
-    }
-
-    public int numBackwardsCalls() {
-        return numBackwardsCalls;
-    }
-
-    public void incrementAnnoN() {
-        anno_N.increment(anno_N.size() - 1);
-    }
-
-    public void newEntryInAnnoN() {
-        anno_N.add(1);
-    }
-
     /**
      * Remove the latest annotation that was added to this group
      */
@@ -390,35 +394,50 @@ public class MetadataBandGroup extends BandSet {
      */
     private void removeOnePair() {
         final String tag = T.remove(T.size() - 1);
-        if (tag.equals("B") || tag.equals("C") || tag.equals("I") || tag.equals("S") || tag.equals("Z")) {
-            caseI_KI.remove(caseI_KI.size() - 1);
-        } else if (tag.equals("D")) {
-            caseD_KD.remove(caseD_KD.size() - 1);
-        } else if (tag.equals("F")) {
-            caseF_KF.remove(caseF_KF.size() - 1);
-        } else if (tag.equals("J")) {
-            caseJ_KJ.remove(caseJ_KJ.size() - 1);
-        } else if (tag.equals("C")) {
-            casec_RS.remove(casec_RS.size() - 1);
-        } else if (tag.equals("e")) {
-            caseet_RS.remove(caseet_RS.size() - 1);
-            caseec_RU.remove(caseet_RS.size() - 1);
-        } else if (tag.equals("s")) {
-            cases_RU.remove(cases_RU.size() - 1);
-        } else if (tag.equals("[")) {
-            final int arraySize = casearray_N.remove(casearray_N.size() - 1);
-            numBackwardsCalls -= arraySize;
-            for (int k = 0; k < arraySize; k++) {
-                removeOnePair();
-            }
-        } else if (tag.equals("@")) {
-            nesttype_RS.remove(nesttype_RS.size() - 1);
-            final int numPairs = nestpair_N.remove(nestpair_N.size() - 1);
-            numBackwardsCalls -= numPairs;
-            for (int i = 0; i < numPairs; i++) {
-                removeOnePair();
-            }
+        switch (tag) {
+            case "B":
+            case "C":
+            case "I":
+            case "S":
+            case "Z":
+                caseI_KI.remove(caseI_KI.size() - 1);
+                break;
+            case "D":
+                caseD_KD.remove(caseD_KD.size() - 1);
+                break;
+            case "F":
+                caseF_KF.remove(caseF_KF.size() - 1);
+                break;
+            case "J":
+                caseJ_KJ.remove(caseJ_KJ.size() - 1);
+                break;
+            case "e":
+                caseet_RS.remove(caseet_RS.size() - 1);
+                caseec_RU.remove(caseet_RS.size() - 1);
+                break;
+            case "s":
+                cases_RU.remove(cases_RU.size() - 1);
+                break;
+            case "[":
+                final int arraySize = casearray_N.remove(casearray_N.size() - 1);
+                numBackwardsCalls -= arraySize;
+                for (int k = 0; k < arraySize; k++) {
+                    removeOnePair();
+                }
+                break;
+            case "@":
+                nesttype_RS.remove(nesttype_RS.size() - 1);
+                final int numPairs = nestpair_N.remove(nestpair_N.size() - 1);
+                numBackwardsCalls -= numPairs;
+                for (int i = 0; i < numPairs; i++) {
+                    removeOnePair();
+                }
+                break;
         }
     }
 
+    private int[] tagListToArray(final List<String> list) {
+        return list.stream().mapToInt(s -> s.charAt(0)).toArray();
+    }
+
 }
