@@ -16,10 +16,12 @@
  */
 package org.apache.commons.compress.harmony.pack200;
 
+import java.nio.file.FileSystems;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 
 import org.objectweb.asm.Attribute;
 
@@ -28,7 +30,7 @@ import org.objectweb.asm.Attribute;
  */
 public class PackingOptions {
 
-    private static final Attribute[] EMPTY_ATTRIBUTE_ARRAY = new Attribute[0];
+    private static final Attribute[] EMPTY_ATTRIBUTE_ARRAY = {};
     public static final long SEGMENT_LIMIT = 1_000_000L;
     public static final String STRIP = "strip";
     public static final String ERROR = "error";
@@ -73,8 +75,9 @@ public class PackingOptions {
     private void addOrUpdateAttributeActions(final List<Attribute> prototypes, final Map<String, String> attributeActions, final int tag) {
         if (attributeActions != null && attributeActions.size() > 0) {
             NewAttribute newAttribute;
-            for (final String name : attributeActions.keySet()) {
-                final String action = attributeActions.get(name);
+            for (final Entry<String, String> entry : attributeActions.entrySet()) {
+                final String name = entry.getKey();
+                final String action = entry.getValue();
                 boolean prototypeExists = false;
                 for (final Object prototype : prototypes) {
                     newAttribute = (NewAttribute) prototype;
@@ -109,7 +112,7 @@ public class PackingOptions {
      * @param passFileName the file name
      */
     public void addPassFile(String passFileName) {
-        String fileSeparator = System.getProperty("file.separator");
+        String fileSeparator = FileSystems.getDefault().getSeparator();
         if (fileSeparator.equals("\\")) {
             // Need to escape backslashes for replaceAll(), which uses regex
             fileSeparator += "\\";
