@@ -43,15 +43,6 @@ import org.apache.commons.compress.utils.ExactMath;
  */
 public abstract class BandSet {
 
-    public abstract void read(InputStream inputStream) throws IOException, Pack200Exception;
-
-    public abstract void unpack() throws IOException, Pack200Exception;
-
-    public void unpack(final InputStream in) throws IOException, Pack200Exception {
-        read(in);
-        unpack();
-    }
-
     protected Segment segment;
 
     protected SegmentHeader header;
@@ -76,7 +67,7 @@ public abstract class BandSet {
         throws IOException, Pack200Exception {
         int[] band;
         // Useful for debugging
-//        if(count > 0) {
+//        if (count > 0) {
 //            System.out.println("decoding " + name + " " + count);
 //        }
         Codec codecUsed = codec;
@@ -90,7 +81,7 @@ public abstract class BandSet {
         final int first = getFirst[0];
         if (codec.isSigned() && first >= -256 && first <= -1) {
             // Non-default codec should be used
-            codecUsed = CodecEncoding.getCodec((-1 - first), header.getBandHeadersInputStream(), codec);
+            codecUsed = CodecEncoding.getCodec(-1 - first, header.getBandHeadersInputStream(), codec);
             band = codecUsed.decodeInts(count, in);
         } else if (!codec.isSigned() && first >= codec.getL() && first <= codec.getL() + 255) {
             // Non-default codec should be used
@@ -101,7 +92,7 @@ public abstract class BandSet {
             band = codec.decodeInts(count - 1, in, first);
         }
         // Useful for debugging -E options:
-        // if(!codecUsed.equals(codec)) {
+        // if (!codecUsed.equals(codec)) {
         // int bytes = codecUsed.lastBandLength;
         // System.out.println(count + " " + name + " encoded with " + codecUsed + " " + bytes);
         // }
@@ -142,7 +133,7 @@ public abstract class BandSet {
         final int[] counts) throws IOException, Pack200Exception {
         final int[][] result = new int[counts.length][];
         int totalCount = 0;
-        for (int count : counts) {
+        for (final int count : counts) {
             totalCount += count;
         }
         final int[] twoDResult = decodeBandInt(name, in, defaultCodec, totalCount);
@@ -157,14 +148,207 @@ public abstract class BandSet {
         return result;
     }
 
-    public long[] parseFlags(final String name, final InputStream in, final int count, final BHSDCodec codec,
-        final boolean hasHi) throws IOException, Pack200Exception {
-        return parseFlags(name, in, new int[] {count}, (hasHi ? codec : null), codec)[0];
+    protected String[] getReferences(final int[] ints, final String[] reference) {
+        final String[] result = new String[ints.length];
+        Arrays.setAll(result, i -> reference[ints[i]]);
+        return result;
     }
 
-    public long[][] parseFlags(final String name, final InputStream in, final int[] counts, final BHSDCodec codec,
-        final boolean hasHi) throws IOException, Pack200Exception {
-        return parseFlags(name, in, counts, (hasHi ? codec : null), codec);
+    protected String[][] getReferences(final int[][] ints, final String[] reference) {
+        final String[][] result = new String[ints.length][];
+        for (int i = 0; i < result.length; i++) {
+            result[i] = new String[ints[i].length];
+            for (int j = 0; j < result[i].length; j++) {
+                result[i][j] = reference[ints[i][j]];
+            }
+        }
+        return result;
+    }
+
+    public CPClass[] parseCPClassReferences(final String name, final InputStream in, final BHSDCodec codec,
+        final int count) throws IOException, Pack200Exception {
+        final int[] indices = decodeBandInt(name, in, codec, count);
+        final CPClass[] result = new CPClass[indices.length];
+        for (int i1 = 0; i1 < count; i1++) {
+            result[i1] = segment.getCpBands().cpClassValue(indices[i1]);
+        }
+        return result;
+    }
+
+    public CPNameAndType[] parseCPDescriptorReferences(final String name, final InputStream in, final BHSDCodec codec,
+        final int count) throws IOException, Pack200Exception {
+        final CpBands cpBands = segment.getCpBands();
+        final int[] indices = decodeBandInt(name, in, codec, count);
+        final CPNameAndType[] result = new CPNameAndType[indices.length];
+        for (int i1 = 0; i1 < count; i1++) {
+            final int index = indices[i1];
+            result[i1] = cpBands.cpNameAndTypeValue(index);
+        }
+        return result;
+    }
+
+    public CPDouble[] parseCPDoubleReferences(final String name, final InputStream in, final BHSDCodec codec,
+        final int count) throws IOException, Pack200Exception {
+        final int[] indices = decodeBandInt(name, in, codec, count);
+        final CPDouble[] result = new CPDouble[indices.length];
+        for (int i1 = 0; i1 < count; i1++) {
+            result[i1] = segment.getCpBands().cpDoubleValue(indices[i1]);
+        }
+        return result;
+    }
+
+    public CPFieldRef[] parseCPFieldRefReferences(final String name, final InputStream in, final BHSDCodec codec,
+        final int count) throws IOException, Pack200Exception {
+        final CpBands cpBands = segment.getCpBands();
+        final int[] indices = decodeBandInt(name, in, codec, count);
+        final CPFieldRef[] result = new CPFieldRef[indices.length];
+        for (int i1 = 0; i1 < count; i1++) {
+            final int index = indices[i1];
+            result[i1] = cpBands.cpFieldValue(index);
+        }
+        return result;
+    }
+
+    public CPFloat[] parseCPFloatReferences(final String name, final InputStream in, final BHSDCodec codec,
+        final int count) throws IOException, Pack200Exception {
+        final int[] indices = decodeBandInt(name, in, codec, count);
+        final CPFloat[] result = new CPFloat[indices.length];
+        for (int i1 = 0; i1 < count; i1++) {
+            result[i1] = segment.getCpBands().cpFloatValue(indices[i1]);
+        }
+        return result;
+    }
+
+    public CPInterfaceMethodRef[] parseCPInterfaceMethodRefReferences(final String name, final InputStream in,
+        final BHSDCodec codec, final int count) throws IOException, Pack200Exception {
+        final CpBands cpBands = segment.getCpBands();
+        final int[] indices = decodeBandInt(name, in, codec, count);
+        final CPInterfaceMethodRef[] result = new CPInterfaceMethodRef[indices.length];
+        for (int i1 = 0; i1 < count; i1++) {
+            result[i1] = cpBands.cpIMethodValue(indices[i1]);
+        }
+        return result;
+    }
+
+    public CPInteger[] parseCPIntReferences(final String name, final InputStream in, final BHSDCodec codec,
+        final int count) throws IOException, Pack200Exception {
+        final int[] reference = segment.getCpBands().getCpInt();
+        final int[] indices = decodeBandInt(name, in, codec, count);
+        final CPInteger[] result = new CPInteger[indices.length];
+        for (int i1 = 0; i1 < count; i1++) {
+            final int index = indices[i1];
+            if (index < 0 || index >= reference.length) {
+                throw new Pack200Exception("Something has gone wrong during parsing references, index = " + index
+                    + ", array size = " + reference.length);
+            }
+            result[i1] = segment.getCpBands().cpIntegerValue(index);
+        }
+        return result;
+    }
+
+    public CPLong[] parseCPLongReferences(final String name, final InputStream in, final BHSDCodec codec,
+        final int count) throws IOException, Pack200Exception {
+        final long[] reference = segment.getCpBands().getCpLong();
+        final int[] indices = decodeBandInt(name, in, codec, count);
+        final CPLong[] result = new CPLong[indices.length];
+        for (int i1 = 0; i1 < count; i1++) {
+            final int index = indices[i1];
+            if (index < 0 || index >= reference.length) {
+                throw new Pack200Exception("Something has gone wrong during parsing references, index = " + index
+                    + ", array size = " + reference.length);
+            }
+            result[i1] = segment.getCpBands().cpLongValue(index);
+        }
+        return result;
+    }
+
+    public CPMethodRef[] parseCPMethodRefReferences(final String name, final InputStream in, final BHSDCodec codec,
+        final int count) throws IOException, Pack200Exception {
+        final CpBands cpBands = segment.getCpBands();
+        final int[] indices = decodeBandInt(name, in, codec, count);
+        final CPMethodRef[] result = new CPMethodRef[indices.length];
+        for (int i1 = 0; i1 < count; i1++) {
+            result[i1] = cpBands.cpMethodValue(indices[i1]);
+        }
+        return result;
+    }
+
+    public CPUTF8[] parseCPSignatureReferences(final String name, final InputStream in, final BHSDCodec codec,
+        final int count) throws IOException, Pack200Exception {
+        final int[] indices = decodeBandInt(name, in, codec, count);
+        final CPUTF8[] result = new CPUTF8[indices.length];
+        for (int i1 = 0; i1 < count; i1++) {
+            result[i1] = segment.getCpBands().cpSignatureValue(indices[i1]);
+        }
+        return result;
+    }
+
+    protected CPUTF8[][] parseCPSignatureReferences(final String name, final InputStream in, final BHSDCodec codec,
+        final int[] counts) throws IOException, Pack200Exception {
+        final CPUTF8[][] result = new CPUTF8[counts.length][];
+        int sum = 0;
+        for (int i = 0; i < counts.length; i++) {
+            result[i] = new CPUTF8[counts[i]];
+            sum += counts[i];
+        }
+        final CPUTF8[] result1 = new CPUTF8[sum];
+        final int[] indices = decodeBandInt(name, in, codec, sum);
+        for (int i1 = 0; i1 < sum; i1++) {
+            result1[i1] = segment.getCpBands().cpSignatureValue(indices[i1]);
+        }
+        int pos = 0;
+        for (int i = 0; i < counts.length; i++) {
+            final int num = counts[i];
+            result[i] = new CPUTF8[num];
+            System.arraycopy(result1, pos, result[i], 0, num);
+            pos += num;
+        }
+        return result;
+    }
+
+    public CPString[] parseCPStringReferences(final String name, final InputStream in, final BHSDCodec codec,
+        final int count) throws IOException, Pack200Exception {
+        final int[] indices = decodeBandInt(name, in, codec, count);
+        final CPString[] result = new CPString[indices.length];
+        for (int i1 = 0; i1 < count; i1++) {
+            result[i1] = segment.getCpBands().cpStringValue(indices[i1]);
+        }
+        return result;
+    }
+
+    public CPUTF8[] parseCPUTF8References(final String name, final InputStream in, final BHSDCodec codec,
+        final int count) throws IOException, Pack200Exception {
+        final int[] indices = decodeBandInt(name, in, codec, count);
+        final CPUTF8[] result = new CPUTF8[indices.length];
+        for (int i1 = 0; i1 < count; i1++) {
+            final int index = indices[i1];
+            result[i1] = segment.getCpBands().cpUTF8Value(index);
+        }
+        return result;
+    }
+
+    public CPUTF8[][] parseCPUTF8References(final String name, final InputStream in, final BHSDCodec codec,
+        final int[] counts) throws IOException, Pack200Exception {
+        final CPUTF8[][] result = new CPUTF8[counts.length][];
+        int sum = 0;
+        for (int i = 0; i < counts.length; i++) {
+            result[i] = new CPUTF8[counts[i]];
+            sum += counts[i];
+        }
+        final CPUTF8[] result1 = new CPUTF8[sum];
+        final int[] indices = decodeBandInt(name, in, codec, sum);
+        for (int i1 = 0; i1 < sum; i1++) {
+            final int index = indices[i1];
+            result1[i1] = segment.getCpBands().cpUTF8Value(index);
+        }
+        int pos = 0;
+        for (int i = 0; i < counts.length; i++) {
+            final int num = counts[i];
+            result[i] = new CPUTF8[num];
+            System.arraycopy(result1, pos, result[i], 0, num);
+            pos += num;
+        }
+        return result;
     }
 
     public long[] parseFlags(final String name, final InputStream in, final int count, final BHSDCodec hiCodec,
@@ -172,6 +356,11 @@ public abstract class BandSet {
         return parseFlags(name, in, new int[] {count}, hiCodec, loCodec)[0];
     }
 
+    public long[] parseFlags(final String name, final InputStream in, final int count, final BHSDCodec codec,
+        final boolean hasHi) throws IOException, Pack200Exception {
+        return parseFlags(name, in, new int[] {count}, hasHi ? codec : null, codec)[0];
+    }
+
     public long[][] parseFlags(final String name, final InputStream in, final int[] counts, final BHSDCodec hiCodec,
         final BHSDCodec loCodec) throws IOException, Pack200Exception {
         final int count = counts.length;
@@ -188,16 +377,14 @@ public abstract class BandSet {
         int[] lo;
         if (hiCodec != null) {
             hi = decodeBandInt(name, in, hiCodec, sum);
-            lo = decodeBandInt(name, in, loCodec, sum);
-        } else {
-            lo = decodeBandInt(name, in, loCodec, sum);
         }
+        lo = decodeBandInt(name, in, loCodec, sum);
 
         int index = 0;
         for (int i = 0; i < result.length; i++) {
             for (int j = 0; j < result[i].length; j++) {
                 if (hi != null) {
-                    result[i][j] = ((long) hi[index] << 32) | (lo[index] & 4294967295L);
+                    result[i][j] = (long) hi[index] << 32 | lo[index] & 4294967295L;
                 } else {
                     result[i][j] = lo[index];
                 }
@@ -207,6 +394,11 @@ public abstract class BandSet {
         return result;
     }
 
+    public long[][] parseFlags(final String name, final InputStream in, final int[] counts, final BHSDCodec codec,
+        final boolean hasHi) throws IOException, Pack200Exception {
+        return parseFlags(name, in, counts, hasHi ? codec : null, codec);
+    }
+
     /**
      * Parses <i>count</i> references from {@code in}, using {@code codec} to decode the values as indexes
      * into {@code reference} (which is populated prior to this call). An exception is thrown if a decoded index
@@ -277,207 +469,13 @@ public abstract class BandSet {
         return result;
     }
 
-    public CPInteger[] parseCPIntReferences(final String name, final InputStream in, final BHSDCodec codec,
-        final int count) throws IOException, Pack200Exception {
-        final int[] reference = segment.getCpBands().getCpInt();
-        final int[] indices = decodeBandInt(name, in, codec, count);
-        final CPInteger[] result = new CPInteger[indices.length];
-        for (int i1 = 0; i1 < count; i1++) {
-            final int index = indices[i1];
-            if (index < 0 || index >= reference.length) {
-                throw new Pack200Exception("Something has gone wrong during parsing references, index = " + index
-                    + ", array size = " + reference.length);
-            }
-            result[i1] = segment.getCpBands().cpIntegerValue(index);
-        }
-        return result;
-    }
+    public abstract void read(InputStream inputStream) throws IOException, Pack200Exception;
 
-    public CPDouble[] parseCPDoubleReferences(final String name, final InputStream in, final BHSDCodec codec,
-        final int count) throws IOException, Pack200Exception {
-        final int[] indices = decodeBandInt(name, in, codec, count);
-        final CPDouble[] result = new CPDouble[indices.length];
-        for (int i1 = 0; i1 < count; i1++) {
-            result[i1] = segment.getCpBands().cpDoubleValue(indices[i1]);
-        }
-        return result;
-    }
+    public abstract void unpack() throws IOException, Pack200Exception;
 
-    public CPFloat[] parseCPFloatReferences(final String name, final InputStream in, final BHSDCodec codec,
-        final int count) throws IOException, Pack200Exception {
-        final int[] indices = decodeBandInt(name, in, codec, count);
-        final CPFloat[] result = new CPFloat[indices.length];
-        for (int i1 = 0; i1 < count; i1++) {
-            result[i1] = segment.getCpBands().cpFloatValue(indices[i1]);
-        }
-        return result;
-    }
-
-    public CPLong[] parseCPLongReferences(final String name, final InputStream in, final BHSDCodec codec,
-        final int count) throws IOException, Pack200Exception {
-        final long[] reference = segment.getCpBands().getCpLong();
-        final int[] indices = decodeBandInt(name, in, codec, count);
-        final CPLong[] result = new CPLong[indices.length];
-        for (int i1 = 0; i1 < count; i1++) {
-            final int index = indices[i1];
-            if (index < 0 || index >= reference.length) {
-                throw new Pack200Exception("Something has gone wrong during parsing references, index = " + index
-                    + ", array size = " + reference.length);
-            }
-            result[i1] = segment.getCpBands().cpLongValue(index);
-        }
-        return result;
-    }
-
-    public CPUTF8[] parseCPUTF8References(final String name, final InputStream in, final BHSDCodec codec,
-        final int count) throws IOException, Pack200Exception {
-        final int[] indices = decodeBandInt(name, in, codec, count);
-        final CPUTF8[] result = new CPUTF8[indices.length];
-        for (int i1 = 0; i1 < count; i1++) {
-            final int index = indices[i1];
-            result[i1] = segment.getCpBands().cpUTF8Value(index);
-        }
-        return result;
-    }
-
-    public CPUTF8[][] parseCPUTF8References(final String name, final InputStream in, final BHSDCodec codec,
-        final int[] counts) throws IOException, Pack200Exception {
-        final CPUTF8[][] result = new CPUTF8[counts.length][];
-        int sum = 0;
-        for (int i = 0; i < counts.length; i++) {
-            result[i] = new CPUTF8[counts[i]];
-            sum += counts[i];
-        }
-        final CPUTF8[] result1 = new CPUTF8[sum];
-        final int[] indices = decodeBandInt(name, in, codec, sum);
-        for (int i1 = 0; i1 < sum; i1++) {
-            final int index = indices[i1];
-            result1[i1] = segment.getCpBands().cpUTF8Value(index);
-        }
-        int pos = 0;
-        for (int i = 0; i < counts.length; i++) {
-            final int num = counts[i];
-            result[i] = new CPUTF8[num];
-            System.arraycopy(result1, pos, result[i], 0, num);
-            pos += num;
-        }
-        return result;
-    }
-
-    public CPString[] parseCPStringReferences(final String name, final InputStream in, final BHSDCodec codec,
-        final int count) throws IOException, Pack200Exception {
-        final int[] indices = decodeBandInt(name, in, codec, count);
-        final CPString[] result = new CPString[indices.length];
-        for (int i1 = 0; i1 < count; i1++) {
-            result[i1] = segment.getCpBands().cpStringValue(indices[i1]);
-        }
-        return result;
-    }
-
-    public CPInterfaceMethodRef[] parseCPInterfaceMethodRefReferences(final String name, final InputStream in,
-        final BHSDCodec codec, final int count) throws IOException, Pack200Exception {
-        final CpBands cpBands = segment.getCpBands();
-        final int[] indices = decodeBandInt(name, in, codec, count);
-        final CPInterfaceMethodRef[] result = new CPInterfaceMethodRef[indices.length];
-        for (int i1 = 0; i1 < count; i1++) {
-            result[i1] = cpBands.cpIMethodValue(indices[i1]);
-        }
-        return result;
-    }
-
-    public CPMethodRef[] parseCPMethodRefReferences(final String name, final InputStream in, final BHSDCodec codec,
-        final int count) throws IOException, Pack200Exception {
-        final CpBands cpBands = segment.getCpBands();
-        final int[] indices = decodeBandInt(name, in, codec, count);
-        final CPMethodRef[] result = new CPMethodRef[indices.length];
-        for (int i1 = 0; i1 < count; i1++) {
-            result[i1] = cpBands.cpMethodValue(indices[i1]);
-        }
-        return result;
-    }
-
-    public CPFieldRef[] parseCPFieldRefReferences(final String name, final InputStream in, final BHSDCodec codec,
-        final int count) throws IOException, Pack200Exception {
-        final CpBands cpBands = segment.getCpBands();
-        final int[] indices = decodeBandInt(name, in, codec, count);
-        final CPFieldRef[] result = new CPFieldRef[indices.length];
-        for (int i1 = 0; i1 < count; i1++) {
-            final int index = indices[i1];
-            result[i1] = cpBands.cpFieldValue(index);
-        }
-        return result;
-    }
-
-    public CPNameAndType[] parseCPDescriptorReferences(final String name, final InputStream in, final BHSDCodec codec,
-        final int count) throws IOException, Pack200Exception {
-        final CpBands cpBands = segment.getCpBands();
-        final int[] indices = decodeBandInt(name, in, codec, count);
-        final CPNameAndType[] result = new CPNameAndType[indices.length];
-        for (int i1 = 0; i1 < count; i1++) {
-            final int index = indices[i1];
-            result[i1] = cpBands.cpNameAndTypeValue(index);
-        }
-        return result;
-    }
-
-    public CPUTF8[] parseCPSignatureReferences(final String name, final InputStream in, final BHSDCodec codec,
-        final int count) throws IOException, Pack200Exception {
-        final int[] indices = decodeBandInt(name, in, codec, count);
-        final CPUTF8[] result = new CPUTF8[indices.length];
-        for (int i1 = 0; i1 < count; i1++) {
-            result[i1] = segment.getCpBands().cpSignatureValue(indices[i1]);
-        }
-        return result;
-    }
-
-    protected CPUTF8[][] parseCPSignatureReferences(final String name, final InputStream in, final BHSDCodec codec,
-        final int[] counts) throws IOException, Pack200Exception {
-        final CPUTF8[][] result = new CPUTF8[counts.length][];
-        int sum = 0;
-        for (int i = 0; i < counts.length; i++) {
-            result[i] = new CPUTF8[counts[i]];
-            sum += counts[i];
-        }
-        final CPUTF8[] result1 = new CPUTF8[sum];
-        final int[] indices = decodeBandInt(name, in, codec, sum);
-        for (int i1 = 0; i1 < sum; i1++) {
-            result1[i1] = segment.getCpBands().cpSignatureValue(indices[i1]);
-        }
-        int pos = 0;
-        for (int i = 0; i < counts.length; i++) {
-            final int num = counts[i];
-            result[i] = new CPUTF8[num];
-            System.arraycopy(result1, pos, result[i], 0, num);
-            pos += num;
-        }
-        return result;
-    }
-
-    public CPClass[] parseCPClassReferences(final String name, final InputStream in, final BHSDCodec codec,
-        final int count) throws IOException, Pack200Exception {
-        final int[] indices = decodeBandInt(name, in, codec, count);
-        final CPClass[] result = new CPClass[indices.length];
-        for (int i1 = 0; i1 < count; i1++) {
-            result[i1] = segment.getCpBands().cpClassValue(indices[i1]);
-        }
-        return result;
-    }
-
-    protected String[] getReferences(final int[] ints, final String[] reference) {
-        final String[] result = new String[ints.length];
-        Arrays.setAll(result, i -> reference[ints[i]]);
-        return result;
-    }
-
-    protected String[][] getReferences(final int[][] ints, final String[] reference) {
-        final String[][] result = new String[ints.length][];
-        for (int i = 0; i < result.length; i++) {
-            result[i] = new String[ints[i].length];
-            for (int j = 0; j < result[i].length; j++) {
-                result[i][j] = reference[ints[i][j]];
-            }
-        }
-        return result;
+    public void unpack(final InputStream in) throws IOException, Pack200Exception {
+        read(in);
+        unpack();
     }
 
 }
