@@ -19,6 +19,7 @@ package org.apache.commons.compress.harmony.unpack200.bytecode;
 import java.io.DataOutputStream;
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.List;
 
 import org.apache.commons.compress.harmony.pack200.Pack200Exception;
@@ -28,71 +29,42 @@ import org.apache.commons.compress.harmony.pack200.Pack200Exception;
  */
 public class LocalVariableTypeTableAttribute extends BCIRenumberedAttribute {
 
-    private final int local_variable_type_table_length;
-    private final int[] start_pcs;
-    private final int[] lengths;
-    private int[] name_indexes;
-    private int[] signature_indexes;
-    private final int[] indexes;
-    private final CPUTF8[] names;
-    private final CPUTF8[] signatures;
-    private int codeLength;
     private static CPUTF8 attributeName;
-
     public static void setAttributeName(final CPUTF8 cpUTF8Value) {
         attributeName = cpUTF8Value;
     }
+    private final int localVariableTypeTableLength;
+    private final int[] startPcs;
+    private final int[] lengths;
+    private int[] nameIndexes;
+    private int[] signatureIndexes;
+    private final int[] indexes;
+    private final CPUTF8[] names;
+    private final CPUTF8[] signatures;
 
-    public LocalVariableTypeTableAttribute(final int local_variable_type_table_length, final int[] start_pcs,
+    private int codeLength;
+
+    public LocalVariableTypeTableAttribute(final int localVariableTypeTableLength, final int[] startPcs,
         final int[] lengths, final CPUTF8[] names, final CPUTF8[] signatures, final int[] indexes) {
         super(attributeName);
-        this.local_variable_type_table_length = local_variable_type_table_length;
-        this.start_pcs = start_pcs;
+        this.localVariableTypeTableLength = localVariableTypeTableLength;
+        this.startPcs = startPcs;
         this.lengths = lengths;
         this.names = names;
         this.signatures = signatures;
         this.indexes = indexes;
     }
 
-    public void setCodeLength(final int length) {
-        codeLength = length;
-    }
-
     @Override
     protected int getLength() {
-        return 2 + (10 * local_variable_type_table_length);
-    }
-
-    @Override
-    protected void writeBody(final DataOutputStream dos) throws IOException {
-        dos.writeShort(local_variable_type_table_length);
-        for (int i = 0; i < local_variable_type_table_length; i++) {
-            dos.writeShort(start_pcs[i]);
-            dos.writeShort(lengths[i]);
-            dos.writeShort(name_indexes[i]);
-            dos.writeShort(signature_indexes[i]);
-            dos.writeShort(indexes[i]);
-        }
-    }
-
-    @Override
-    protected void resolve(final ClassConstantPool pool) {
-        super.resolve(pool);
-        name_indexes = new int[local_variable_type_table_length];
-        signature_indexes = new int[local_variable_type_table_length];
-        for (int i = 0; i < local_variable_type_table_length; i++) {
-            names[i].resolve(pool);
-            signatures[i].resolve(pool);
-            name_indexes[i] = pool.indexOf(names[i]);
-            signature_indexes[i] = pool.indexOf(signatures[i]);
-        }
+        return 2 + 10 * localVariableTypeTableLength;
     }
 
     @Override
     protected ClassFileEntry[] getNestedClassFileEntries() {
         final List<CPUTF8> nestedEntries = new ArrayList<>();
         nestedEntries.add(getAttributeName());
-        for (int i = 0; i < local_variable_type_table_length; i++) {
+        for (int i = 0; i < localVariableTypeTableLength; i++) {
             nestedEntries.add(names[i]);
             nestedEntries.add(signatures[i]);
         }
@@ -101,7 +73,7 @@ public class LocalVariableTypeTableAttribute extends BCIRenumberedAttribute {
 
     @Override
     protected int[] getStartPCs() {
-        return start_pcs;
+        return startPcs;
     }
 
     /*
@@ -111,34 +83,33 @@ public class LocalVariableTypeTableAttribute extends BCIRenumberedAttribute {
      */
     @Override
     public void renumber(final List<Integer> byteCodeOffsets) throws Pack200Exception {
-        // Remember the unrenumbered start_pcs, since that's used later
+        // Remember the unrenumbered startPcs, since that's used later
         // to calculate end position.
-        final int[] unrenumbered_start_pcs = new int[start_pcs.length];
-        System.arraycopy(start_pcs, 0, unrenumbered_start_pcs, 0, start_pcs.length);
+        final int[] unrenumberedStartPcs = Arrays.copyOf(startPcs, startPcs.length);
 
-        // Next renumber start_pcs in place
+        // Next renumber startPcs in place
         super.renumber(byteCodeOffsets);
 
         // lengths are BRANCH5 encoded, not BCI-encoded.
         // In other words:
-        // start_pc is BCI5 start_pc
-        // end_pc is byteCodeOffset[(index of start_pc in byteCodeOffset) +
+        // startPc is BCI5 startPc
+        // endPc is byteCodeOffset[(index of startPc in byteCodeOffset) +
         // (encoded length)]
-        // real length = end_pc - start_pc
-        // special case if end_pc is beyond end of bytecode array
+        // real length = endPc - startPc
+        // special case if endPc is beyond end of bytecode array
 
         final int maxSize = codeLength;
 
         // Iterate through the lengths and update each in turn.
         // This is done in place in the lengths array.
         for (int index = 0; index < lengths.length; index++) {
-            final int start_pc = start_pcs[index];
+            final int startPc = startPcs[index];
             int revisedLength = -1;
             final int encodedLength = lengths[index];
 
-            // First get the index of the start_pc in the byteCodeOffsets
-            final int indexOfStartPC = unrenumbered_start_pcs[index];
-            // Given the index of the start_pc, we can now add
+            // First get the index of the startPc in the byteCodeOffsets
+            final int indexOfStartPC = unrenumberedStartPcs[index];
+            // Given the index of the startPc, we can now add
             // the encodedLength to it to get the stop index.
             final int stopIndex = indexOfStartPC + encodedLength;
             if (stopIndex < 0) {
@@ -149,19 +120,48 @@ public class LocalVariableTypeTableAttribute extends BCIRenumberedAttribute {
             // end of the byte code offsets. Need to determine which this is.
             if (stopIndex == byteCodeOffsets.size()) {
                 // Pointing to one past the end of the byte code array
-                revisedLength = maxSize - start_pc;
+                revisedLength = maxSize - startPc;
             } else {
                 // We're indexed into the byte code array
                 final int stopValue = byteCodeOffsets.get(stopIndex).intValue();
-                revisedLength = stopValue - start_pc;
+                revisedLength = stopValue - startPc;
             }
             lengths[index] = revisedLength;
         }
     }
 
+    @Override
+    protected void resolve(final ClassConstantPool pool) {
+        super.resolve(pool);
+        nameIndexes = new int[localVariableTypeTableLength];
+        signatureIndexes = new int[localVariableTypeTableLength];
+        for (int i = 0; i < localVariableTypeTableLength; i++) {
+            names[i].resolve(pool);
+            signatures[i].resolve(pool);
+            nameIndexes[i] = pool.indexOf(names[i]);
+            signatureIndexes[i] = pool.indexOf(signatures[i]);
+        }
+    }
+
+    public void setCodeLength(final int length) {
+        codeLength = length;
+    }
+
     @Override
     public String toString() {
-        return "LocalVariableTypeTable: " + +local_variable_type_table_length + " varaibles";
+        return "LocalVariableTypeTable: " + +localVariableTypeTableLength + " varaibles";
+    }
+
+    @Override
+    protected void writeBody(final DataOutputStream dos) throws IOException {
+        dos.writeShort(localVariableTypeTableLength);
+        for (int i = 0; i < localVariableTypeTableLength; i++) {
+            dos.writeShort(startPcs[i]);
+            dos.writeShort(lengths[i]);
+            dos.writeShort(nameIndexes[i]);
+            dos.writeShort(signatureIndexes[i]);
+            dos.writeShort(indexes[i]);
+        }
     }
 
 }
