@@ -16,6 +16,7 @@
  */
 package org.apache.commons.compress.harmony.unpack200.bytecode.forms;
 
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
 
@@ -290,10 +291,14 @@ public abstract class ByteCodeForm {
         }
     }
 
+    public static ByteCodeForm get(final int opcode) {
+        return byteCodeArray[opcode];
+    }
     private final int opcode;
     private final String name;
     private final int[] rewrite;
     private int firstOperandIndex;
+
     private int operandLength;
 
     /**
@@ -362,43 +367,34 @@ public abstract class ByteCodeForm {
         operandLength = difference + 1;
     }
 
-    public static ByteCodeForm get(final int opcode) {
-        return byteCodeArray[opcode];
+    public int firstOperandIndex() {
+        return firstOperandIndex;
     }
 
-    @Override
-    public String toString() {
-        return this.getClass().getName() + "(" + getName() + ")";
-    }
-
-    public int getOpcode() {
-        return opcode;
+    /**
+     * The ByteCodeForm knows how to fix up a bytecode if it needs to be fixed up because it holds a Label bytecode.
+     *
+     * @param byteCode a ByteCode to be fixed up
+     * @param codeAttribute a CodeAttribute used to determine how the ByteCode should be fixed up.
+     */
+    public void fixUpByteCodeTargets(final ByteCode byteCode, final CodeAttribute codeAttribute) {
+        // Most ByteCodeForms don't have any fixing up to do.
     }
 
     public String getName() {
         return name;
     }
 
+    public int getOpcode() {
+        return opcode;
+    }
+
     public int[] getRewrite() {
         return rewrite;
     }
 
     public int[] getRewriteCopy() {
-        final int[] result = new int[rewrite.length];
-        System.arraycopy(rewrite, 0, result, 0, rewrite.length);
-        return result;
-    }
-
-    public int firstOperandIndex() {
-        return firstOperandIndex;
-    }
-
-    public int operandLength() {
-        return operandLength;
-    }
-
-    public boolean hasNoOperand() {
-        return false;
+        return Arrays.copyOf(rewrite, rewrite.length);
     }
 
     /**
@@ -410,15 +406,27 @@ public abstract class ByteCodeForm {
     public boolean hasMultipleByteCodes() {
         // Currently, all multi-bytecode instructions
         // begin with aload_0, so this is how we test.
-        if ((rewrite.length > 1) && (rewrite[0] == 42)) {
+        if (rewrite.length > 1 && rewrite[0] == 42) {
             // If there's an instruction (not a negative
             // number, which is an operand) after the
             // aload_0, it's a multibytecode instruction.
-            return (rewrite[1] > 0);
+            return rewrite[1] > 0;
         }
         return false;
     }
 
+    public boolean hasNoOperand() {
+        return false;
+    }
+
+    public boolean nestedMustStartClassPool() {
+        return false;
+    }
+
+    public int operandLength() {
+        return operandLength;
+    }
+
     /**
      * When passed a byteCode, an OperandTable and a SegmentConstantPool, this method will set the rewrite of the
      * byteCode appropriately.
@@ -430,18 +438,8 @@ public abstract class ByteCodeForm {
      */
     public abstract void setByteCodeOperands(ByteCode byteCode, OperandManager operandManager, int codeLength);
 
-    /**
-     * The ByteCodeForm knows how to fix up a bytecode if it needs to be fixed up because it holds a Label bytecode.
-     *
-     * @param byteCode a ByteCode to be fixed up
-     * @param codeAttribute a CodeAttribute used to determine how the ByteCode should be fixed up.
-     */
-    public void fixUpByteCodeTargets(final ByteCode byteCode, final CodeAttribute codeAttribute) {
-        // Most ByteCodeForms don't have any fixing up to do.
-        return;
-    }
-
-    public boolean nestedMustStartClassPool() {
-        return false;
+    @Override
+    public String toString() {
+        return this.getClass().getName() + "(" + getName() + ")";
     }
 }
