@@ -13,10 +13,10 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 package org.apache.commons.compress.utils;
 
+import java.io.FilterInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 
@@ -25,10 +25,9 @@ import java.io.InputStream;
  * @NotThreadSafe
  * @since 1.6
  */
-public class BoundedInputStream extends InputStream {
-    private final InputStream in;
+public class BoundedInputStream extends FilterInputStream {
     private long bytesRemaining;
-    
+
     /**
      * Creates the stream that will at most read the given amount of
      * bytes from the given stream.
@@ -36,22 +35,38 @@ public class BoundedInputStream extends InputStream {
      * @param size the maximum amount of bytes to read
      */
     public BoundedInputStream(final InputStream in, final long size) {
-        this.in = in;
+        super(in);
         bytesRemaining = size;
     }
-    
+
+    @Override
+    public void close() {
+        // there isn't anything to close in this stream and the nested
+        // stream is controlled externally
+    }
+
+    /**
+     * @return bytes remaining to read
+     * @since 1.21
+     */
+    public long getBytesRemaining() {
+        return bytesRemaining;
+    }
+
     @Override
     public int read() throws IOException {
         if (bytesRemaining > 0) {
             --bytesRemaining;
             return in.read();
-        } else {
-            return -1;
         }
+        return -1;
     }
 
     @Override
-    public int read(byte[] b, int off, int len) throws IOException {
+    public int read(final byte[] b, final int off, final int len) throws IOException {
+        if (len == 0) {
+            return 0;
+        }
         if (bytesRemaining == 0) {
             return -1;
         }
@@ -66,9 +81,15 @@ public class BoundedInputStream extends InputStream {
         return bytesRead;
     }
 
+    /**
+     * @since 1.20
+     */
     @Override
-    public void close() {
-        // there isn't anything to close in this stream and the nested
-        // stream is controlled externally
+    public long skip(final long n) throws IOException {
+        final long bytesToSkip = Math.min(bytesRemaining, n);
+        final long bytesSkipped = in.skip(bytesToSkip);
+        bytesRemaining -= bytesSkipped;
+
+        return bytesSkipped;
     }
 }
