@@ -13,7 +13,6 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- *
  */
 
 package org.apache.commons.compress.utils;
@@ -38,47 +37,48 @@ public class FileNameUtils {
     }
 
     /**
-     * Gets the basename (i.e. the part up to and not including the
-     * last ".") of the last path segment of a filename.
+     * Gets the base name (i.e. the part up to and not including the
+     * last ".") of the last path segment of a file name.
      * <p>Will return the file name itself if it doesn't contain any
-     * dots. All leading directories of the {@code filename} parameter
+     * dots. All leading directories of the {@code file name} parameter
      * are skipped.</p>
-     * @return the basename of filename
-     * @param path the path of the file to obtain the basename of.
+     * @return the base name of file name
+     * @param path the path of the file to obtain the base name of.
      * @since 1.22
      */
     public static String getBaseName(final Path path) {
         if (path == null) {
             return null;
         }
-        return fileNameToBaseName(path.getFileName().toString());
+        final Path fileName = path.getFileName();
+        return fileName != null ? fileNameToBaseName(fileName.toString()) : null;
     }
 
     /**
-     * Gets the basename (i.e. the part up to and not including the
-     * last ".") of the last path segment of a filename.
+     * Gets the base name (i.e. the part up to and not including the
+     * last ".") of the last path segment of a file name.
      *
      * <p>Will return the file name itself if it doesn't contain any
-     * dots. All leading directories of the {@code filename} parameter
+     * dots. All leading directories of the {@code file name} parameter
      * are skipped.</p>
      *
-     * @return the basename of filename
-     * @param filename the name of the file to obtain the basename of.
+     * @return the base name of file name
+     * @param fileName the name of the file to obtain the base name of.
      */
-    public static String getBaseName(final String filename) {
-        if (filename == null) {
+    public static String getBaseName(final String fileName) {
+        if (fileName == null) {
             return null;
         }
-        return fileNameToBaseName(new File(filename).getName());
+        return fileNameToBaseName(new File(fileName).getName());
     }
 
     /**
      * Gets the extension (i.e. the part after the last ".") of a file.
      * <p>Will return an empty string if the file name doesn't contain
      * any dots. Only the last segment of a the file name is consulted
-     * - i.e. all leading directories of the {@code filename}
+     * - i.e. all leading directories of the {@code file name}
      * parameter are skipped.</p>
-     * @return the extension of filename
+     * @return the extension of file name
      * @param path the path of the file to obtain the extension of.
      * @since 1.22
      */
@@ -86,7 +86,8 @@ public class FileNameUtils {
         if (path == null) {
             return null;
         }
-        return fileNameToExtension(path.getFileName().toString());
+        final Path fileName = path.getFileName();
+        return fileName != null ? fileNameToExtension(fileName.toString()) : null;
     }
 
     /**
@@ -94,16 +95,16 @@ public class FileNameUtils {
      *
      * <p>Will return an empty string if the file name doesn't contain
      * any dots. Only the last segment of a the file name is consulted
-     * - i.e. all leading directories of the {@code filename}
+     * - i.e. all leading directories of the {@code fileName}
      * parameter are skipped.</p>
      *
-     * @return the extension of filename
-     * @param filename the name of the file to obtain the extension of.
+     * @return the extension of file name
+     * @param fileName the name of the file to obtain the extension of.
      */
-    public static String getExtension(final String filename) {
-        if (filename == null) {
+    public static String getExtension(final String fileName) {
+        if (fileName == null) {
             return null;
         }
-        return fileNameToExtension(new File(filename).getName());
+        return fileNameToExtension(new File(fileName).getName());
     }
 }
