@@ -64,22 +64,6 @@ public class OsgiITest {
        };
     }
 
-    @Test
-    public void canLoadBundle() {
-        assertNotNull("Expected to find bundle " + EXPECTED_BUNDLE_NAME, loadBundle());
-    }
-
-    @Test
-    public void properlyDetectsRunningInsideOsgiEnv() throws Exception {
-        final Class<?> osgiUtils = loadBundle().loadClass("org.apache.commons.compress.utils.OsgiUtils");
-        assertNotNull("Can load OsgiUtils via bundle", osgiUtils);
-
-        final Method m = osgiUtils.getMethod("isRunningInOsgiEnvironment");
-        assertNotNull("Can access isRunningInOsgiEnvironment method", m);
-
-        assertTrue("Compress detects OSGi environment", (Boolean) m.invoke(null));
-    }
-
     private Bundle loadBundle() {
         for (final Bundle b : ctx.getBundles()) {
             if (EXPECTED_BUNDLE_NAME.equals(b.getSymbolicName())) {
@@ -88,4 +72,20 @@ public class OsgiITest {
         }
         return null;
     }
+
+    @Test
+    public void testCanLoadBundle() {
+        assertNotNull("Expected to find bundle " + EXPECTED_BUNDLE_NAME, loadBundle());
+    }
+
+    @Test
+    public void testProperlyDetectsRunningInsideOsgiEnv() throws Exception {
+        final Class<?> osgiUtils = loadBundle().loadClass("org.apache.commons.compress.utils.OsgiUtils");
+        assertNotNull("Can load OsgiUtils via bundle", osgiUtils);
+
+        final Method m = osgiUtils.getMethod("isRunningInOsgiEnvironment");
+        assertNotNull("Can access isRunningInOsgiEnvironment method", m);
+
+        assertTrue("Compress detects OSGi environment", (Boolean) m.invoke(null));
+    }
 }
