@@ -13,12 +13,10 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- *
  */
 
 package org.apache.commons.compress.archivers;
 
-import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
 
@@ -31,7 +29,7 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.stream.Stream;
 
-import org.apache.commons.compress.AbstractTestCase;
+import org.apache.commons.compress.AbstractTest;
 import org.apache.commons.compress.archivers.ar.ArArchiveInputStream;
 import org.apache.commons.compress.archivers.cpio.CpioArchiveInputStream;
 import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
@@ -45,10 +43,9 @@ import org.junit.jupiter.params.provider.MethodSource;
 /**
  * Test that can read various tar file examples.
  *
-  * Files must be in resources/longsymlink, and there must be a file.txt containing
- * the list of files in the archives.
-*/
-public class LongSymLinkTest extends AbstractTestCase {
+ * Files must be in resources/longsymlink, and there must be a file.txt containing the list of files in the archives.
+ */
+public class LongSymLinkTest extends AbstractTest {
 
     private static final ClassLoader CLASSLOADER = LongSymLinkTest.class.getClassLoader();
     private static final File ARCDIR;
@@ -73,19 +70,18 @@ public class LongSymLinkTest extends AbstractTestCase {
     @BeforeAll
     public static void setUpFileList() throws Exception {
         assertTrue(ARCDIR.exists());
-        final File listing= new File(ARCDIR,"files.txt");
+        final File listing = new File(ARCDIR, "files.txt");
         assertTrue(listing.canRead(), "files.txt is readable");
-        final BufferedReader br = new BufferedReader(Files.newBufferedReader(listing.toPath()));
-        String line;
-        while ((line=br.readLine())!=null){
-            if (!line.startsWith("#")){
-                FILELIST.add(line);
+        try (BufferedReader br = new BufferedReader(Files.newBufferedReader(listing.toPath()))) {
+            String line;
+            while ((line = br.readLine()) != null) {
+                if (!line.startsWith("#")) {
+                    FILELIST.add(line);
+                }
             }
         }
-        br.close();
     }
 
-
     @Override
     protected String getExpectedString(final ArchiveEntry entry) {
         if (entry instanceof TarArchiveEntry) {
@@ -101,49 +97,44 @@ public class LongSymLinkTest extends AbstractTestCase {
     @MethodSource("data")
     public void testArchive(final File file) throws Exception {
         @SuppressWarnings("unchecked") // fileList is of correct type
-        final
-        ArrayList<String> expected = (ArrayList<String>) FILELIST.clone();
+        final ArrayList<String> expected = (ArrayList<String>) FILELIST.clone();
         final String name = file.getName();
-        if ("minotaur.jar".equals(name) || "minotaur-0.jar".equals(name)){
+        if ("minotaur.jar".equals(name) || "minotaur-0.jar".equals(name)) {
             expected.add("META-INF/");
             expected.add("META-INF/MANIFEST.MF");
         }
-        final ArchiveInputStream ais = factory.createArchiveInputStream(new BufferedInputStream(Files.newInputStream(file.toPath())));
-        // check if expected type recognized
-        if (name.endsWith(".tar")){
-            assertTrue(ais instanceof TarArchiveInputStream);
-        } else if (name.endsWith(".jar") || name.endsWith(".zip")){
-            assertTrue(ais instanceof ZipArchiveInputStream);
-        } else if (name.endsWith(".cpio")){
-            assertTrue(ais instanceof CpioArchiveInputStream);
-            // Hack: cpio does not add trailing "/" to directory names
-            for(int i=0; i < expected.size(); i++){
-                final String ent = expected.get(i);
-                if (ent.endsWith("/")){
-                    expected.set(i, ent.substring(0, ent.length()-1));
-                }
-            }
-        } else if (name.endsWith(".ar")){
-            assertTrue(ais instanceof ArArchiveInputStream);
-            // CPIO does not store directories or directory names
-            expected.clear();
-            for (final String ent : FILELIST) {
-                if (!ent.endsWith("/")) {// not a directory
-                    final int lastSlash = ent.lastIndexOf('/');
-                    if (lastSlash >= 0) { // extract path name
-                        expected.add(ent.substring(lastSlash + 1));
-                    } else {
-                        expected.add(ent);
+        try (ArchiveInputStream<?> ais = factory.createArchiveInputStream(new BufferedInputStream(Files.newInputStream(file.toPath())))) {
+            // check if expected type recognized
+            if (name.endsWith(".tar")) {
+                assertTrue(ais instanceof TarArchiveInputStream);
+            } else if (name.endsWith(".jar") || name.endsWith(".zip")) {
+                assertTrue(ais instanceof ZipArchiveInputStream);
+            } else if (name.endsWith(".cpio")) {
+                assertTrue(ais instanceof CpioArchiveInputStream);
+                // Hack: cpio does not add trailing "/" to directory names
+                for (int i = 0; i < expected.size(); i++) {
+                    final String ent = expected.get(i);
+                    if (ent.endsWith("/")) {
+                        expected.set(i, ent.substring(0, ent.length() - 1));
                     }
                 }
+            } else if (name.endsWith(".ar")) {
+                assertTrue(ais instanceof ArArchiveInputStream);
+                // CPIO does not store directories or directory names
+                expected.clear();
+                for (final String ent : FILELIST) {
+                    if (!ent.endsWith("/")) {// not a directory
+                        final int lastSlash = ent.lastIndexOf('/');
+                        if (lastSlash >= 0) { // extract path name
+                            expected.add(ent.substring(lastSlash + 1));
+                        } else {
+                            expected.add(ent);
+                        }
+                    }
+                }
+            } else {
+                fail("Unexpected file type: " + name);
             }
-        } else {
-            fail("Unexpected file type: "+name);
-        }
-        try {
-            assertDoesNotThrow(() -> checkArchiveContent(ais, expected), "Error processing " + file.getName());
-        } finally {
-            ais.close();
         }
     }
 }
