@@ -13,7 +13,6 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 
 package org.apache.commons.compress.archivers.ar;
@@ -29,26 +28,25 @@ import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.compress.AbstractTestCase;
+import org.apache.commons.compress.AbstractTest;
 import org.junit.jupiter.api.Test;
 
-public class ArArchiveOutputStreamTest extends AbstractTestCase {
+public class ArArchiveOutputStreamTest extends AbstractTest {
 
     @Test
     public void testLongFileNamesCauseExceptionByDefault() throws IOException {
         try (ArArchiveOutputStream os = new ArArchiveOutputStream(new ByteArrayOutputStream())) {
             final ArArchiveEntry ae = new ArArchiveEntry("this_is_a_long_name.txt", 0);
-            final IOException ex = assertThrows(IOException.class, () -> os.putArchiveEntry(ae),
-                    "Expected an exception");
+            final IOException ex = assertThrows(IOException.class, () -> os.putArchiveEntry(ae), "Expected an exception");
             assertTrue(ex.getMessage().startsWith("File name too long"));
         }
     }
 
     @Test
     public void testLongFileNamesWorkUsingBSDDialect() throws Exception {
-        final File[] df = createTempDirAndFile();
-        try (OutputStream fos = Files.newOutputStream(df[1].toPath());
-             ArArchiveOutputStream os = new ArArchiveOutputStream(fos)) {
+        final File file = createTempFile();
+        try (OutputStream fos = Files.newOutputStream(file.toPath());
+                ArArchiveOutputStream os = new ArArchiveOutputStream(fos)) {
             os.setLongFileMode(ArArchiveOutputStream.LONGFILE_BSD);
             final ArArchiveEntry ae = new ArArchiveEntry("this_is_a_long_name.txt", 14);
             os.putArchiveEntry(ae);
@@ -57,9 +55,7 @@ public class ArArchiveOutputStreamTest extends AbstractTestCase {
 
             final List<String> expected = new ArrayList<>();
             expected.add("this_is_a_long_name.txt");
-            checkArchiveContent(df[1], expected);
-        } finally {
-            rmdir(df[0]);
+            checkArchiveContent(file, expected);
         }
     }
 }
