@@ -26,26 +26,6 @@ import org.junit.jupiter.api.Test;
 
 public class CpioUtilTest {
 
-    @Test
-    public void oldBinMagic2ByteArrayNotSwapped() {
-        assertArrayEquals(new byte[] {(byte) 0xc7, 0x71}, CpioUtil.long2byteArray(CpioConstants.MAGIC_OLD_BINARY, 2, false));
-    }
-
-    @Test
-    public void oldBinMagic2ByteArraySwapped() {
-        assertArrayEquals(new byte[] {0x71, (byte) 0xc7,}, CpioUtil.long2byteArray(CpioConstants.MAGIC_OLD_BINARY, 2, true));
-    }
-
-    @Test
-    public void oldBinMagicFromByteArrayNotSwapped() {
-        assertEquals(CpioConstants.MAGIC_OLD_BINARY, CpioUtil.byteArray2long(new byte[] {(byte) 0xc7, 0x71}, false));
-    }
-
-    @Test
-    public void oldBinMagicFromByteArraySwapped() {
-        assertEquals(CpioConstants.MAGIC_OLD_BINARY, CpioUtil.byteArray2long(new byte[] {0x71, (byte) 0xc7}, true));
-    }
-
     @Test
     public void testByteArray2longThrowsUnsupportedOperationException() {
         assertThrows(UnsupportedOperationException.class, () -> CpioUtil.byteArray2long(new byte[1], true));
@@ -62,4 +42,24 @@ public class CpioUtilTest {
         assertThrows(UnsupportedOperationException.class, () -> CpioUtil.long2byteArray(0L, 0, false));
     }
 
+    @Test
+    public void testOldBinMagic2ByteArrayNotSwapped() {
+        assertArrayEquals(new byte[] {(byte) 0xc7, 0x71}, CpioUtil.long2byteArray(CpioConstants.MAGIC_OLD_BINARY, 2, false));
+    }
+
+    @Test
+    public void testOldBinMagic2ByteArraySwapped() {
+        assertArrayEquals(new byte[] {0x71, (byte) 0xc7,}, CpioUtil.long2byteArray(CpioConstants.MAGIC_OLD_BINARY, 2, true));
+    }
+
+    @Test
+    public void testOldBinMagicFromByteArrayNotSwapped() {
+        assertEquals(CpioConstants.MAGIC_OLD_BINARY, CpioUtil.byteArray2long(new byte[] {(byte) 0xc7, 0x71}, false));
+    }
+
+    @Test
+    public void testOldBinMagicFromByteArraySwapped() {
+        assertEquals(CpioConstants.MAGIC_OLD_BINARY, CpioUtil.byteArray2long(new byte[] {0x71, (byte) 0xc7}, true));
+    }
+
 }
