@@ -25,7 +25,7 @@ import org.junit.jupiter.api.Test;
 public class DumpArchiveUtilTest {
 
     @Test
-    public void convert16() {
+    public void testConvert16() {
         assertEquals(0xABCD,
                      DumpArchiveUtil.convert16(new byte[] {
                              (byte) 0xCD, (byte) 0xAB
@@ -33,7 +33,7 @@ public class DumpArchiveUtilTest {
     }
 
     @Test
-    public void convert32() {
+    public void testConvert32() {
         assertEquals(0xABCDEF01,
                      DumpArchiveUtil.convert32(new byte[] {
                              1, (byte) 0xEF, (byte) 0xCD, (byte) 0xAB
@@ -41,7 +41,7 @@ public class DumpArchiveUtilTest {
     }
 
     @Test
-    public void convert64() {
+    public void testConvert64() {
         assertEquals(0xABCDEF0123456780L,
                      DumpArchiveUtil.convert64(new byte[] {
                              (byte) 0x80, 0x67, 0x45, 0x23, 1, (byte) 0xEF,
