@@ -28,7 +28,6 @@ import java.io.ObjectInputStream;
 
 import org.junit.jupiter.api.Test;
 
-
 /**
  * Unit tests for class {@link AES256SHA256Decoder}.
  *
@@ -36,23 +35,22 @@ import org.junit.jupiter.api.Test;
  **/
 public class AES256SHA256DecoderTest {
 
-
     @Test
-    public void testDecodeWithNonEmptyString() {
+    public void testDecodeWithNonEmptyString() throws IOException {
 
         final AES256SHA256Decoder aES256SHA256Decoder = new AES256SHA256Decoder();
-        final BufferedInputStream bufferedInputStream = new BufferedInputStream(null, 3138);
-        final Coder coder = new Coder();
-        final byte[] byteArray = new byte[8];
-        byteArray[1] = (byte) (-72);
-        coder.properties = byteArray;
-        final InputStream inputStream = aES256SHA256Decoder.decode("x", bufferedInputStream, 3138, coder, coder.properties,
-                Integer.MAX_VALUE);
-
-        final IOException e = assertThrows(IOException.class, () -> new ObjectInputStream(inputStream), "Expecting exception: IOException");
-        assertEquals("Salt size + IV size too long in x", e.getMessage());
-        assertEquals("org.apache.commons.compress.archivers.sevenz.AES256SHA256Decoder$1", e.getStackTrace()[0].getClassName());
+        try (BufferedInputStream bufferedInputStream = new BufferedInputStream(null, 3138)) {
+            final Coder coder = new Coder();
+            final byte[] byteArray = new byte[8];
+            byteArray[1] = (byte) -72;
+            coder.properties = byteArray;
+            try (InputStream inputStream = aES256SHA256Decoder.decode("x", bufferedInputStream, 3138, coder, coder.properties, Integer.MAX_VALUE)) {
+                final IOException e = assertThrows(IOException.class, () -> new ObjectInputStream(inputStream), "Expecting exception: IOException");
+                assertEquals("Salt size + IV size too long in x", e.getMessage());
+                assertEquals("org.apache.commons.compress.archivers.sevenz.AES256SHA256Decoder$AES256SHA256DecoderInputStream",
+                        e.getStackTrace()[0].getClassName());
+            }
+        }
     }
 
-
 }
