@@ -19,16 +19,34 @@
 
 package org.apache.commons.compress.archivers.zip;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import org.junit.jupiter.api.Test;
 
 public class GeneralPurposeBitTest {
 
+    @Test
+    public void testClone() {
+        final GeneralPurposeBit b = new GeneralPurposeBit();
+        b.useStrongEncryption(true);
+        b.useUTF8ForNames(true);
+        assertEquals(b, b.clone());
+        assertNotSame(b, b.clone());
+    }
+
+    @Test
+    public void testDataDescriptor() {
+        final byte[] flags = {(byte) 8, (byte) 0};
+        assertTrue(GeneralPurposeBit.parse(flags, 0).usesDataDescriptor());
+        final GeneralPurposeBit b = new GeneralPurposeBit();
+        b.useDataDescriptor(true);
+        assertArrayEquals(flags, b.encode());
+    }
+
     @Test
     public void testDefaults() {
         assertFalse(new GeneralPurposeBit().usesDataDescriptor());
@@ -39,6 +57,24 @@ public class GeneralPurposeBitTest {
         assertArrayEquals(b, new GeneralPurposeBit().encode());
     }
 
+    @Test
+    public void testEncryption() {
+        final byte[] flags = {(byte) 1, (byte) 0};
+        assertTrue(GeneralPurposeBit.parse(flags, 0).usesEncryption());
+        final GeneralPurposeBit b = new GeneralPurposeBit();
+        b.useEncryption(true);
+        assertArrayEquals(flags, b.encode());
+    }
+
+    @Test
+    public void testLanguageEncodingFlag() {
+        final byte[] flags = {(byte) 0, (byte) 8};
+        assertTrue(GeneralPurposeBit.parse(flags, 0).usesUTF8ForNames());
+        final GeneralPurposeBit b = new GeneralPurposeBit();
+        b.useUTF8ForNames(true);
+        assertArrayEquals(flags, b.encode());
+    }
+
     @Test
     public void testParseEdgeCases() {
         assertFalse(GeneralPurposeBit.parse(new byte[2], 0)
@@ -63,36 +99,9 @@ public class GeneralPurposeBitTest {
                    .usesStrongEncryption());
     }
 
-    @Test
-    public void testDataDescriptor() {
-        final byte[] flags = new byte[] {(byte) 8, (byte) 0};
-        assertTrue(GeneralPurposeBit.parse(flags, 0).usesDataDescriptor());
-        final GeneralPurposeBit b = new GeneralPurposeBit();
-        b.useDataDescriptor(true);
-        assertArrayEquals(flags, b.encode());
-    }
-
-    @Test
-    public void testLanguageEncodingFlag() {
-        final byte[] flags = new byte[] {(byte) 0, (byte) 8};
-        assertTrue(GeneralPurposeBit.parse(flags, 0).usesUTF8ForNames());
-        final GeneralPurposeBit b = new GeneralPurposeBit();
-        b.useUTF8ForNames(true);
-        assertArrayEquals(flags, b.encode());
-    }
-
-    @Test
-    public void testEncryption() {
-        final byte[] flags = new byte[] {(byte) 1, (byte) 0};
-        assertTrue(GeneralPurposeBit.parse(flags, 0).usesEncryption());
-        final GeneralPurposeBit b = new GeneralPurposeBit();
-        b.useEncryption(true);
-        assertArrayEquals(flags, b.encode());
-    }
-
     @Test
     public void testStrongEncryption() {
-        byte[] flags = new byte[] {(byte) 65, (byte) 0};
+        byte[] flags = {(byte) 65, (byte) 0};
         assertTrue(GeneralPurposeBit.parse(flags, 0).usesStrongEncryption());
         final GeneralPurposeBit b = new GeneralPurposeBit();
         b.useStrongEncryption(true);
@@ -102,13 +111,4 @@ public class GeneralPurposeBitTest {
         flags = new byte[] {(byte) 64, (byte) 0};
         assertFalse(GeneralPurposeBit.parse(flags, 0).usesStrongEncryption());
     }
-
-    @Test
-    public void testClone() {
-        final GeneralPurposeBit b = new GeneralPurposeBit();
-        b.useStrongEncryption(true);
-        b.useUTF8ForNames(true);
-        assertEquals(b, b.clone());
-        assertNotSame(b, b.clone());
-    }
 }
