@@ -13,7 +13,6 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 
 package org.apache.commons.compress.archivers.zip;
@@ -24,7 +23,7 @@ import static org.junit.jupiter.api.Assertions.assertThrows;
 import java.io.IOException;
 import java.io.InputStream;
 
-import org.apache.commons.compress.AbstractTestCase;
+import org.apache.commons.compress.AbstractTest;
 import org.apache.commons.compress.archivers.ArchiveEntry;
 import org.junit.jupiter.api.Test;
 
@@ -40,9 +39,8 @@ import org.junit.jupiter.api.Test;
  * such a file. This test is intended to prove that this error doesn't occur
  * anymore. All entries but the last one are returned correctly, the last entry
  * yields an exception.
- *
  */
-public class Maven221MultiVolumeTest extends AbstractTestCase {
+public class Maven221MultiVolumeTest extends AbstractTest {
 
     private static final String[] ENTRIES = {
         // @formatter:off
