@@ -13,11 +13,9 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 package org.apache.commons.compress.archivers.zip;
 
-import java.io.File;
 import java.io.IOException;
 import java.util.concurrent.ExecutionException;
 
@@ -26,9 +24,10 @@ import org.apache.commons.compress.parallel.InputStreamSupplier;
 public class ScatterSample {
 
     final ParallelScatterZipCreator scatterZipCreator = new ParallelScatterZipCreator();
-    final ScatterZipOutputStream dirs = ScatterZipOutputStream.fileBased(File.createTempFile("scatter-dirs", "tmp"));
+    final ScatterZipOutputStream dirs;
 
-    public ScatterSample() throws IOException {
+    ScatterSample(final ScatterSampleTest scatterSampleTest) throws IOException {
+        this.dirs = ScatterZipOutputStream.fileBased(scatterSampleTest.createTempFile("scatter-dirs", "tmp"));
     }
 
     public void addEntry(final ZipArchiveEntry zipArchiveEntry, final InputStreamSupplier streamSupplier) throws IOException {
