@@ -13,42 +13,33 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 package org.apache.commons.compress.archivers.zip;
 
-import static org.apache.commons.compress.AbstractTestCase.tryHardToDelete;
 import static org.apache.commons.compress.archivers.zip.ZipArchiveEntryRequest.createZipArchiveEntryRequest;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
 import java.io.ByteArrayInputStream;
 import java.io.File;
+import java.io.InputStream;
 import java.util.zip.ZipEntry;
 
+import org.apache.commons.compress.AbstractTempDirTest;
 import org.apache.commons.compress.parallel.InputStreamSupplier;
 import org.apache.commons.compress.utils.IOUtils;
-import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.Test;
 
-public class ScatterZipOutputStreamTest {
-
-    private File scatterFile = null;
-    private File target = null;
-
-    @AfterEach
-    public void cleanup() {
-        tryHardToDelete(scatterFile);
-        tryHardToDelete(target);
-    }
+public class ScatterZipOutputStreamTest extends AbstractTempDirTest {
 
     private InputStreamSupplier createPayloadSupplier(final ByteArrayInputStream payload) {
         return () -> payload;
     }
 
     @Test
-    public void putArchiveEntry() throws Exception {
-        scatterFile = File.createTempFile("scattertest", ".notzip");
+    public void testPutArchiveEntry() throws Exception {
+        final File scatterFile = createTempFile("scattertest", ".notzip");
+        final File target = createTempFile("scattertest", ".zip");
         final byte[] B_PAYLOAD = "RBBBBBBS".getBytes();
         final byte[] A_PAYLOAD = "XAAY".getBytes();
         try (ScatterZipOutputStream scatterZipOutputStream = ScatterZipOutputStream.fileBased(scatterFile)) {
@@ -63,20 +54,23 @@ public class ScatterZipOutputStreamTest {
             final ByteArrayInputStream payload1 = new ByteArrayInputStream(A_PAYLOAD);
             scatterZipOutputStream.addArchiveEntry(createZipArchiveEntryRequest(zae, createPayloadSupplier(payload1)));
 
-            target = File.createTempFile("scattertest", ".zip");
             try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(target)) {
                 scatterZipOutputStream.writeTo(outputStream);
             }
         }
 
         try (ZipFile zf = new ZipFile(target)) {
-            final ZipArchiveEntry b_entry = zf.getEntries("b.txt").iterator().next();
-            assertEquals(8, b_entry.getSize());
-            assertArrayEquals(B_PAYLOAD, IOUtils.toByteArray(zf.getInputStream(b_entry)));
+            final ZipArchiveEntry bEntry = zf.getEntries("b.txt").iterator().next();
+            assertEquals(8, bEntry.getSize());
+            try (InputStream inputStream = zf.getInputStream(bEntry)) {
+                assertArrayEquals(B_PAYLOAD, IOUtils.toByteArray(inputStream));
+            }
 
-            final ZipArchiveEntry a_entry = zf.getEntries("a.txt").iterator().next();
-            assertEquals(4, a_entry.getSize());
-            assertArrayEquals(A_PAYLOAD, IOUtils.toByteArray(zf.getInputStream(a_entry)));
+            final ZipArchiveEntry aEntry = zf.getEntries("a.txt").iterator().next();
+            assertEquals(4, aEntry.getSize());
+            try (InputStream inputStream = zf.getInputStream(aEntry)) {
+                assertArrayEquals(A_PAYLOAD, IOUtils.toByteArray(inputStream));
+            }
         }
     }
 }
