@@ -13,12 +13,11 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 
 package org.apache.commons.compress.archivers.zip;
 
-import static org.apache.commons.compress.AbstractTestCase.getFile;
+import static org.apache.commons.compress.AbstractTest.getFile;
 import static org.junit.Assert.assertNull;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
@@ -41,7 +40,6 @@ import org.junit.jupiter.api.Test;
 
 /**
  * JUnit tests for org.apache.commons.compress.archivers.zip.ZipEntry.
- *
  */
 public class ZipArchiveEntryTest {
 
@@ -54,43 +52,6 @@ public class ZipArchiveEntryTest {
         assertEquals(extraFields.length, read.length);
     }
 
-    @Test
-    public void draconicThrowsOnUnparseableExtraData() throws Exception {
-        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
-        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
-        ze.setExtraFields(extraFields);
-        assertThrows(ZipException.class, () -> ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.DRACONIC));
-    }
-
-    /**
-     * @see "https://issues.apache.org/jira/browse/COMPRESS-379"
-     */
-    @Test
-    public void isUnixSymlinkIsFalseIfMoreThanOneFlagIsSet() throws Exception {
-        try (ZipFile zf = new ZipFile(getFile("COMPRESS-379.jar"))) {
-            final ZipArchiveEntry ze = zf.getEntry("META-INF/maven/");
-            assertFalse(ze.isUnixSymlink());
-        }
-    }
-
-    @Test
-    public void onlyParseableLenientExcludesUnparseableExtraData() throws Exception {
-        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
-        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
-        ze.setExtraFields(extraFields);
-        final ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.ONLY_PARSEABLE_LENIENT);
-        assertEquals(extraFields.length, read.length + 1);
-    }
-
-    @Test
-    public void onlyParseableStrictExcludesUnparseableExtraData() throws Exception {
-        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
-        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
-        ze.setExtraFields(extraFields);
-        final ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.ONLY_PARSEABLE_STRICT);
-        assertEquals(extraFields.length, read.length + 1);
-    }
-
     private ZipExtraField[] parsingModeBehaviorTestData() {
         final AsiExtraField a = new AsiExtraField();
         a.setDirectory(true);
@@ -106,24 +67,6 @@ public class ZipArchiveEntryTest {
         return new ZipExtraField[] { a, u, x };
     }
 
-    @Test
-    public void reparsingUnicodeExtraWithUnsupportedversionThrowsInStrictMode()
-        throws Exception {
-        try (ZipFile zf = new ZipFile(getFile("COMPRESS-479.zip"))) {
-            final ZipArchiveEntry ze = zf.getEntry("%U20AC_for_Dollar.txt");
-            assertThrows(ZipException.class, () -> ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.STRICT_FOR_KNOW_EXTRA_FIELDS));
-        }
-    }
-
-    @Test
-    public void strictForKnowExtraFieldsIncludesUnparseableExtraData() throws Exception {
-        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
-        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
-        ze.setExtraFields(extraFields);
-        final ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.STRICT_FOR_KNOW_EXTRA_FIELDS);
-        assertEquals(extraFields.length, read.length);
-    }
-
     /**
      * test handling of extra fields
      */
@@ -200,6 +143,14 @@ public class ZipArchiveEntryTest {
         assertEquals(archiveEntry, copy);
     }
 
+    @Test
+    public void testDraconicThrowsOnUnparseableExtraData() throws Exception {
+        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
+        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
+        ze.setExtraFields(extraFields);
+        assertThrows(ZipException.class, () -> ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.DRACONIC));
+    }
+
     /**
      * test handling of extra fields via central directory
      */
@@ -307,6 +258,17 @@ public class ZipArchiveEntryTest {
         assertFalse(ze.isUnixSymlink());
     }
 
+    /**
+     * @see "https://issues.apache.org/jira/browse/COMPRESS-379"
+     */
+    @Test
+    public void testIsUnixSymlinkIsFalseIfMoreThanOneFlagIsSet() throws Exception {
+        try (ZipFile zf = new ZipFile(getFile("COMPRESS-379.jar"))) {
+            final ZipArchiveEntry ze = zf.getEntry("META-INF/maven/");
+            assertFalse(ze.isUnixSymlink());
+        }
+    }
+
     /**
      * Test case for
      * <a href="https://issues.apache.org/jira/browse/COMPRESS-94"
@@ -336,6 +298,33 @@ public class ZipArchiveEntryTest {
         assertNotEquals(entry2, entry3);
     }
 
+    @Test
+    public void testOnlyParseableLenientExcludesUnparseableExtraData() throws Exception {
+        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
+        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
+        ze.setExtraFields(extraFields);
+        final ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.ONLY_PARSEABLE_LENIENT);
+        assertEquals(extraFields.length, read.length + 1);
+    }
+
+    @Test
+    public void testOnlyParseableStrictExcludesUnparseableExtraData() throws Exception {
+        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
+        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
+        ze.setExtraFields(extraFields);
+        final ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.ONLY_PARSEABLE_STRICT);
+        assertEquals(extraFields.length, read.length + 1);
+    }
+
+    @Test
+    public void testReparsingUnicodeExtraWithUnsupportedversionThrowsInStrictMode()
+        throws Exception {
+        try (ZipFile zf = new ZipFile(getFile("COMPRESS-479.zip"))) {
+            final ZipArchiveEntry ze = zf.getEntry("%U20AC_for_Dollar.txt");
+            assertThrows(ZipException.class, () -> ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.STRICT_FOR_KNOW_EXTRA_FIELDS));
+        }
+    }
+
     @Test
     public void testShouldNotSetExtraDateFieldsIfDateFitsInDosDates() {
         final ZipArchiveEntry ze = new ZipArchiveEntry();
@@ -492,6 +481,15 @@ public class ZipArchiveEntryTest {
         assertEquals(0L, ntfs.getCreateTime().getLongValue());
     }
 
+    @Test
+    public void testStrictForKnowExtraFieldsIncludesUnparseableExtraData() throws Exception {
+        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
+        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
+        ze.setExtraFields(extraFields);
+        final ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.STRICT_FOR_KNOW_EXTRA_FIELDS);
+        assertEquals(extraFields.length, read.length);
+    }
+
     @Test
     public void testUnixMode() {
         ZipArchiveEntry ze = new ZipArchiveEntry("foo");
@@ -499,13 +497,13 @@ public class ZipArchiveEntryTest {
         ze.setUnixMode(0755);
         assertEquals(3, ze.getPlatform());
         assertEquals(0755,
-                     (ze.getExternalAttributes() >> 16) & 0xFFFF);
+                     ze.getExternalAttributes() >> 16 & 0xFFFF);
         assertEquals(0, ze.getExternalAttributes()  & 0xFFFF);
 
         ze.setUnixMode(0444);
         assertEquals(3, ze.getPlatform());
         assertEquals(0444,
-                     (ze.getExternalAttributes() >> 16) & 0xFFFF);
+                     ze.getExternalAttributes() >> 16 & 0xFFFF);
         assertEquals(1, ze.getExternalAttributes()  & 0xFFFF);
 
         ze = new ZipArchiveEntry("foo/");
@@ -513,13 +511,13 @@ public class ZipArchiveEntryTest {
         ze.setUnixMode(0777);
         assertEquals(3, ze.getPlatform());
         assertEquals(0777,
-                     (ze.getExternalAttributes() >> 16) & 0xFFFF);
+                     ze.getExternalAttributes() >> 16 & 0xFFFF);
         assertEquals(0x10, ze.getExternalAttributes()  & 0xFFFF);
 
         ze.setUnixMode(0577);
         assertEquals(3, ze.getPlatform());
         assertEquals(0577,
-                     (ze.getExternalAttributes() >> 16) & 0xFFFF);
+                     ze.getExternalAttributes() >> 16 & 0xFFFF);
         assertEquals(0x11, ze.getExternalAttributes()  & 0xFFFF);
     }
 
