@@ -19,7 +19,7 @@
 
 package org.apache.commons.compress.compressors;
 
-import static org.junit.Assert.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -31,13 +31,13 @@ import org.junit.jupiter.api.Test;
 public class CompressorServiceLoaderTest {
 
     @Test
-    public void testInputStream() throws CompressorException {
+    public void testInputStream() {
         assertThrows(InvocationConfirmationException.class,
             () -> new CompressorStreamFactory().createCompressorInputStream("TestInput1", new ByteArrayInputStream(ArrayUtils.EMPTY_BYTE_ARRAY)));
     }
 
     @Test
-    public void testOutputStream() throws CompressorException {
+    public void testOutputStream() {
         assertThrows(InvocationConfirmationException.class,
             () -> new CompressorStreamFactory().createCompressorOutputStream("TestOutput1", new ByteArrayOutputStream()));
     }
