@@ -17,35 +17,42 @@
 
 package org.apache.commons.compress.compressors.brotli;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
-import java.io.OutputStream;
 import java.nio.file.Files;
 
-import org.apache.commons.compress.AbstractTestCase;
+import org.apache.commons.compress.AbstractTest;
 import org.apache.commons.compress.compressors.CompressorInputStream;
 import org.apache.commons.compress.compressors.CompressorStreamFactory;
 import org.apache.commons.compress.utils.IOUtils;
-import org.junit.Assert;
 import org.junit.jupiter.api.Test;
 
-public class BrotliCompressorInputStreamTest extends AbstractTestCase {
+public class BrotliCompressorInputStreamTest extends AbstractTest {
+
+    @Test
+    public void testAvailableShouldReturnZero() throws IOException {
+        try (InputStream is = newInputStream("brotli.testdata.compressed");
+                final BrotliCompressorInputStream in = new BrotliCompressorInputStream(is)) {
+            assertEquals(0, in.available());
+        }
+    }
 
     /**
-     * Test bridge works fine
-     * @throws {@link IOException}
+     * Test bridge works fine.
+     *
+     * @throws IOException
      */
     @Test
     public void testBrotliDecode() throws IOException {
-        final File input = getFile("brotli.testdata.compressed");
         final File expected = getFile("brotli.testdata.uncompressed");
-        try (InputStream inputStream = Files.newInputStream(input.toPath());
-            BrotliCompressorInputStream brotliInputStream = new BrotliCompressorInputStream(inputStream)) {
+        try (InputStream inputStream = newInputStream("brotli.testdata.compressed");
+                BrotliCompressorInputStream brotliInputStream = new BrotliCompressorInputStream(inputStream)) {
             final byte[] b = new byte[20];
             IOUtils.read(expected, b);
             final ByteArrayOutputStream bos = new ByteArrayOutputStream();
@@ -53,7 +60,17 @@ public class BrotliCompressorInputStreamTest extends AbstractTestCase {
             while ((readByte = brotliInputStream.read()) != -1) {
                 bos.write(readByte);
             }
-            Assert.assertArrayEquals(b, bos.toByteArray());
+            assertArrayEquals(b, bos.toByteArray());
+        }
+    }
+
+    @Test
+    public void testBrotliUnarchive() throws Exception {
+        final File output = newTempFile("bla.tar");
+        try (InputStream is = newInputStream("bla.tar.br")) {
+            try (CompressorInputStream in = new CompressorStreamFactory().createCompressorInputStream("br", is)) {
+                Files.copy(in, output.toPath());
+            }
         }
     }
 
@@ -74,6 +91,44 @@ public class BrotliCompressorInputStreamTest extends AbstractTestCase {
         }
     }
 
+    @Test
+    public void testMultiByteReadConsistentlyReturnsMinusOneAtEof() throws IOException {
+        final byte[] buf = new byte[2];
+        try (InputStream is = newInputStream("brotli.testdata.compressed");
+                final BrotliCompressorInputStream in = new BrotliCompressorInputStream(is)) {
+            IOUtils.toByteArray(in);
+            assertEquals(-1, in.read(buf));
+            assertEquals(-1, in.read(buf));
+        }
+    }
+
+    @Test
+    public void testShouldBeAbleToSkipAByte() throws IOException {
+        try (InputStream is = newInputStream("brotli.testdata.compressed");
+                final BrotliCompressorInputStream in = new BrotliCompressorInputStream(is)) {
+            assertEquals(1, in.skip(1));
+        }
+    }
+
+    @Test
+    public void testSingleByteReadConsistentlyReturnsMinusOneAtEof() throws IOException {
+        try (InputStream is = newInputStream("brotli.testdata.compressed");
+                final BrotliCompressorInputStream in = new BrotliCompressorInputStream(is)) {
+            IOUtils.toByteArray(in);
+            assertEquals(-1, in.read());
+            assertEquals(-1, in.read());
+        }
+    }
+
+    @Test
+    public void testSingleByteReadWorksAsExpected() throws IOException {
+        try (InputStream is = newInputStream("brotli.testdata.compressed");
+                final BrotliCompressorInputStream in = new BrotliCompressorInputStream(is)) {
+            // starts with file name "XXX"
+            assertEquals('X', in.read());
+        }
+    }
+
     @Test
     public void testTurningOnCachingReEvaluatesAvailability() {
         try {
@@ -86,79 +141,4 @@ public class BrotliCompressorInputStreamTest extends AbstractTestCase {
         }
     }
 
-
-    @Test
-    public void availableShouldReturnZero() throws IOException {
-        final File input = getFile("brotli.testdata.compressed");
-        try (InputStream is = Files.newInputStream(input.toPath())) {
-            final BrotliCompressorInputStream in =
-                    new BrotliCompressorInputStream(is);
-            assertEquals(0, in.available());
-            in.close();
-        }
-    }
-
-    @Test
-    public void shouldBeAbleToSkipAByte() throws IOException {
-        final File input = getFile("brotli.testdata.compressed");
-        try (InputStream is = Files.newInputStream(input.toPath())) {
-            final BrotliCompressorInputStream in =
-                    new BrotliCompressorInputStream(is);
-            Assert.assertEquals(1, in.skip(1));
-            in.close();
-        }
-    }
-
-    @Test
-    public void singleByteReadWorksAsExpected() throws IOException {
-        final File input = getFile("brotli.testdata.compressed");
-        try (InputStream is = Files.newInputStream(input.toPath())) {
-            final BrotliCompressorInputStream in =
-                    new BrotliCompressorInputStream(is);
-            //  starts with filename "XXX"
-            Assert.assertEquals('X', in.read());
-            in.close();
-        }
-    }
-
-    @Test
-    public void singleByteReadConsistentlyReturnsMinusOneAtEof() throws IOException {
-        final File input = getFile("brotli.testdata.compressed");
-        try (InputStream is = Files.newInputStream(input.toPath())) {
-            final BrotliCompressorInputStream in =
-                    new BrotliCompressorInputStream(is);
-            IOUtils.toByteArray(in);
-            Assert.assertEquals(-1, in.read());
-            Assert.assertEquals(-1, in.read());
-            in.close();
-        }
-    }
-
-    @Test
-    public void multiByteReadConsistentlyReturnsMinusOneAtEof() throws IOException {
-        final File input = getFile("brotli.testdata.compressed");
-        final byte[] buf = new byte[2];
-        try (InputStream is = Files.newInputStream(input.toPath())) {
-            final BrotliCompressorInputStream in =
-                    new BrotliCompressorInputStream(is);
-            IOUtils.toByteArray(in);
-            Assert.assertEquals(-1, in.read(buf));
-            Assert.assertEquals(-1, in.read(buf));
-            in.close();
-        }
-    }
-
-    @Test
-    public void testBrotliUnarchive() throws Exception {
-        final File input = getFile("bla.tar.br");
-        final File output = new File(dir, "bla.tar");
-        try (InputStream is = Files.newInputStream(input.toPath())) {
-            try (CompressorInputStream in = new CompressorStreamFactory()
-                    .createCompressorInputStream("br", is);
-                    OutputStream out = Files.newOutputStream(output.toPath())) {
-                IOUtils.copy(in, out);
-            }
-        }
-    }
-
 }
