@@ -19,9 +19,9 @@
 package org.apache.commons.compress.compressors.lz77support;
 
 import static java.nio.charset.StandardCharsets.US_ASCII;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -62,6 +62,50 @@ public class LZ77CompressorTest {
         ONE_TO_TEN = new byte[] { 1, 2, 3, 4, 5, 6, 7, 8, 9, 10 };
     }
 
+    private static final void assertBackReference(final int expectedOffset, final int expectedLength, final LZ77Compressor.Block block) {
+        assertEquals(LZ77Compressor.BackReference.class, block.getClass());
+        final LZ77Compressor.BackReference b = (LZ77Compressor.BackReference) block;
+        assertEquals(expectedOffset, b.getOffset());
+        assertEquals(expectedLength, b.getLength());
+    }
+
+    private static final void assertLiteralBlock(final byte[] expectedContent, final LZ77Compressor.Block block) {
+        assertEquals(LZ77Compressor.LiteralBlock.class, block.getClass());
+        assertArrayEquals(expectedContent, ((LZ77Compressor.LiteralBlock) block).getData());
+    }
+
+    private static final void assertLiteralBlock(final String expectedContent, final LZ77Compressor.Block block) {
+        assertLiteralBlock(expectedContent.getBytes(US_ASCII), block);
+    }
+
+    private static final void assertSize(final int expectedSize, final List<LZ77Compressor.Block> blocks) {
+        assertEquals(expectedSize, blocks.size());
+        assertEquals(LZ77Compressor.Block.BlockType.EOD, blocks.get(expectedSize - 1).getType());
+    }
+
+    private static Parameters newParameters(final int windowSize) {
+        return Parameters.builder(windowSize).build();
+    }
+
+    private static Parameters newParameters(final int windowSize, final int minBackReferenceLength, final int maxBackReferenceLength,
+        final int maxOffset, final int maxLiteralLength) {
+        return Parameters.builder(windowSize)
+            .withMinBackReferenceLength(minBackReferenceLength)
+            .withMaxBackReferenceLength(maxBackReferenceLength)
+            .withMaxOffset(maxOffset)
+            .withMaxLiteralLength(maxLiteralLength)
+            .tunedForCompressionRatio()
+            .build();
+    }
+
+    private static final byte[][] stagger(final byte[] data) {
+        final byte[][] r = new byte[data.length][1];
+        for (int i = 0; i < data.length; i++) {
+            r[i][0] = data[i];
+        }
+        return r;
+    }
+
     private List<LZ77Compressor.Block> compress(final Parameters params, final byte[]... chunks) throws IOException {
         final List<LZ77Compressor.Block> blocks = new ArrayList<>();
         final LZ77Compressor c = new LZ77Compressor(params, block -> {
@@ -86,61 +130,7 @@ public class LZ77CompressorTest {
     }
 
     @Test
-    public void nonCompressableWithLengthSmallerThanLiteralMax() throws IOException {
-        final List<LZ77Compressor.Block> blocks = compress(newParameters(128), ONE_TO_TEN);
-        assertSize(2, blocks);
-        assertLiteralBlock(ONE_TO_TEN, blocks.get(0));
-    }
-
-    @Test
-    public void nonCompressableWithLengthGreaterThanLiteralMaxButLessThanTwiceWindowSize() throws IOException {
-        final List<LZ77Compressor.Block> blocks = compress(newParameters(8), ONE_TO_TEN);
-        assertSize(3, blocks);
-        assertLiteralBlock(new byte[] { 1, 2, 3, 4, 5, 6, 7, 8 }, blocks.get(0));
-        assertLiteralBlock(new byte[] { 9, 10 }, blocks.get(1));
-    }
-
-    @Test
-    public void nonCompressableWithLengthThatForcesWindowSlide() throws IOException {
-        final List<LZ77Compressor.Block> blocks = compress(newParameters(4), ONE_TO_TEN);
-        assertSize(4, blocks);
-        assertLiteralBlock(new byte[] { 1, 2, 3, 4, }, blocks.get(0));
-        assertLiteralBlock(new byte[] { 5, 6, 7, 8 }, blocks.get(1));
-        assertLiteralBlock(new byte[] { 9, 10 }, blocks.get(2));
-    }
-
-    @Test
-    public void nonCompressableSentAsSingleBytes() throws IOException {
-        final List<LZ77Compressor.Block> blocks = compress(newParameters(8), stagger(ONE_TO_TEN));
-        assertSize(3, blocks);
-        assertLiteralBlock(new byte[] { 1, 2, 3, 4, 5, 6, 7, 8 }, blocks.get(0));
-        assertLiteralBlock(new byte[] { 9, 10 }, blocks.get(1));
-    }
-
-    @Test
-    public void blaExampleWithFullArrayAvailableForCompression()
-        throws IOException {
-        final List<LZ77Compressor.Block> blocks = compress(newParameters(128), BLA);
-        assertSize(4, blocks);
-        assertLiteralBlock("Blah b", blocks.get(0));
-        assertBackReference(5, 18, blocks.get(1));
-        assertLiteralBlock("!", blocks.get(2));
-    }
-
-    @Test
-    public void blaExampleWithShorterBackReferenceLength() throws IOException {
-        final List<LZ77Compressor.Block> blocks = compress(newParameters(128, 3, 5, 0, 0), BLA);
-        assertSize(7, blocks);
-        assertLiteralBlock("Blah b", blocks.get(0));
-        assertBackReference(5, 5, blocks.get(1));
-        assertBackReference(5, 5, blocks.get(2));
-        assertBackReference(5, 5, blocks.get(3));
-        assertBackReference(5, 3, blocks.get(4));
-        assertLiteralBlock("!", blocks.get(5));
-    }
-
-    @Test
-    public void blaExampleSmallerWindowSize() throws IOException {
+    public void testBlaExampleSmallerWindowSize() throws IOException {
         final List<LZ77Compressor.Block> blocks = compress(newParameters(8), BLA);
         assertSize(6, blocks);
         assertLiteralBlock("Blah b", blocks.get(0));
@@ -151,47 +141,17 @@ public class LZ77CompressorTest {
     }
 
     @Test
-    public void blaExampleWithSingleByteWrites() throws IOException {
-        final List<LZ77Compressor.Block> blocks = compress(newParameters(128), stagger(BLA));
-        assertEquals(9, blocks.size());
+    public void testBlaExampleWithFullArrayAvailableForCompression()
+        throws IOException {
+        final List<LZ77Compressor.Block> blocks = compress(newParameters(128), BLA);
+        assertSize(4, blocks);
         assertLiteralBlock("Blah b", blocks.get(0));
-        assertBackReference(5, 3, blocks.get(1));
-        assertBackReference(5, 3, blocks.get(2));
-        assertBackReference(5, 3, blocks.get(3));
-        assertBackReference(5, 3, blocks.get(4));
-        assertBackReference(5, 3, blocks.get(5));
-        assertBackReference(5, 3, blocks.get(6));
-        assertLiteralBlock("!", blocks.get(7));
+        assertBackReference(5, 18, blocks.get(1));
+        assertLiteralBlock("!", blocks.get(2));
     }
 
     @Test
-    public void samIAmExampleWithFullArrayAvailableForCompression() throws IOException {
-        final List<LZ77Compressor.Block> blocks = compress(newParameters(1024), SAM);
-        assertEquals(21, blocks.size());
-        assertLiteralBlock("I am Sam\n\n", blocks.get(0));
-        assertBackReference(5, 3, blocks.get(1));
-        assertLiteralBlock(" ", blocks.get(2));
-        assertBackReference(14, 4, blocks.get(3));
-        assertLiteralBlock("\n\nThat", blocks.get(4));
-        assertBackReference(20, 4, blocks.get(5));
-        assertLiteralBlock("-I-am!", blocks.get(6));
-        assertBackReference(15, 16, blocks.get(7));
-        assertLiteralBlock("I do not like\nt", blocks.get(8));
-        assertBackReference(29, 14, blocks.get(9));
-        assertLiteralBlock("\nDo you", blocks.get(10));
-        assertBackReference(28, 5, blocks.get(11));
-        assertLiteralBlock(" green eggs and ham?\n", blocks.get(12));
-        assertBackReference(63, 14, blocks.get(13));
-        assertLiteralBlock(" them,", blocks.get(14));
-        assertBackReference(64, 9, blocks.get(15));
-        assertLiteralBlock(".", blocks.get(16));
-        assertBackReference(30, 15, blocks.get(17));
-        assertBackReference(65, 18, blocks.get(18));
-        assertLiteralBlock(".", blocks.get(19));
-    }
-
-    @Test
-    public void blaExampleWithPrefill() throws IOException {
+    public void testBlaExampleWithPrefill() throws IOException {
         final List<LZ77Compressor.Block> blocks = new ArrayList<>();
         final LZ77Compressor c = new LZ77Compressor(newParameters(128), block -> {
             //System.err.println(block);
@@ -216,33 +176,7 @@ public class LZ77CompressorTest {
     }
 
     @Test
-    public void blaExampleWithShortPrefill() throws IOException {
-        final List<LZ77Compressor.Block> blocks = new ArrayList<>();
-        final LZ77Compressor c = new LZ77Compressor(newParameters(128), block -> {
-            //System.err.println(block);
-            if (block instanceof LZ77Compressor.LiteralBlock) {
-                // replace with a real copy of data so tests
-                // can see the results as they've been when
-                // the callback has been called
-                final LZ77Compressor.LiteralBlock b = (LZ77Compressor.LiteralBlock) block;
-                final int len = b.getLength();
-                block = new LZ77Compressor.LiteralBlock(
-                    Arrays.copyOfRange(b.getData(), b.getOffset(), b.getOffset() + len),
-                    0, len);
-            }
-            blocks.add(block);
-        });
-        c.prefill(Arrays.copyOfRange(BLA, 0, 2));
-        c.compress(Arrays.copyOfRange(BLA, 2, BLA.length));
-        c.finish();
-        assertSize(4, blocks);
-        assertLiteralBlock("ah b", blocks.get(0));
-        assertBackReference(5, 18, blocks.get(1));
-        assertLiteralBlock("!", blocks.get(2));
-    }
-
-    @Test
-    public void blaExampleWithPrefillBiggerThanWindowSize() throws IOException {
+    public void testBlaExampleWithPrefillBiggerThanWindowSize() throws IOException {
         final List<LZ77Compressor.Block> blocks = new ArrayList<>();
         final LZ77Compressor c = new LZ77Compressor(newParameters(4), block -> {
             //System.err.println(block);
@@ -270,60 +204,126 @@ public class LZ77CompressorTest {
     }
 
     @Test
-    public void cantPrefillTwice() {
+    public void testBlaExampleWithShorterBackReferenceLength() throws IOException {
+        final List<LZ77Compressor.Block> blocks = compress(newParameters(128, 3, 5, 0, 0), BLA);
+        assertSize(7, blocks);
+        assertLiteralBlock("Blah b", blocks.get(0));
+        assertBackReference(5, 5, blocks.get(1));
+        assertBackReference(5, 5, blocks.get(2));
+        assertBackReference(5, 5, blocks.get(3));
+        assertBackReference(5, 3, blocks.get(4));
+        assertLiteralBlock("!", blocks.get(5));
+    }
+
+    @Test
+    public void testBlaExampleWithShortPrefill() throws IOException {
+        final List<LZ77Compressor.Block> blocks = new ArrayList<>();
+        final LZ77Compressor c = new LZ77Compressor(newParameters(128), block -> {
+            //System.err.println(block);
+            if (block instanceof LZ77Compressor.LiteralBlock) {
+                // replace with a real copy of data so tests
+                // can see the results as they've been when
+                // the callback has been called
+                final LZ77Compressor.LiteralBlock b = (LZ77Compressor.LiteralBlock) block;
+                final int len = b.getLength();
+                block = new LZ77Compressor.LiteralBlock(
+                    Arrays.copyOfRange(b.getData(), b.getOffset(), b.getOffset() + len),
+                    0, len);
+            }
+            blocks.add(block);
+        });
+        c.prefill(Arrays.copyOfRange(BLA, 0, 2));
+        c.compress(Arrays.copyOfRange(BLA, 2, BLA.length));
+        c.finish();
+        assertSize(4, blocks);
+        assertLiteralBlock("ah b", blocks.get(0));
+        assertBackReference(5, 18, blocks.get(1));
+        assertLiteralBlock("!", blocks.get(2));
+    }
+
+    @Test
+    public void testBlaExampleWithSingleByteWrites() throws IOException {
+        final List<LZ77Compressor.Block> blocks = compress(newParameters(128), stagger(BLA));
+        assertEquals(9, blocks.size());
+        assertLiteralBlock("Blah b", blocks.get(0));
+        assertBackReference(5, 3, blocks.get(1));
+        assertBackReference(5, 3, blocks.get(2));
+        assertBackReference(5, 3, blocks.get(3));
+        assertBackReference(5, 3, blocks.get(4));
+        assertBackReference(5, 3, blocks.get(5));
+        assertBackReference(5, 3, blocks.get(6));
+        assertLiteralBlock("!", blocks.get(7));
+    }
+
+    @Test
+    public void testCantPrefillAfterCompress() throws IOException {
+        final LZ77Compressor c = new LZ77Compressor(newParameters(128), block -> {});
+        c.compress(Arrays.copyOfRange(BLA, 0, 2));
+        assertThrows(IllegalStateException.class, () -> c.prefill(Arrays.copyOfRange(BLA, 2, 4)));
+    }
+
+    @Test
+    public void testCantPrefillTwice() {
         final LZ77Compressor c = new LZ77Compressor(newParameters(128), block -> {});
         c.prefill(Arrays.copyOfRange(BLA, 0, 2));
         assertThrows(IllegalStateException.class, () -> c.prefill(Arrays.copyOfRange(BLA, 2, 4)));
     }
 
     @Test
-    public void cantPrefillAfterCompress() throws IOException {
-        final LZ77Compressor c = new LZ77Compressor(newParameters(128), block -> {});
-        c.compress(Arrays.copyOfRange(BLA, 0, 2));
-        assertThrows(IllegalStateException.class, () -> c.prefill(Arrays.copyOfRange(BLA, 2, 4)));
+    public void testNonCompressableSentAsSingleBytes() throws IOException {
+        final List<LZ77Compressor.Block> blocks = compress(newParameters(8), stagger(ONE_TO_TEN));
+        assertSize(3, blocks);
+        assertLiteralBlock(new byte[] { 1, 2, 3, 4, 5, 6, 7, 8 }, blocks.get(0));
+        assertLiteralBlock(new byte[] { 9, 10 }, blocks.get(1));
     }
 
-    private static final void assertSize(final int expectedSize, final List<LZ77Compressor.Block> blocks) {
-        assertEquals(expectedSize, blocks.size());
-        assertEquals(LZ77Compressor.Block.BlockType.EOD, blocks.get(expectedSize - 1).getType());
+    @Test
+    public void testNonCompressableWithLengthGreaterThanLiteralMaxButLessThanTwiceWindowSize() throws IOException {
+        final List<LZ77Compressor.Block> blocks = compress(newParameters(8), ONE_TO_TEN);
+        assertSize(3, blocks);
+        assertLiteralBlock(new byte[] { 1, 2, 3, 4, 5, 6, 7, 8 }, blocks.get(0));
+        assertLiteralBlock(new byte[] { 9, 10 }, blocks.get(1));
     }
 
-    private static final void assertLiteralBlock(final String expectedContent, final LZ77Compressor.Block block) {
-        assertLiteralBlock(expectedContent.getBytes(US_ASCII), block);
+    @Test
+    public void testNonCompressableWithLengthSmallerThanLiteralMax() throws IOException {
+        final List<LZ77Compressor.Block> blocks = compress(newParameters(128), ONE_TO_TEN);
+        assertSize(2, blocks);
+        assertLiteralBlock(ONE_TO_TEN, blocks.get(0));
     }
 
-    private static final void assertLiteralBlock(final byte[] expectedContent, final LZ77Compressor.Block block) {
-        assertEquals(LZ77Compressor.LiteralBlock.class, block.getClass());
-        assertArrayEquals(expectedContent, ((LZ77Compressor.LiteralBlock) block).getData());
+    @Test
+    public void testNonCompressableWithLengthThatForcesWindowSlide() throws IOException {
+        final List<LZ77Compressor.Block> blocks = compress(newParameters(4), ONE_TO_TEN);
+        assertSize(4, blocks);
+        assertLiteralBlock(new byte[] { 1, 2, 3, 4, }, blocks.get(0));
+        assertLiteralBlock(new byte[] { 5, 6, 7, 8 }, blocks.get(1));
+        assertLiteralBlock(new byte[] { 9, 10 }, blocks.get(2));
     }
 
-    private static final void assertBackReference(final int expectedOffset, final int expectedLength, final LZ77Compressor.Block block) {
-        assertEquals(LZ77Compressor.BackReference.class, block.getClass());
-        final LZ77Compressor.BackReference b = (LZ77Compressor.BackReference) block;
-        assertEquals(expectedOffset, b.getOffset());
-        assertEquals(expectedLength, b.getLength());
-    }
-
-    private static final byte[][] stagger(final byte[] data) {
-        final byte[][] r = new byte[data.length][1];
-        for (int i = 0; i < data.length; i++) {
-            r[i][0] = data[i];
-        }
-        return r;
-    }
-
-    private static Parameters newParameters(final int windowSize) {
-        return Parameters.builder(windowSize).build();
-    }
-
-    private static Parameters newParameters(final int windowSize, final int minBackReferenceLength, final int maxBackReferenceLength,
-        final int maxOffset, final int maxLiteralLength) {
-        return Parameters.builder(windowSize)
-            .withMinBackReferenceLength(minBackReferenceLength)
-            .withMaxBackReferenceLength(maxBackReferenceLength)
-            .withMaxOffset(maxOffset)
-            .withMaxLiteralLength(maxLiteralLength)
-            .tunedForCompressionRatio()
-            .build();
+    @Test
+    public void testSamIAmExampleWithFullArrayAvailableForCompression() throws IOException {
+        final List<LZ77Compressor.Block> blocks = compress(newParameters(1024), SAM);
+        assertEquals(21, blocks.size());
+        assertLiteralBlock("I am Sam\n\n", blocks.get(0));
+        assertBackReference(5, 3, blocks.get(1));
+        assertLiteralBlock(" ", blocks.get(2));
+        assertBackReference(14, 4, blocks.get(3));
+        assertLiteralBlock("\n\nThat", blocks.get(4));
+        assertBackReference(20, 4, blocks.get(5));
+        assertLiteralBlock("-I-am!", blocks.get(6));
+        assertBackReference(15, 16, blocks.get(7));
+        assertLiteralBlock("I do not like\nt", blocks.get(8));
+        assertBackReference(29, 14, blocks.get(9));
+        assertLiteralBlock("\nDo you", blocks.get(10));
+        assertBackReference(28, 5, blocks.get(11));
+        assertLiteralBlock(" green eggs and ham?\n", blocks.get(12));
+        assertBackReference(63, 14, blocks.get(13));
+        assertLiteralBlock(" them,", blocks.get(14));
+        assertBackReference(64, 9, blocks.get(15));
+        assertLiteralBlock(".", blocks.get(16));
+        assertBackReference(30, 15, blocks.get(17));
+        assertBackReference(65, 18, blocks.get(18));
+        assertLiteralBlock(".", blocks.get(19));
     }
 }
