@@ -17,6 +17,8 @@
 
 package org.apache.commons.compress.compressors.zstandard;
 
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.IOException;
@@ -24,33 +26,26 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.file.Files;
 
-import org.apache.commons.compress.AbstractTestCase;
+import org.apache.commons.compress.AbstractTest;
 import org.apache.commons.compress.compressors.CompressorInputStream;
 import org.apache.commons.compress.compressors.CompressorOutputStream;
 import org.apache.commons.compress.compressors.CompressorStreamFactory;
 import org.apache.commons.compress.utils.IOUtils;
-import org.junit.Assert;
 import org.junit.jupiter.api.Test;
 
-public class ZstdRoundtripTest extends AbstractTestCase {
+public class ZstdRoundtripTest extends AbstractTest {
 
     private interface OutputStreamCreator {
         ZstdCompressorOutputStream wrap(FileOutputStream os) throws IOException;
     }
 
-    @Test
-    public void directRoundtrip() throws Exception {
-        roundtrip(ZstdCompressorOutputStream::new);
-    }
-
     private void roundtrip(final OutputStreamCreator oc) throws IOException {
         final File input = getFile("bla.tar");
         long start = System.currentTimeMillis();
-        final File output = new File(dir, input.getName() + ".zstd");
-        try (InputStream is = Files.newInputStream(input.toPath());
-             FileOutputStream os = new FileOutputStream(output);
+        final File output = newTempFile(input.getName() + ".zstd");
+        try (FileOutputStream os = new FileOutputStream(output);
              ZstdCompressorOutputStream zos = oc.wrap(os)) {
-            IOUtils.copy(is, zos);
+            Files.copy(input.toPath(), zos);
         }
         //System.err.println(input.getName() + " written, uncompressed bytes: " + input.length()
         //    + ", compressed bytes: " + output.length() + " after " + (System.currentTimeMillis() - start) + "ms");
@@ -59,44 +54,47 @@ public class ZstdRoundtripTest extends AbstractTestCase {
              ZstdCompressorInputStream zis = new ZstdCompressorInputStream(Files.newInputStream(output.toPath()))) {
             final byte[] expected = IOUtils.toByteArray(is);
             final byte[] actual = IOUtils.toByteArray(zis);
-            Assert.assertArrayEquals(expected, actual);
+            assertArrayEquals(expected, actual);
         }
         // System.err.println(output.getName() + " read after " + (System.currentTimeMillis() - start) + "ms");
     }
 
     @Test
-    public void factoryRoundtrip() throws Exception {
+    public void testDirectRoundtrip() throws Exception {
+        roundtrip(ZstdCompressorOutputStream::new);
+    }
+
+    @Test
+    public void testFactoryRoundtrip() throws Exception {
         final File input = getFile("bla.tar");
         long start = System.currentTimeMillis();
-        final File output = new File(dir, input.getName() + ".zstd");
-        try (InputStream is = Files.newInputStream(input.toPath());
-             OutputStream os = Files.newOutputStream(output.toPath());
-             CompressorOutputStream zos = new CompressorStreamFactory().createCompressorOutputStream("zstd", os)) {
-            IOUtils.copy(is, zos);
+        final File output = newTempFile(input.getName() + ".zstd");
+        try (OutputStream os = Files.newOutputStream(output.toPath());
+                CompressorOutputStream zos = new CompressorStreamFactory().createCompressorOutputStream("zstd", os)) {
+            Files.copy(input.toPath(), zos);
         }
         start = System.currentTimeMillis();
-        try (InputStream is = Files.newInputStream(input.toPath());
-             CompressorInputStream zis = new CompressorStreamFactory()
-             .createCompressorInputStream("zstd", Files.newInputStream(output.toPath()))) {
-            final byte[] expected = IOUtils.toByteArray(is);
+        try (final InputStream inputStream = Files.newInputStream(output.toPath());
+                CompressorInputStream zis = new CompressorStreamFactory().createCompressorInputStream("zstd", inputStream)) {
+            final byte[] expected = Files.readAllBytes(input.toPath());
             final byte[] actual = IOUtils.toByteArray(zis);
-            Assert.assertArrayEquals(expected, actual);
+            assertArrayEquals(expected, actual);
         }
     }
 
     @Test
-    public void roundtripWithCustomLevel() throws Exception {
-        roundtrip(os -> new ZstdCompressorOutputStream(os, 1));
+    public void testRoundtripWithChecksum() throws Exception {
+        roundtrip(os -> new ZstdCompressorOutputStream(os, 3, false, true));
     }
 
     @Test
-    public void roundtripWithCloseFrameOnFlush() throws Exception {
+    public void testRoundtripWithCloseFrameOnFlush() throws Exception {
         roundtrip(os -> new ZstdCompressorOutputStream(os, 3, true));
     }
 
     @Test
-    public void roundtripWithChecksum() throws Exception {
-        roundtrip(os -> new ZstdCompressorOutputStream(os, 3, false, true));
+    public void testRoundtripWithCustomLevel() throws Exception {
+        roundtrip(os -> new ZstdCompressorOutputStream(os, 1));
     }
 
 }
