@@ -17,25 +17,13 @@
 
 package org.apache.commons.compress.compressors.zstandard;
 
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import org.junit.jupiter.api.Test;
 
 public class ZstdUtilsTest {
 
-    @Test
-    public void testMatchesZstandardFrame() {
-        final byte[] data = {
-            (byte) 0x28, (byte) 0xB5, (byte) 0x2F, (byte) 0xFD,
-        };
-        assertFalse(ZstdUtils.matches(data, 3));
-        assertTrue(ZstdUtils.matches(data, 4));
-        assertTrue(ZstdUtils.matches(data, 5));
-        data[3] = '0';
-        assertFalse(ZstdUtils.matches(data, 4));
-    }
-
     @Test
     public void testMatchesSkippableFrame() {
         final byte[] data = {
@@ -49,4 +37,16 @@ public class ZstdUtilsTest {
         assertFalse(ZstdUtils.matches(data, 3));
         assertTrue(ZstdUtils.matches(data, 5));
     }
+
+    @Test
+    public void testMatchesZstandardFrame() {
+        final byte[] data = {
+            (byte) 0x28, (byte) 0xB5, (byte) 0x2F, (byte) 0xFD,
+        };
+        assertFalse(ZstdUtils.matches(data, 3));
+        assertTrue(ZstdUtils.matches(data, 4));
+        assertTrue(ZstdUtils.matches(data, 5));
+        data[3] = '0';
+        assertFalse(ZstdUtils.matches(data, 4));
+    }
 }
