@@ -16,47 +16,36 @@
  */
 package org.apache.commons.compress.harmony.pack200.tests;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+
 import java.io.ByteArrayInputStream;
+import java.util.stream.Stream;
 
 import org.apache.commons.compress.harmony.pack200.Codec;
 import org.apache.commons.compress.harmony.pack200.Pack200Exception;
 import org.apache.commons.compress.harmony.pack200.PopulationCodec;
 import org.apache.commons.compress.harmony.pack200.RunCodec;
-
-import junit.framework.TestCase;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.Arguments;
+import org.junit.jupiter.params.provider.MethodSource;
 
 /**
  * Test for RunCodec
  */
-public class RunCodecTest extends TestCase {
+public class RunCodecTest {
 
-    public void testRunCodec() {
-        try {
-            new RunCodec(0, Codec.SIGNED5, Codec.UDELTA5);
-            fail("Should not allow a k value of 0");
-        } catch (Pack200Exception e) {
-            // pass
-        }
-        try {
-            new RunCodec(10, null, Codec.UDELTA5);
-            fail("Should not allow a null codec");
-        } catch (Pack200Exception e) {
-            // pass
-        }
-        try {
-            new RunCodec(10, Codec.UDELTA5, null);
-            fail("Should not allow a null codec");
-        } catch (Pack200Exception e) {
-            // pass
-        }
-        try {
-            new RunCodec(10, null, null);
-            fail("Should not allow a null codec");
-        } catch (Pack200Exception e) {
-            // pass
-        }
+    static Stream<Arguments> runCodec() {
+        return Stream.of(
+                Arguments.of(0, Codec.SIGNED5, Codec.UDELTA5, "Should not allow a k value of 0"),
+                Arguments.of(10, null, Codec.UDELTA5, "Should not allow a null codec"),
+                Arguments.of(10, Codec.UDELTA5, null, "Should not allow a null codec"),
+                Arguments.of(10, null, null, "Should not allow a null codec")
+        );
     }
 
+    @Test
     public void testDecode() throws Exception {
         RunCodec runCodec = new RunCodec(1, Codec.UNSIGNED5, Codec.BYTE1);
         ByteArrayInputStream bais = new ByteArrayInputStream(new byte[] {
@@ -74,17 +63,18 @@ public class RunCodecTest extends TestCase {
         assertEquals(0, bais.available());
     }
 
+    @Test
     public void testDecodeInts() throws Exception {
-        int[] band = new int[] { 1, -2, -3, 1000, 55, 5, 10, 20 };
+        final int[] band = { 1, -2, -3, 1000, 55, 5, 10, 20 };
         // first 5 of band to be encoded with DELTA5
-        byte[] bytes1 = Codec.DELTA5.encode(new int[] { 1, -2, -3, 1000, 55 });
+        final byte[] bytes1 = Codec.DELTA5.encode(new int[] { 1, -2, -3, 1000, 55 });
         // rest of band to be encoded with UNSIGNED5
-        byte[] bytes2 = Codec.UNSIGNED5.encode(new int[] { 5, 10, 20 });
-        byte[] bandEncoded = new byte[bytes1.length + bytes2.length];
+        final byte[] bytes2 = Codec.UNSIGNED5.encode(new int[] { 5, 10, 20 });
+        final byte[] bandEncoded = new byte[bytes1.length + bytes2.length];
         System.arraycopy(bytes1, 0, bandEncoded, 0, bytes1.length);
         System.arraycopy(bytes2, 0, bandEncoded, bytes1.length, bytes2.length);
-        RunCodec runCodec = new RunCodec(5, Codec.DELTA5, Codec.UNSIGNED5);
-        int[] bandDecoded = runCodec.decodeInts(8, new ByteArrayInputStream(
+        final RunCodec runCodec = new RunCodec(5, Codec.DELTA5, Codec.UNSIGNED5);
+        final int[] bandDecoded = runCodec.decodeInts(8, new ByteArrayInputStream(
                 bandEncoded));
         assertEquals(band.length, bandDecoded.length);
         for (int i = 0; i < band.length; i++) {
@@ -92,24 +82,33 @@ public class RunCodecTest extends TestCase {
         }
     }
 
+    @Test
+    public void testEncodeSingleValue() {
+        assertThrows(Pack200Exception.class, () -> new RunCodec(10, Codec.SIGNED5, Codec.UDELTA5).encode(5),
+                "Should not allow a single value to be encoded as we don't know which codec to use");
+        assertThrows(Pack200Exception.class, () -> new RunCodec(10, Codec.SIGNED5, Codec.UDELTA5).encode(5, 8),
+                "Should not allow a single value to be encoded as we don't know which codec to use");
+    }
+
+    @Test
     public void testNestedPopulationCodec() throws Exception {
-        int[] band = new int[] { 11, 12, 33, 4000, -555, 5, 10, 20, 10, 3, 20,
+        final int[] band = { 11, 12, 33, 4000, -555, 5, 10, 20, 10, 3, 20,
                 20, 20, 10, 10, 999, 20, 789, 10, 10, 355, 12345 };
         // first 5 of band to be encoded with DELTA5
-        byte[] bytes1 = Codec.DELTA5
+        final byte[] bytes1 = Codec.DELTA5
                 .encode(new int[] { 11, 12, 33, 4000, -555 });
         // rest of band to be encoded with a PopulationCodec
-        PopulationCodec popCodec = new PopulationCodec(Codec.UNSIGNED5,
+        final PopulationCodec popCodec = new PopulationCodec(Codec.UNSIGNED5,
                 Codec.BYTE1, Codec.UNSIGNED5);
-        byte[] bytes2 = popCodec.encode(new int[] { 10, 20 }, new int[] { 0, 1,
+        final byte[] bytes2 = popCodec.encode(new int[] { 10, 20 }, new int[] { 0, 1,
                 2, 1, 0, 2, 2, 2, 1, 1, 0, 2, 0, 1, 1, 0, 0 }, new int[] { 5,
                 3, 999, 789, 355, 12345 });
-        byte[] bandEncoded = new byte[bytes1.length + bytes2.length];
+        final byte[] bandEncoded = new byte[bytes1.length + bytes2.length];
         System.arraycopy(bytes1, 0, bandEncoded, 0, bytes1.length);
         System.arraycopy(bytes2, 0, bandEncoded, bytes1.length, bytes2.length);
-        RunCodec runCodec = new RunCodec(5, Codec.DELTA5, new PopulationCodec(
+        final RunCodec runCodec = new RunCodec(5, Codec.DELTA5, new PopulationCodec(
                 Codec.UNSIGNED5, Codec.BYTE1, Codec.UNSIGNED5));
-        int[] bandDecoded = runCodec.decodeInts(band.length,
+        final int[] bandDecoded = runCodec.decodeInts(band.length,
                 new ByteArrayInputStream(bandEncoded));
         assertEquals(band.length, bandDecoded.length);
         for (int i = 0; i < band.length; i++) {
@@ -117,22 +116,23 @@ public class RunCodecTest extends TestCase {
         }
     }
 
+    @Test
     public void testNestedRunCodec() throws Exception {
-        int[] band = new int[] { 1, 2, 3, 10, 20, 30, 100, 200, 300 };
+        final int[] band = { 1, 2, 3, 10, 20, 30, 100, 200, 300 };
         // first 3 of band to be encoded with UDELTA5
-        byte[] bytes1 = Codec.UDELTA5.encode(new int[] { 1, 2, 3 });
+        final byte[] bytes1 = Codec.UDELTA5.encode(new int[] { 1, 2, 3 });
         // rest of band to be encoded with a RunCodec
-        byte[] bytes2 = Codec.BYTE1.encode(new int[] { 10, 20, 30 });
-        byte[] bytes3 = Codec.UNSIGNED5.encode(new int[] { 100, 200, 300 });
-        byte[] bandEncoded = new byte[bytes1.length + bytes2.length
+        final byte[] bytes2 = Codec.BYTE1.encode(new int[] { 10, 20, 30 });
+        final byte[] bytes3 = Codec.UNSIGNED5.encode(new int[] { 100, 200, 300 });
+        final byte[] bandEncoded = new byte[bytes1.length + bytes2.length
                 + bytes3.length];
         System.arraycopy(bytes1, 0, bandEncoded, 0, bytes1.length);
         System.arraycopy(bytes2, 0, bandEncoded, bytes1.length, bytes2.length);
         System.arraycopy(bytes3, 0, bandEncoded, bytes1.length + bytes2.length,
                 bytes3.length);
-        RunCodec runCodec = new RunCodec(3, Codec.UDELTA5, new RunCodec(3,
+        final RunCodec runCodec = new RunCodec(3, Codec.UDELTA5, new RunCodec(3,
                 Codec.BYTE1, Codec.UNSIGNED5));
-        int[] bandDecoded = runCodec.decodeInts(9, new ByteArrayInputStream(
+        final int[] bandDecoded = runCodec.decodeInts(9, new ByteArrayInputStream(
                 bandEncoded));
         assertEquals(band.length, bandDecoded.length);
         for (int i = 0; i < band.length; i++) {
@@ -140,25 +140,17 @@ public class RunCodecTest extends TestCase {
         }
     }
 
+    @ParameterizedTest
+    @MethodSource("runCodec")
+    public void testRunCodec(final int k, final Codec aCodec, final Codec bCodec, final String failureMessage) {
+        assertThrows(Pack200Exception.class, () -> new RunCodec(k, aCodec, bCodec), failureMessage);
+    }
+
+    @Test
     public void testToString() throws Pack200Exception {
-        RunCodec runCodec = new RunCodec(3, Codec.UNSIGNED5, Codec.BYTE1);
+        final RunCodec runCodec = new RunCodec(3, Codec.UNSIGNED5, Codec.BYTE1);
         assertEquals(
                 "RunCodec[k=" + 3 + ";aCodec=" + Codec.UNSIGNED5 + "bCodec=" + Codec.BYTE1 + "]",
                 runCodec.toString());
     }
-
-    public void testEncodeSingleValue() {
-        try {
-            new RunCodec(10, Codec.SIGNED5, Codec.UDELTA5).encode(5);
-            fail("Should not allow a single value to be encoded as we don't know which codec to use");
-        } catch (Pack200Exception e) {
-            // pass
-        }
-        try {
-            new RunCodec(10, Codec.SIGNED5, Codec.UDELTA5).encode(5, 8);
-            fail("Should not allow a single value to be encoded as we don't know which codec to use");
-        } catch (Pack200Exception e) {
-            // pass
-        }
-    }
 }
