@@ -16,15 +16,28 @@
  */
 package org.apache.commons.compress.harmony.unpack200.tests.bytecode;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
+import java.util.stream.Stream;
+
 import org.apache.commons.compress.harmony.unpack200.bytecode.ByteCode;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.Arguments;
+import org.junit.jupiter.params.provider.MethodSource;
 
-import junit.framework.TestCase;
+public class ByteCodeTest {
 
-public class ByteCodeTest extends TestCase {
+    static Stream<Arguments> byteCode() {
+        return Stream.of(
+                Arguments.of(0, "nop"),
+                Arguments.of(-79, "return"),
+                Arguments.of(177, "return")
+        );
+    }
 
-    public void testByteCode() {
-        assertEquals("nop", ByteCode.getByteCode(0).getName());
-        assertEquals("return", ByteCode.getByteCode(-79).getName());
-        assertEquals("return", ByteCode.getByteCode(177).getName());
+    @ParameterizedTest
+    @MethodSource("byteCode")
+    public void testByteCode(final int opCode, final String expectedName) {
+        assertEquals(expectedName, ByteCode.getByteCode(opCode).getName());
     }
 }
