@@ -35,21 +35,24 @@ import org.junit.jupiter.api.Test;
 public class ChecksumVerifyingInputStreamTest {
 
     @Test
-    public void testReadTakingByteArrayThrowsIOException() {
+    public void testReadTakingByteArrayThrowsIOException() throws IOException {
         final Adler32 adler32 = new Adler32();
         final byte[] byteArray = new byte[3];
         final ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(byteArray);
-        final ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(adler32, byteArrayInputStream, (-1859L), (byte) (-68));
-        assertThrows(IOException.class, () -> checksumVerifyingInputStream.read(byteArray));
+        try (ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(adler32, byteArrayInputStream, -1859L,
+                (byte) -68)) {
+            assertThrows(IOException.class, () -> checksumVerifyingInputStream.read(byteArray));
+        }
     }
 
     @Test
-    public void testReadTakingNoArgumentsThrowsIOException() {
+    public void testReadTakingNoArgumentsThrowsIOException() throws IOException {
         final CRC32 cRC32_ = new CRC32();
         final byte[] byteArray = new byte[9];
         final ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(byteArray);
-        final ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(cRC32_, byteArrayInputStream, (byte)1, (byte)1);
-        assertThrows(IOException.class, () -> checksumVerifyingInputStream.read());
+        try (ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(cRC32_, byteArrayInputStream, (byte) 1, (byte) 1)) {
+            assertThrows(IOException.class, () -> checksumVerifyingInputStream.read());
+        }
     }
 
     @Test
@@ -57,13 +60,15 @@ public class ChecksumVerifyingInputStreamTest {
         final CRC32 cRC32_ = new CRC32();
         final byte[] byteArray = new byte[4];
         final ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(byteArray);
-        final ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(cRC32_, byteArrayInputStream, (byte)33, 2303L);
-        final int intOne = checksumVerifyingInputStream.read(byteArray);
-        final long skipReturnValue = checksumVerifyingInputStream.skip((byte)1);
-        assertEquals(558161692L, cRC32_.getValue());
-        assertEquals(0, byteArrayInputStream.available());
-        assertArrayEquals(new byte[] {(byte)0, (byte)0, (byte)0, (byte)0}, byteArray);
-        assertEquals(0L, skipReturnValue);
+        try (ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(cRC32_, byteArrayInputStream, (byte) 33, 2303L)) {
+            @SuppressWarnings("unused")
+            final int intOne = checksumVerifyingInputStream.read(byteArray);
+            final long skipReturnValue = checksumVerifyingInputStream.skip((byte) 1);
+            assertEquals(558161692L, cRC32_.getValue());
+            assertEquals(0, byteArrayInputStream.available());
+            assertArrayEquals(new byte[] { (byte) 0, (byte) 0, (byte) 0, (byte) 0 }, byteArray);
+            assertEquals(0L, skipReturnValue);
+        }
     }
 
 }
\ No newline at end of file
