@@ -13,13 +13,12 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 
 package org.apache.commons.compress.utils;
 
-import static org.apache.commons.compress.AbstractTestCase.getFile;
-import static org.apache.commons.compress.AbstractTestCase.getPath;
+import static org.apache.commons.compress.AbstractTest.getFile;
+import static org.apache.commons.compress.AbstractTest.getPath;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertSame;
 import static org.junit.jupiter.api.Assertions.assertThrows;
@@ -40,127 +39,6 @@ import org.junit.jupiter.api.Test;
 
 public class ZipSplitReadOnlySeekableByteChannelTest {
 
-    @Test
-    public void buildFromLastSplitSegmentThrowsOnNotZipFile() throws IOException {
-        final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
-        assertThrows(IllegalArgumentException.class, () -> ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile));
-    }
-
-    @Test
-    public void channelsPositionIsZeroAfterConstructor() throws IOException {
-        final List<SeekableByteChannel> channels = getSplitZipChannels();
-        new ZipSplitReadOnlySeekableByteChannel(channels);
-        for (final SeekableByteChannel channel : channels) {
-            assertEquals(0, channel.position());
-        }
-    }
-
-    @Test
-    public void constructorThrowsOnNonSplitZipFiles() throws IOException {
-        final List<SeekableByteChannel> channels = new ArrayList<>();
-        final File file = getFile("COMPRESS-189.zip");
-        channels.add(Files.newByteChannel(file.toPath(), StandardOpenOption.READ));
-        assertThrows(IOException.class, () -> new ZipSplitReadOnlySeekableByteChannel(channels));
-    }
-
-    @Test
-    public void constructorThrowsOnNullArg() {
-        assertThrows(NullPointerException.class, () -> new ZipSplitReadOnlySeekableByteChannel(null));
-    }
-
-    @Test
-    public void forFilesOfTwoParametersThrowsOnNullArg() {
-        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forFiles(null, null));
-    }
-
-    @Test
-    public void forFilesReturnCorrectClass() throws IOException {
-        final File firstFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
-        final File secondFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z02");
-        final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
-
-        final ArrayList<File> list = new ArrayList<>();
-        list.add(firstFile);
-        list.add(secondFile);
-
-        SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forFiles(lastFile, list);
-        assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
-
-        channel = ZipSplitReadOnlySeekableByteChannel.forFiles(firstFile, secondFile, lastFile);
-        assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
-    }
-
-    @Test
-    public void forFilesThrowsOnNullArg() {
-        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forFiles(null));
-    }
-
-    @Test
-    public void forOrderedSeekableByteChannelsOfTwoParametersThrowsOnNullArg() {
-        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(null, null));
-    }
-
-    @Test
-    public void forOrderedSeekableByteChannelsReturnCorrectClass() throws IOException {
-        final File file1 = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
-        final SeekableByteChannel firstChannel = Files.newByteChannel(file1.toPath(), StandardOpenOption.READ);
-
-        final File file2 = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z02");
-        final SeekableByteChannel secondChannel = Files.newByteChannel(file2.toPath(), StandardOpenOption.READ);
-
-        final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.zip");
-        final SeekableByteChannel lastChannel = Files.newByteChannel(lastFile.toPath(), StandardOpenOption.READ);
-
-        final List<SeekableByteChannel> channels = new ArrayList<>();
-        channels.add(firstChannel);
-        channels.add(secondChannel);
-
-        SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(lastChannel, channels);
-        assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
-
-        channel = ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(firstChannel, secondChannel, lastChannel);
-        assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
-    }
-
-    @Test
-    public void forOrderedSeekableByteChannelsReturnsIdentityForSingleElement() throws IOException {
-        final SeekableByteChannel emptyChannel = new SeekableInMemoryByteChannel(ByteUtils.EMPTY_BYTE_ARRAY);
-        final SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(emptyChannel);
-        assertSame(emptyChannel, channel);
-    }
-
-    @Test
-    public void forOrderedSeekableByteChannelsThrowsOnNullArg() {
-        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(null));
-    }
-
-    @Test
-    public void forPathsOfTwoParametersThrowsOnNullArg() {
-        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forPaths(null, null));
-    }
-
-    @Test
-    public void forPathsReturnCorrectClass() throws IOException {
-        final Path firstFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
-        final Path secondFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z02");
-        final Path lastFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.zip");
-
-        final ArrayList<Path> list = new ArrayList<>();
-        list.add(firstFile);
-        list.add(secondFile);
-
-        SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forPaths(lastFile, list);
-        assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
-
-        channel = ZipSplitReadOnlySeekableByteChannel.forPaths(firstFile, secondFile, lastFile);
-        assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
-    }
-
-    @Test
-    public void forPathsThrowsOnNullArg() {
-        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forPaths(null));
-    }
-
     private List<SeekableByteChannel> getSplitZipChannels() throws IOException {
         final List<SeekableByteChannel> channels = new ArrayList<>();
         final File file1 = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
@@ -176,7 +54,137 @@ public class ZipSplitReadOnlySeekableByteChannelTest {
     }
 
     @Test
-    public void positionToSomeZipSplitSegment() throws IOException {
+    public void testBuildFromLastSplitSegmentThrowsOnNotZipFile() throws IOException {
+        final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
+        assertThrows(IllegalArgumentException.class, () -> ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile));
+    }
+
+    @Test
+    public void testChannelsPositionIsZeroAfterConstructor() throws IOException {
+        final List<SeekableByteChannel> channels = getSplitZipChannels();
+        new ZipSplitReadOnlySeekableByteChannel(channels);
+        for (final SeekableByteChannel channel : channels) {
+            assertEquals(0, channel.position());
+        }
+    }
+
+    @Test
+    public void testConstructorThrowsOnNonSplitZipFiles() throws IOException {
+        final List<SeekableByteChannel> channels = new ArrayList<>();
+        final File file = getFile("COMPRESS-189.zip");
+        try (final SeekableByteChannel byteChannel = Files.newByteChannel(file.toPath(), StandardOpenOption.READ)) {
+            channels.add(byteChannel);
+            assertThrows(IOException.class, () -> new ZipSplitReadOnlySeekableByteChannel(channels));
+        }
+    }
+
+    @Test
+    public void testConstructorThrowsOnNullArg() {
+        assertThrows(NullPointerException.class, () -> new ZipSplitReadOnlySeekableByteChannel(null));
+    }
+
+    @Test
+    public void testForFilesOfTwoParametersThrowsOnNullArg() {
+        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forFiles(null, null));
+    }
+
+    @Test
+    public void testForFilesReturnCorrectClass() throws IOException {
+        final File firstFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
+        final File secondFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z02");
+        final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
+
+        final ArrayList<File> list = new ArrayList<>();
+        list.add(firstFile);
+        list.add(secondFile);
+
+        try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forFiles(lastFile, list)) {
+            assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
+        }
+
+        try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forFiles(firstFile, secondFile, lastFile)) {
+            assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
+        }
+    }
+
+    @Test
+    public void testForFilesThrowsOnNullArg() {
+        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forFiles(null));
+    }
+
+    @Test
+    public void testForOrderedSeekableByteChannelsOfTwoParametersThrowsOnNullArg() {
+        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(null, null));
+    }
+
+    @Test
+    public void testForOrderedSeekableByteChannelsReturnCorrectClass() throws IOException {
+        final File file1 = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
+        final File file2 = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z02");
+        final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.zip");
+
+        try (SeekableByteChannel firstChannel = Files.newByteChannel(file1.toPath(), StandardOpenOption.READ);
+                final SeekableByteChannel secondChannel = Files.newByteChannel(file2.toPath(), StandardOpenOption.READ);
+                final SeekableByteChannel lastChannel = Files.newByteChannel(lastFile.toPath(), StandardOpenOption.READ)) {
+
+            final List<SeekableByteChannel> channels = new ArrayList<>();
+            channels.add(firstChannel);
+            channels.add(secondChannel);
+
+            @SuppressWarnings("resource") // try-with-resources closes
+            final SeekableByteChannel channel1 = ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(lastChannel, channels);
+            assertTrue(channel1 instanceof ZipSplitReadOnlySeekableByteChannel);
+
+            @SuppressWarnings("resource") // try-with-resources closes
+            final SeekableByteChannel channel2 = ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(firstChannel, secondChannel, lastChannel);
+            assertTrue(channel2 instanceof ZipSplitReadOnlySeekableByteChannel);
+        }
+    }
+
+    @Test
+    public void testForOrderedSeekableByteChannelsReturnsIdentityForSingleElement() throws IOException {
+        try (SeekableByteChannel emptyChannel = new SeekableInMemoryByteChannel(ByteUtils.EMPTY_BYTE_ARRAY);
+                final SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(emptyChannel)) {
+            assertSame(emptyChannel, channel);
+        }
+    }
+
+    @Test
+    public void testForOrderedSeekableByteChannelsThrowsOnNullArg() {
+        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(null));
+    }
+
+    @Test
+    public void testForPathsOfTwoParametersThrowsOnNullArg() {
+        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forPaths(null, null));
+    }
+
+    @Test
+    public void testForPathsReturnCorrectClass() throws IOException {
+        final Path firstFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
+        final Path secondFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z02");
+        final Path lastFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.zip");
+
+        final ArrayList<Path> list = new ArrayList<>();
+        list.add(firstFile);
+        list.add(secondFile);
+
+        try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forPaths(lastFile, list)) {
+            assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
+        }
+
+        try (SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forPaths(firstFile, secondFile, lastFile)) {
+            assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
+        }
+    }
+
+    @Test
+    public void testForPathsThrowsOnNullArg() {
+        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forPaths(null));
+    }
+
+    @Test
+    public void testPositionToSomeZipSplitSegment() throws IOException {
         final File firstFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
         final int firstFileSize = (int) firstFile.length();
 
@@ -190,13 +198,15 @@ public class ZipSplitReadOnlySeekableByteChannelTest {
         final int randomDiskNumber = random.nextInt(3);
         final int randomOffset = randomDiskNumber < 2 ? random.nextInt(firstFileSize) : random.nextInt(lastFileSize);
 
-        final ZipSplitReadOnlySeekableByteChannel channel = (ZipSplitReadOnlySeekableByteChannel) ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile);
-        channel.position(randomDiskNumber, randomOffset);
-        long expectedPosition = randomOffset;
+        try (ZipSplitReadOnlySeekableByteChannel channel = (ZipSplitReadOnlySeekableByteChannel) ZipSplitReadOnlySeekableByteChannel
+                .buildFromLastSplitSegment(lastFile)) {
+            channel.position(randomDiskNumber, randomOffset);
+            long expectedPosition = randomOffset;
 
-        expectedPosition += randomDiskNumber > 0 ? firstFileSize : 0;
-        expectedPosition += randomDiskNumber > 1 ? secondFileSize : 0;
+            expectedPosition += randomDiskNumber > 0 ? firstFileSize : 0;
+            expectedPosition += randomDiskNumber > 1 ? secondFileSize : 0;
 
-        assertEquals(expectedPosition, channel.position());
+            assertEquals(expectedPosition, channel.position());
+        }
     }
 }
